@@ -31,13 +31,9 @@
 /* to be renamed qofdate.c */
 #include <ctype.h>
 
-#ifdef HAVE_LANGINFO_H
-#define HAVE_LANGINFO_D_FMT 1
-#endif
-
-#ifdef HAVE_LANGINFO_D_FMT
-#include <langinfo.h>
-#endif
+#ifdef HAVE_LANGINFO_D_FMT 
+#  include <langinfo.h> 
+#endif 
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -46,7 +42,7 @@
 
 #include <glib.h>
 
-#include "gnc-date.h"
+#include "gnc-date-p.h"
 #include "qof.h"
 
 #ifndef HAVE_STRPTIME
@@ -62,13 +58,16 @@
 #  define GNC_D_FMT (nl_langinfo (D_FMT))
 #  define GNC_D_T_FMT (nl_langinfo (D_T_FMT))
 #  define GNC_T_FMT (nl_langinfo (T_FMT))
+#elif defined(G_OS_WIN32)
+#  define GNC_D_FMT (qof_win32_get_time_format(QOF_WIN32_PICTURE_DATE))
+#  define GNC_T_FMT (qof_win32_get_time_format(QOF_WIN32_PICTURE_TIME))
+#  define GNC_D_T_FMT (qof_win32_get_time_format(QOF_WIN32_PICTURE_DATETIME))
 #else
-#  define GNC_D_FMT "%Y-%m-%d"
-#  define GNC_D_T_FMT "%Y-%m-%d %r"
-#  define GNC_T_FMT "%r"
+#  define GNC_D_FMT "%Y-%m-%d" 
+#  define GNC_D_T_FMT "%Y-%m-%d %r" 
+#  define GNC_T_FMT "%r" 
 #endif
 
-
 /* This is now user configured through the gnome options system() */
 static QofDateFormat dateFormat = QOF_DATE_FORMAT_LOCALE;
 static QofDateFormat prevQofDateFormat = QOF_DATE_FORMAT_LOCALE;
@@ -297,41 +296,6 @@ gboolean date_is_last_mday(struct tm *tm)
   return(tm->tm_mday == date_get_last_mday(tm));
 }
 
-/* Add a number of months to a time value
-
- Add a number of months to a time value, and normalize.  Optionally
- also track the last day of the month, i.e. 1/31 -> 2/28 -> 3/30.
-
-param  tm: base time value
-param  months: The number of months to add to this time
-param  track_last_day: Coerce the date value if necessary.
-
-return void
-*/
-void date_add_months (struct tm *tm, int months, gboolean track_last_day)
-{
-  gboolean was_last_day;
-  int new_last_mday;
-
-  /* Have to do this now */
-  was_last_day = date_is_last_mday(tm);
-
-  /* Add in the months and normalize */
-  tm->tm_mon += months;
-  while (tm->tm_mon > 11) {
-    tm->tm_mon -= 12;
-    tm->tm_year++;
-  }
-
-  if (!track_last_day)
-    return;
-
-  /* Track last day of the month, i.e. 1/31 -> 2/28 -> 3/31 */
-  new_last_mday = date_get_last_mday(tm);
-  if (was_last_day || (tm->tm_mday > new_last_mday))
-    tm->tm_mday = new_last_mday;
-}
-
 /* Return the set dateFormat.
 
 return QofDateFormat: enumeration indicating preferred format
@@ -390,7 +354,7 @@ const gchar *qof_date_format_get_string(QofDateFormat df)
    case QOF_DATE_FORMAT_UTC:
     return "%Y-%m-%dT%H:%M:%SZ";
    case QOF_DATE_FORMAT_ISO:
-    return "%y-%m-%d";
+    return "%Y-%m-%d";
    case QOF_DATE_FORMAT_LOCALE:
    default:
     return GNC_D_FMT;
@@ -417,7 +381,7 @@ const gchar *qof_date_text_format_get_string(QofDateFormat df)
    case QOF_DATE_FORMAT_UTC:
     return "%Y-%m-%dT%H:%M:%SZ";
    case QOF_DATE_FORMAT_ISO:
-    return "%y-%b-%d";
+    return "%Y-%b-%d";
    case QOF_DATE_FORMAT_LOCALE:
    default:
     return GNC_D_FMT;
@@ -474,7 +438,7 @@ qof_print_date_dmy_buff (char * buff, size_t len, int day, int month, int year)
         gnc_tm_set_day_start (&tm_str);
 	t = mktime (&tm_str);
 	localtime_r (&t, &tm_str);
-        flen = strftime (buff, len, GNC_D_FMT, &tm_str);
+        flen = qof_strftime (buff, len, GNC_D_FMT, &tm_str);
        if (flen != 0)
          break;
       }
@@ -539,81 +503,6 @@ gnc_print_date (Timespec ts)
 
 /* ============================================================== */
 
-size_t
-qof_print_hours_elapsed_buff (char * buff, size_t len, int secs, gboolean show_secs)
-{
-	size_t flen;
-	if (0 <= secs)
-	{
-		if (show_secs)
-		{
-			flen = g_snprintf(buff, len,
-			   "%02d:%02d:%02d", (int)(secs / 3600),
-			   (int)((secs % 3600) / 60), (int)(secs % 60));
-		}
-		else
-		{
-			flen = g_snprintf(buff, len, 
-			   "%02d:%02d", (int)(secs / 3600),
-			   (int)((secs % 3600) / 60));
-		}
-	} 
-	else 
-	{
-		if (show_secs)
-		{
-			flen = g_snprintf(buff, len,
-			   "-%02d:%02d:%02d", (int)(-secs / 3600),
-			   (int)((-secs % 3600) / 60), (int)(-secs % 60));
-		}
-		else
-		{
-			flen = g_snprintf(buff, len,
-			   "-%02d:%02d", (int)(-secs / 3600),
-			   (int)((-secs % 3600) / 60));
-		}
-	}
-	return flen;
-}
-
-/* ============================================================== */
-
-size_t
-qof_print_minutes_elapsed_buff (char * buff, size_t len, int secs, gboolean show_secs)
-{
-	size_t flen;
-	if (0 <= secs)
-	{
-		if (show_secs)
-		{
-			flen = g_snprintf(buff, len,
-			   "%02d:%02d", 
-				(int)(secs / 60), (int)(secs % 60));
-		}
-		else
-		{
-			flen = g_snprintf(buff, len, 
-			   "%02d", (int)(secs / 60));
-		}
-	} 
-	else 
-	{
-		if (show_secs)
-		{
-			flen = g_snprintf(buff, len,
-			   "-%02d:%02d", (int)(-secs / 60), (int)(-secs % 60));
-		}
-		else
-		{
-			flen = g_snprintf(buff, len,
-			   "-%02d", (int)(-secs / 60));
-		}
-	}
-	return flen;
-}
-
-/* ============================================================== */
-
 size_t
 qof_print_date_time_buff (char * buff, size_t len, time_t secs)
 {
@@ -653,12 +542,12 @@ qof_print_date_time_buff (char * buff, size_t len, time_t secs)
 	case QOF_DATE_FORMAT_UTC:
 	{
 		gtm = *gmtime (&secs);
-		flen = strftime (buff, len, QOF_UTC_DATE_FORMAT, &gtm);
+		flen = qof_strftime (buff, len, QOF_UTC_DATE_FORMAT, &gtm);
 		break;
 	}
     case QOF_DATE_FORMAT_LOCALE:
       {
-        flen = strftime (buff, len, GNC_D_T_FMT, &ltm);
+        flen = qof_strftime (buff, len, GNC_D_T_FMT, &ltm);
       }
       break;
 
@@ -680,32 +569,17 @@ qof_print_time_buff (char * buff, size_t len, time_t secs)
 	if(dateFormat == QOF_DATE_FORMAT_UTC)
 	{
 		gtm = *gmtime (&secs);
-		flen = strftime(buff, len, QOF_UTC_DATE_FORMAT, &gtm);
+		flen = qof_strftime(buff, len, QOF_UTC_DATE_FORMAT, &gtm);
 		return flen;
 	}
 	ltm = *localtime (&secs);
-	flen = strftime (buff, len, GNC_T_FMT, &ltm);
+	flen = qof_strftime (buff, len, GNC_T_FMT, &ltm);
 	
 	return flen;
 }
 
 /* ============================================================== */
 
-int
-qof_is_same_day (time_t ta, time_t tb)
-{
-  struct tm lta, ltb;
-  lta = *localtime (&ta);
-  ltb = *localtime (&tb);
-  if (lta.tm_year == ltb.tm_year)
-  {
-    return (ltb.tm_yday - lta.tm_yday);
-  }
-  return (ltb.tm_year - lta.tm_year)*365;  /* very approximate */
-}
-
-/* ============================================================== */
-
 /* Convert a string into  day, month and year integers
 
     Convert a string into  day / month / year integers according to
@@ -758,7 +632,7 @@ qof_scan_date_internal (const char *buff, int *day, int *month, int *year,
 
    /* Use strtok to find delimiters */
    if (tmp) {
-     static char *delims = ".,-+/\\() ";
+     static char *delims = ".,-+/\\()년월年月 ";
 
       first_field = strtok (tmp, delims);
       if (first_field) {
@@ -944,7 +818,7 @@ char dateSeparator (void)
 
         secs = time(NULL);
         localtime_r(&secs, &tm);
-        strftime(string, sizeof(string), GNC_D_FMT, &tm);
+        qof_strftime(string, sizeof(string), GNC_D_FMT, &tm);
 
         for (s = string; s != '\0'; s++)
           if (!isdigit(*s))
@@ -955,6 +829,126 @@ char dateSeparator (void)
   return '\0';
 }
 
+
+#ifndef G_OS_WIN32
+gchar *
+qof_time_format_from_utf8(const gchar *utf8_format)
+{
+    gchar *retval;
+    GError *error = NULL;
+
+    retval = g_locale_from_utf8(utf8_format, -1, NULL, NULL, &error);
+
+    if (!retval) {
+        g_warning("Could not convert format '%s' from UTF-8: %s", utf8_format,
+                  error->message);
+        g_error_free(error);
+    }
+    return retval;
+}
+
+gchar *
+qof_formatted_time_to_utf8(const gchar *locale_string)
+{
+    gchar *retval;
+    GError *error = NULL;
+
+    retval = g_locale_to_utf8(locale_string, -1, NULL, NULL, &error);
+
+    if (!retval) {
+        g_warning("Could not convert '%s' to UTF-8: %s", locale_string,
+                  error->message);
+        g_error_free(error);
+    }
+    return retval;
+}
+#endif /* G_OS_WIN32 */
+
+gchar *
+qof_format_time(const gchar *format, const struct tm *tm)
+{
+    gchar *locale_format, *tmpbuf, *retval;
+    gsize tmplen, tmpbufsize;
+
+    g_return_val_if_fail(format, 0);
+    g_return_val_if_fail(tm, 0);
+
+    locale_format = qof_time_format_from_utf8(format);
+    if (!locale_format)
+        return NULL;
+
+    tmpbufsize = MAX(128, strlen(locale_format) * 2);
+    while (TRUE) {
+        tmpbuf = g_malloc(tmpbufsize);
+
+        /* Set the first byte to something other than '\0', to be able to
+         * recognize whether strftime actually failed or just returned "".
+         */
+        tmpbuf[0] = '\1';
+        tmplen = strftime(tmpbuf, tmpbufsize, locale_format, tm);
+
+        if (tmplen == 0 && tmpbuf[0] != '\0') {
+            g_free(tmpbuf);
+            tmpbufsize *= 2;
+
+            if (tmpbufsize > 65536) {
+                g_warning("Maximum buffer size for qof_format_time "
+                          "exceeded: giving up");
+                g_free(locale_format);
+
+                return NULL;
+            }
+        } else {
+            break;
+        }
+    }
+    g_free(locale_format);
+
+    retval = qof_formatted_time_to_utf8(tmpbuf);
+    g_free(tmpbuf);
+
+    return retval;
+}
+
+gsize
+qof_strftime(gchar *buf, gsize max, const gchar *format, const struct tm *tm)
+{
+    gsize convlen, retval;
+    gchar *convbuf;
+
+    g_return_val_if_fail(buf, 0);
+    g_return_val_if_fail(max > 0, 0);
+    g_return_val_if_fail(format, 0);
+    g_return_val_if_fail(tm, 0);
+
+    convbuf = qof_format_time(format, tm);
+    if (!convbuf) {
+        buf[0] = '\0';
+        return 0;
+    }
+
+    convlen = strlen(convbuf);
+
+    if (max <= convlen) {
+        /* Ensure only whole characters are copied into the buffer. */
+        gchar *end = g_utf8_find_prev_char(convbuf, convbuf + max);
+        g_assert(end != NULL);
+        convlen = end - convbuf;
+
+        /* Return 0 because the buffer isn't large enough. */
+        retval = 0;
+    } else {
+        retval = convlen;
+    }
+
+    memcpy(buf, convbuf, convlen);
+    buf[convlen] = '\0';
+    g_free(convbuf);
+
+    return retval;
+}
+
+
 /********************************************************************\
 \********************************************************************/
                                                                                 
@@ -1363,40 +1357,6 @@ gnc_timet_get_day_end (time_t time_val)
 }
 
 
-#ifndef GNUCASH_MAJOR_VERSION
-time_t
-gnc_timet_get_day_start_gdate (GDate *date)
-{
-  struct tm stm;
-  time_t secs;
-
-  stm.tm_year = g_date_get_year (date) - 1900;
-  stm.tm_mon = g_date_get_month (date) - 1;
-  stm.tm_mday = g_date_get_day (date);
-  gnc_tm_set_day_start(&stm);
-
-  /* Compute number of seconds */
-  secs = mktime (&stm);
-  return secs;
-}
-
-time_t
-gnc_timet_get_day_end_gdate (GDate *date)
-{
-  struct tm stm;
-  time_t secs;
-
-  stm.tm_year = g_date_get_year (date) - 1900;
-  stm.tm_mon = g_date_get_month (date) - 1;
-  stm.tm_mday = g_date_get_day (date);
-  gnc_tm_set_day_end(&stm);
-
-  /* Compute number of seconds */
-  secs = mktime (&stm);
-  return secs;
-}
-#endif /* GNUCASH_MAJOR_VERSION */
-
 /* ======================================================== */
 
 void
@@ -1429,61 +1389,15 @@ gnc_timet_get_today_end (void)
   return mktime(&tm);
 }
 
-gboolean
-qof_date_add_days(Timespec *ts, gint days)
+void
+gnc_dow_abbrev(gchar *buf, int buf_len, int dow)
 {
-	struct tm tm;
-	time_t    tt;
-
-	g_return_val_if_fail(ts, FALSE);
-	tt = timespecToTime_t(*ts);
-#ifdef HAVE_GMTIME_R
-	tm = *gmtime_r(&tt, &tm);
-#else
-	tm = *gmtime(&tt);
-#endif
-	tm.tm_mday += days;
-	/* let mktime normalise the months and year
-	because we aren't tracking last_day_of_month */
-	tt = mktime(&tm);
-	if(tt < 0) { return FALSE; }
-	timespecFromTime_t(ts, tt);
-	return TRUE;
+    struct tm my_tm;
+    int i;
+    
+    memset(buf, 0, buf_len);
+    memset(&my_tm, 0, sizeof(struct tm));
+    my_tm.tm_wday = dow;
+    i = qof_strftime(buf, buf_len - 1, "%a", &my_tm);
+    buf[i] = 0;
 }
-
-gboolean
-qof_date_add_months(Timespec *ts, gint months, gboolean track_last_day)
-{
-	struct tm tm;
-	time_t    tt;
-	gint new_last_mday;
-	gboolean was_last_day;
-
-	g_return_val_if_fail(ts, FALSE);
-	tt = timespecToTime_t(*ts);
-#ifdef HAVE_GMTIME_R
-	tm = *gmtime_r(&tt, &tm);
-#else
-	tm = *gmtime(&tt);
-#endif
-	was_last_day = date_is_last_mday(&tm);
-	tm.tm_mon += months;
-	while (tm.tm_mon > 11) {
-		tm.tm_mon -= 12;
-		tm.tm_year++;
-	}
-	if (track_last_day) {
-		/* Track last day of the month, i.e. 1/31 -> 2/28 -> 3/31 */
-		new_last_mday = date_get_last_mday(&tm);
-		if (was_last_day || (tm.tm_mday > new_last_mday)) {
-			tm.tm_mday = new_last_mday;
-		}
-	}
-	tt = mktime(&tm);
-	if(tt < 0) { return FALSE; }
-	timespecFromTime_t(ts, tt);
-	return TRUE;
-}
-
-/********************** END OF FILE *********************************\
-\********************************************************************/
