@@ -269,11 +269,17 @@ qof_query_string_predicate (QofQueryCompare how,
   pdata->matchstring = g_strdup (str);
 
   if (is_regex) {
+    int rc;
     int flags = REG_EXTENDED;
     if (options == QOF_STRING_MATCH_CASEINSENSITIVE)
       flags |= REG_ICASE;
 
-    regcomp(&pdata->compiled, str, flags);
+    rc = regcomp(&pdata->compiled, str, flags);
+    if (rc) {
+	g_free(pdata->matchstring);
+	g_free(pdata);
+	return NULL;
+    }
     pdata->is_regex = TRUE;
   }
 
@@ -1444,12 +1450,11 @@ collect_predicate_equal (QofQueryPredData *p1, QofQueryPredData *p2)
 }
 
 static void
-query_collect_cb(QofEntity* ent, gpointer user_data)
+query_collect_cb(QofInstance* ent, gpointer user_data)
 {
 	query_coll_t pdata;
 	GUID *guid;
 
-	guid = guid_malloc();
 	guid = (GUID*)qof_entity_get_guid(ent);
 	pdata = (query_coll_t)user_data;
 	pdata->guids = g_list_append(pdata->guids, guid);
