@@ -35,33 +35,35 @@
          ;; option. The function should restore the option to the original
          ;; value.
          generate-restore-form
-	 ;; the scm->kvp and kvp->scm functions should save and load
-	 ;; the option to a kvp.  The arguments to these function will be
-	 ;; a kvp-frame and a base key-path list for this option.
-	 scm->kvp
-	 kvp->scm	 
+         ;; the scm->kvp and kvp->scm functions should save and load
+         ;; the option to a kvp.  The arguments to these function will be
+         ;; a kvp-frame and a base key-path list for this option.
+         scm->kvp
+         kvp->scm	 
          ;; Validation func should accept a value and return (#t value)
          ;; on success, and (#f "failure-message") on failure. If #t,
          ;; the supplied value will be used by the gui to set the option.
          value-validator
-	 ;;; free-form storage depending on type.
+         ;;; free-form storage depending on type.
          option-data 
-	 ;; If this is a "multiple choice" type of option,
-	 ;; this should be a vector of the following five functions
-	 ;; one taking no arguments giving the number of choices
-         ;; one taking one argument, a non-negative integer, that
+         ;; If this is a "multiple choice" type of option,
+         ;; this should be a vector of the following five functions:
+         ;; 
+         ;; Function 1: taking no arguments, giving the number of choices
+         ;;
+         ;; Function 2: taking one argument, a non-negative integer, that
          ;; returns the scheme value (usually a symbol) matching the
          ;; nth choice
          ;;
-	 ;; one taking one argument, a non-negative integer,
-	 ;; that returns the string matching the nth choice
+         ;; Function 3: taking one argument, a non-negative integer,
+         ;; that returns the string matching the nth choice
          ;;
-	 ;; the third takes one argument and returns the description
-	 ;; containing the nth choice
-	 ;;
-	 ;; the fourth giving a possible value and returning the index
-	 ;; if an option doesn't use these,  this should just be a #f
-	 option-data-fns
+         ;; Function 4: takes one argument and returns the description
+         ;; containing the nth choice
+         ;;
+         ;; Function 5: giving a possible value and returning the index
+         ;; if an option doesn't use these,  this should just be a #f
+         option-data-fns
          ;; This function should return a list of all the strings
          ;; in the option other than the section, name, (define
          ;; (list-lookup list item) and documentation-string that
@@ -196,9 +198,9 @@
      (lambda (x) (set! value x))
      (lambda () default-value)
      (gnc:restore-form-generator value->string)
-     (lambda (f p) (gnc:kvp-frame-set-slot-path f value p))
+     (lambda (f p) (kvp-frame-set-slot-path-gslist f value p))
      (lambda (f p)
-       (let ((v (gnc:kvp-frame-get-slot-path f p)))
+       (let ((v (kvp-frame-get-slot-path-gslist f p)))
 	 (if (and v (string? v))
 	     (set! value v))))
      (lambda (x)
@@ -220,9 +222,9 @@
      (lambda (x) (set! value x))
      (lambda () default-value)
      (gnc:restore-form-generator value->string)
-     (lambda (f p) (gnc:kvp-frame-set-slot-path f value p))
+     (lambda (f p) (kvp-frame-set-slot-path-gslist f value p))
      (lambda (f p)
-       (let ((v (gnc:kvp-frame-get-slot-path f p)))
+       (let ((v (kvp-frame-get-slot-path-gslist f p)))
 	 (if (and v (string? v))
 	     (set! value v))))
      (lambda (x)
@@ -254,9 +256,9 @@
      (lambda (x) (set! value x))
      (lambda () default-value)
      (gnc:restore-form-generator value->string)     
-     (lambda (f p) (gnc:kvp-frame-set-slot-path f value p))
+     (lambda (f p) (kvp-frame-set-slot-path-gslist f value p))
      (lambda (f p)
-       (let ((v (gnc:kvp-frame-get-slot-path f p)))
+       (let ((v (kvp-frame-get-slot-path-gslist f p)))
 	 (if (and v (string? v))
 	     (set! value v))))
      (lambda (x)
@@ -276,12 +278,12 @@
   (define (currency->scm currency)
     (if (string? currency)
         currency
-        (gnc:commodity-get-mnemonic currency)))
+        (gnc-commodity-get-mnemonic currency)))
 
   (define (scm->currency currency)
     (if (string? currency)
-        (gnc:commodity-table-lookup
-         (gnc:book-get-commodity-table (gnc:get-current-book))
+        (gnc-commodity-table-lookup
+         (gnc-commodity-table-get-table (gnc-get-current-book))
          GNC_COMMODITY_NS_CURRENCY currency)
         currency))
 
@@ -293,9 +295,9 @@
       (lambda (x) (set! value (currency->scm x)))
       (lambda ()  (scm->currency default-value))
       (gnc:restore-form-generator value->string)
-      (lambda (f p) (gnc:kvp-frame-set-slot-path f value p))
+      (lambda (f p) (kvp-frame-set-slot-path-gslist f value p))
       (lambda (f p)
-	(let ((v (gnc:kvp-frame-get-slot-path f p)))
+	(let ((v (kvp-frame-get-slot-path-gslist f p)))
 	  (if (and v (string? v))
 	      (set! value v))))
       (lambda (x) (list #t x))
@@ -312,14 +314,14 @@
   (define (budget->guid budget)
     (if (string? budget)
         budget
-        (gnc:budget-get-guid budget)))
+        (gncBudgetGetGUID budget)))
 
   (define (guid->budget budget)
     (if (string? budget)
-        (gnc:budget-lookup budget (gnc:get-current-book))
+        (gnc-budget-lookup budget (gnc-get-current-book))
         budget))
 
-  (let* ((default-value (gnc:budget-get-default (gnc:get-current-book)))
+  (let* ((default-value (gnc-budget-get-default (gnc-get-current-book)))
          (value (budget->guid default-value))
          (option-set #f)
          (value->string (lambda ()
@@ -340,11 +342,11 @@
              (set! option-set #t)) ;; setter
      (lambda ()
        (guid->budget
-        (gnc:budget-get-default (gnc:get-current-book)))) ;; default-getter
+        (gnc-budget-get-default (gnc-get-current-book)))) ;; default-getter
      (gnc:restore-form-generator value->string) ;; ??
-     (lambda (f p) (gnc:kvp-frame-set-slot-path f value p))
+     (lambda (f p) (kvp-frame-set-slot-path-gslist f value p))
      (lambda (f p)
-       (let ((v (gnc:kvp-frame-get-slot-path f p)))
+       (let ((v (kvp-frame-get-slot-path-gslist f p)))
          (if (and v (string? v))
              (set! value v))))
      (lambda (x) (list #t x)) ;; value-validator
@@ -365,12 +367,12 @@
               GNC_COMMODITY_NS_CURRENCY
               commodity)
         (list 'commodity-scm
-              (gnc:commodity-get-namespace commodity)
-              (gnc:commodity-get-mnemonic commodity))))
+              (gnc-commodity-get-namespace commodity)
+              (gnc-commodity-get-mnemonic commodity))))
 
   (define (scm->commodity scm)
-    (gnc:commodity-table-lookup
-     (gnc:book-get-commodity-table (gnc:get-current-book))
+    (gnc-commodity-table-lookup
+     (gnc-commodity-table-get-table (gnc-get-current-book))
      (cadr scm) (caddr scm)))
 
    (let* ((value (commodity->scm default-value))
@@ -385,11 +387,11 @@
       (lambda () default-value)
       (gnc:restore-form-generator value->string)
       (lambda (f p) 
-	(gnc:kvp-frame-set-slot-path f (cadr value) (append p '("ns")))
-	(gnc:kvp-frame-set-slot-path f (caddr value) (append p '("monic"))))
+	(kvp-frame-set-slot-path-gslist f (cadr value) (append p '("ns")))
+	(kvp-frame-set-slot-path-gslist f (caddr value) (append p '("monic"))))
       (lambda (f p)
-	(let ((ns (gnc:kvp-frame-get-slot-path f (append p '("ns"))))
-	      (monic (gnc:kvp-frame-get-slot-path f (append p '("monic")))))
+	(let ((ns (kvp-frame-get-slot-path-gslist f (append p '("ns"))))
+	      (monic (kvp-frame-get-slot-path-gslist f (append p '("monic")))))
 	  (if (and ns monic (string? ns) (string? monic))
 	      (set! value (list 'commodity-scm ns monic)))))
       (lambda (x) (list #t x))
@@ -443,9 +445,9 @@
                       (setter-function-called-cb x)))
       (lambda () default-value)
       (gnc:restore-form-generator value->string)
-      (lambda (f p) (gnc:kvp-frame-set-slot-path f value p))
+      (lambda (f p) (kvp-frame-set-slot-path-gslist f value p))
       (lambda (f p)
-	(let ((v (gnc:kvp-frame-get-slot-path f p)))
+	(let ((v (kvp-frame-get-slot-path-gslist f p)))
 	  (if (and v (boolean? v) (not (equal? v default-value)))
 	      (set! value v))))
       (lambda (x)
@@ -517,16 +519,16 @@
      default-getter
      (gnc:restore-form-generator value->string)
      (lambda (f p)
-       (gnc:kvp-frame-set-slot-path f (symbol->string (car value))
+       (kvp-frame-set-slot-path-gslist f (symbol->string (car value))
 				    (append p '("type")))
-       (gnc:kvp-frame-set-slot-path f
+       (kvp-frame-set-slot-path-gslist f
 				    (if (symbol? (cdr value))
 					(symbol->string (cdr value))
 					(cdr value))
 				    (append p '("value"))))
      (lambda (f p)
-       (let ((t (gnc:kvp-frame-get-slot-path f (append p '("type"))))
-	     (v (gnc:kvp-frame-get-slot-path f (append p '("value")))))
+       (let ((t (kvp-frame-get-slot-path-gslist f (append p '("type"))))
+	     (v (kvp-frame-get-slot-path-gslist f (append p '("value")))))
 	 (if (and t v (string? t))
 	     (set! value (cons (string->symbol t)
 			       (if (string? v) (string->symbol v) v))))))
@@ -613,11 +615,11 @@
   (define (convert-to-guid item)
     (if (string? item)
         item
-        (gnc:account-get-guid item)))
+        (gncAccountGetGUID item)))
 
   (define (convert-to-account item)
     (if (string? item)
-        (gnc:account-lookup item (gnc:get-current-book))
+        (xaccAccountLookup item (gnc-get-current-book))
         item))
 
   (let* ((option (map convert-to-guid (default-getter)))
@@ -637,11 +639,12 @@
     (gnc:make-option
      section name sort-tag 'account-list documentation-string getter
      (lambda (account-list)
-       (if (not account-list) (set! account-list (default-getter)))
+       (if (or (not account-list) (null? account-list)) 
+           (set! account-list (default-getter)))
        (set! account-list
              (filter (lambda (x) (if (string? x)
-                                     (gnc:account-lookup
-                                      x (gnc:get-current-book))
+                                     (xaccAccountLookup
+                                      x (gnc-get-current-book))
                                      x)) account-list))
        (let* ((result (validator account-list))
               (valid (car result))
@@ -657,20 +660,20 @@
        (define (save-acc list count)
 	 (if (not (null? list))
 	     (let ((key (string-append "acc" (gnc:value->string count))))
-	       (gnc:kvp-frame-set-slot-path f (car list) (append p (list key)))
+	       (kvp-frame-set-slot-path-gslist f (car list) (append p (list key)))
 	       (save-acc (cdr list) (+ 1 count)))))
 
        (if option-set
 	   (begin
-	     (gnc:kvp-frame-set-slot-path f (length option)
+	     (kvp-frame-set-slot-path-gslist f (length option)
 					  (append p '("len")))
 	     (save-acc option 0))))
      (lambda (f p)
-       (let ((len (gnc:kvp-frame-get-slot-path f (append p '("len")))))
+       (let ((len (kvp-frame-get-slot-path-gslist f (append p '("len")))))
 	 (define (load-acc count)
 	   (if (< count len)
 	       (let* ((key (string-append "acc" (gnc:value->string count)))
-		      (guid (gnc:kvp-frame-get-slot-path
+		      (guid (kvp-frame-get-slot-path-gslist
 			     f (append p (list key)))))
 		 (cons guid (load-acc (+ count 1))))
 	       '()))
@@ -715,26 +718,27 @@
   (define (convert-to-guid item)
     (if (string? item)
         item
-        (gnc:account-get-guid item)))
+        (gncAccountGetGUID item)))
 
   (define (convert-to-account item)
     (if (string? item)
-        (gnc:account-lookup item (gnc:get-current-book))
+        (xaccAccountLookup item (gnc-get-current-book))
         item))
 
   (define (find-first-account)
     (define (find-first account-list)
       (if (null? account-list)
-	  #f
+	  '()
 	  (let* ((this-account (car account-list))
-		 (account-type (gw:enum-<gnc:AccountType>-val->sym
-				(gnc:account-get-type this-account) #f)))
-	    (if (if (null? acct-type-list) #t (member account-type acct-type-list))
+		 (account-type (xaccAccountGetType this-account)))
+	    (if (if (null? acct-type-list)
+                    #t
+                    (member account-type acct-type-list))
 		this-account
 		(find-first (cdr account-list))))))
 
-    (let* ((current-group (gnc:get-current-group))
-	   (account-list (gnc:group-get-subaccounts current-group)))
+    (let* ((current-root (gnc-get-current-root-account))
+	   (account-list (gnc-account-get-descendants-sorted current-root)))
       (find-first account-list)))
 	   
   (define (get-default)
@@ -759,7 +763,7 @@
     (gnc:make-option
      section name sort-tag 'account-sel documentation-string getter
      (lambda (account)
-       (if (not account) (set! account (get-default)))
+       (if (or (not account) (null? account)) (set! account (get-default)))
        (set! account (convert-to-account account))
        (let* ((result (validator account))
 	      (valid (car result))
@@ -771,9 +775,9 @@
 	     (gnc:error "Illegal account value set"))))
      (lambda () (convert-to-account (get-default)))
      (gnc:restore-form-generator value->string)
-     (lambda (f p) (gnc:kvp-frame-set-slot-path f value p))
+     (lambda (f p) (kvp-frame-set-slot-path-gslist f value p))
      (lambda (f p)
-       (let ((v (gnc:kvp-frame-get-slot-path f p)))
+       (let ((v (kvp-frame-get-slot-path-gslist f p)))
 	 (if (and v (string? v))
 	     (set! value v))))
      validator
@@ -850,9 +854,9 @@
            (gnc:error "Illegal Multichoice option set")))
      (lambda () default-value)
      (gnc:restore-form-generator value->string)
-     (lambda (f p) (gnc:kvp-frame-set-slot-path f (symbol->string value) p))
+     (lambda (f p) (kvp-frame-set-slot-path-gslist f (symbol->string value) p))
      (lambda (f p)
-       (let ((v (gnc:kvp-frame-get-slot-path f p)))
+       (let ((v (kvp-frame-get-slot-path-gslist f p)))
 	 (if (and v (string? v))
 	     (set! value (string->symbol v)))))
      (lambda (x)
@@ -936,9 +940,9 @@
            (gnc:error "Illegal Radiobutton option set")))
      (lambda () default-value)
      (gnc:restore-form-generator value->string)
-     (lambda (f p) (gnc:kvp-frame-set-slot-path f (symbol->string value) p))
+     (lambda (f p) (kvp-frame-set-slot-path-gslist f (symbol->string value) p))
      (lambda (f p)
-       (let ((v (gnc:kvp-frame-get-slot-path f p)))
+       (let ((v (kvp-frame-get-slot-path-gslist f p)))
 	 (if (and v (string? v))
 	     (set! value (string->symbol v)))))
      (lambda (x)
@@ -1002,16 +1006,16 @@
        (define (save-item list count)
 	 (if (not (null? list))
 	     (let ((key (string-append "item" (gnc:value->string count))))
-	       (gnc:kvp-frame-set-slot-path f (car list) (append p (list key)))
+	       (kvp-frame-set-slot-path-gslist f (car list) (append p (list key)))
 	       (save-item (cdr list) (+ 1 count)))))
-       (gnc:kvp-frame-set-slot-path f (length value) (append p '("len")))
+       (kvp-frame-set-slot-path-gslist f (length value) (append p '("len")))
        (save-item value 0))
      (lambda (f p)
-       (let ((len (gnc:kvp-frame-get-slot-path f (append p '("len")))))
+       (let ((len (kvp-frame-get-slot-path-gslist f (append p '("len")))))
 	 (define (load-item count)
 	   (if (< count len)
 	       (let* ((key (string-append "item" (gnc:value->string count)))
-		      (val (gnc:kvp-frame-get-slot-path
+		      (val (kvp-frame-get-slot-path-gslist
 			    f (append p (list key)))))
 		 (cons val (load-item (+ count 1))))
 	       '()))
@@ -1050,9 +1054,9 @@
      (lambda (x) (set! value x))
      (lambda () default-value)
      (gnc:restore-form-generator value->string)
-     (lambda (f p) (gnc:kvp-frame-set-slot-path f (symbol->string value) p))
+     (lambda (f p) (kvp-frame-set-slot-path-gslist f (symbol->string value) p))
      (lambda (f p)
-       (let ((v (gnc:kvp-frame-get-slot-path f p)))
+       (let ((v (kvp-frame-get-slot-path-gslist f p)))
 	 (if (and v (number? v))
 	     (set! value v))))
      (lambda (x)
@@ -1089,16 +1093,16 @@
          default-value)
   (let* ((value (if (list? default-value)
                     default-value
-                    (gnc:query->scm default-value)))
+                    (gnc-query2scm default-value)))
          (value->string (lambda ()
                           (string-append "'" (gnc:value->string value)))))
     (gnc:make-option
      section name "" 'query #f
      (lambda () value)
-     (lambda (x) (set! value (if (list? x) x (gnc:query->scm x))))
+     (lambda (x) (set! value (if (list? x) x (gnc-query2scm x))))
      (lambda () (if (list? default-value)
                     default-value
-                    (gnc:query->scm default-value)))
+                    (gnc-query2scm default-value)))
      (gnc:restore-form-generator value->string)
      #f
      #f
@@ -1210,18 +1214,18 @@
      (lambda () (def-value))
      (gnc:restore-form-generator value->string)
      (lambda (f p)
-       (gnc:kvp-frame-set-slot-path
+       (kvp-frame-set-slot-path-gslist
 	f (symbol->string (car value)) (append p '("fmt")))
-       (gnc:kvp-frame-set-slot-path
+       (kvp-frame-set-slot-path-gslist
 	f (symbol->string (cadr value)) (append p '("month")))
-       (gnc:kvp-frame-set-slot-path
+       (kvp-frame-set-slot-path-gslist
 	f (if (caddr value) 1 0) (append p '("years")))
-       (gnc:kvp-frame-set-slot-path f (cadddr value) (append p '("custom"))))
+       (kvp-frame-set-slot-path-gslist f (cadddr value) (append p '("custom"))))
      (lambda (f p)
-       (let ((fmt (gnc:kvp-frame-get-slot-path f (append p '("fmt"))))
-	     (month (gnc:kvp-frame-get-slot-path f (append p '("month"))))
-	     (years (gnc:kvp-frame-get-slot-path f (append p '("years"))))
-	     (custom (gnc:kvp-frame-get-slot-path f (append p '("custom")))))
+       (let ((fmt (kvp-frame-get-slot-path-gslist f (append p '("fmt"))))
+	     (month (kvp-frame-get-slot-path-gslist f (append p '("month"))))
+	     (years (kvp-frame-get-slot-path-gslist f (append p '("years"))))
+	     (custom (kvp-frame-get-slot-path-gslist f (append p '("custom")))))
 	 (if (and
 	      fmt (string? fmt)
 	      month (string? month)
@@ -1447,7 +1451,7 @@
   ((options 'register-callback) section name callback))
 
 (define (gnc:options-register-c-callback section name c-callback data options)
-  (let ((callback (lambda () (gnc:option-invoke-callback c-callback data))))
+  (let ((callback (lambda () (gncp-option-invoke-callback c-callback data))))
     ((options 'register-callback) section name callback)))
 
 (define (gnc:options-unregister-callback-id id options)
@@ -1467,7 +1471,7 @@
 
 (define (gnc:options-scm->kvp options kvp-frame key-path clear-kvp?)
   (if clear-kvp?
-      (gnc:kvp-frame-delete-at-path kvp-frame key-path))
+      (gnc-kvp-frame-delete-at-path kvp-frame key-path))
   ((options 'scm->kvp) kvp-frame key-path))
 
 (define (gnc:options-kvp->scm options kvp-frame key-path)
@@ -1507,7 +1511,7 @@
 (define (gnc:send-options db_handle options)
   (gnc:options-for-each
    (lambda (option)
-     (gnc:option-db-register-option db_handle option))
+     (gnc-option-db-register-option db_handle option))
    options))
 
 (define (gnc:save-options options options-string file header truncate?)
