@@ -22,20 +22,15 @@
 #include "config.h"
 
 #include <glib.h>
-#include <stdio.h>
+#include <glib/gstdio.h>
 #include <fcntl.h>
 #include <string.h>
 #include <unistd.h>
 #include <zlib.h>
 #include <errno.h>
-#ifdef HAVE_SYS_WAIT_H
-# include <sys/wait.h>
-#endif
 
 #include "gnc-engine.h"
 #include "gnc-pricedb-p.h"
-#include "Group.h"
-#include "GroupP.h"
 #include "Scrub.h"
 #include "SX-book.h"
 #include "SX-book-p.h"
@@ -54,7 +49,16 @@
 
 static QofLogModule log_module = GNC_MOD_IO;
 
-static pid_t gzip_child_pid = 0;
+/* map pointers, e.g. of type FILE*, to GThreads */
+static GHashTable *threads = NULL;
+G_LOCK_DEFINE_STATIC(threads);
+
+typedef struct {
+  gint fd;
+  gchar *filename;
+  gchar *perms;
+  gboolean compress;
+} gz_thread_params_t;
 
 /* Callback structure */
 struct file_backend {
@@ -163,6 +167,8 @@ static gboolean
 add_account_local(sixtp_gdv2 *data, Account *act)
 {
     gnc_commodity_table *table;
+    Account *parent, *root;
+    int type;
 
     table = gnc_book_get_commodity_table (data->book);
 
@@ -180,10 +186,20 @@ add_account_local(sixtp_gdv2 *data, Account *act)
     xaccAccountScrubCommodity (act);
     xaccAccountScrubKvp (act);
 
-    if(!xaccAccountGetParent(act))
-    {
-        xaccGroupInsertAccount(gnc_book_get_group(data->book), act);
+    /* Backwards compatability.  If there's no parent, see if this
+     * account is of type ROOT.  If not, find or create a ROOT
+     * account and make that the parent. */
+    type = xaccAccountGetType(act);
+    if (type == ACCT_TYPE_ROOT) {
+      gnc_book_set_root_account(data->book, act);
+    } else {
+      parent = gnc_account_get_parent(act);
+      if (parent == NULL) {
+	root = gnc_book_get_root_account(data->book);
+	gnc_account_append_child(root, act);
+      }
     }
+
     data->counter.accounts_loaded++;
     run_callback(data, "account");
 
@@ -218,8 +234,6 @@ static gboolean
 add_transaction_local(sixtp_gdv2 *data, Transaction *trn)
 {
     gnc_commodity_table *table;
-    Split *spl;
-    int i;
     
     table = gnc_book_get_commodity_table (data->book);
 
@@ -229,13 +243,6 @@ add_transaction_local(sixtp_gdv2 *data, Transaction *trn)
                                    xaccTransSetCurrency);
 
     xaccTransScrubCurrency (trn);
-
-    for(i = 0, spl = xaccTransGetSplit(trn, i);
-        spl;
-        i++, spl = xaccTransGetSplit(trn, i))
-    {
-        xaccAccountInsertSplit(xaccSplitGetAccount(spl), spl);
-    }
     xaccTransCommitEdit (trn);
 
     data->counter.transactions_loaded++;
@@ -246,16 +253,12 @@ add_transaction_local(sixtp_gdv2 *data, Transaction *trn)
 static gboolean
 add_schedXaction_local(sixtp_gdv2 *data, SchedXaction *sx)
 {
-    GList *list;
-
-    list = gnc_book_get_schedxactions (data->book);
-    list = g_list_append(list, sx);
-
-    gnc_book_set_schedxactions(data->book, list);
-    data->counter.schedXactions_loaded++;
-    run_callback(data, "schedXactions");
-
-    return TRUE;
+     SchedXactions *sxes;
+     sxes = gnc_book_get_schedxactions(data->book);
+     gnc_sxes_add_sx(sxes, sx);
+     data->counter.schedXactions_loaded++;
+     run_callback(data, "schedXactions");
+     return TRUE;
 }
 
 static gboolean
@@ -264,7 +267,7 @@ add_template_transaction_local( sixtp_gdv2 *data,
 {
     GList *n;
     Account *tmpAcct;
-    AccountGroup *acctGroup = NULL;
+    Account *acctRoot = NULL;
     QofBook *book;
 
     book = data->book;
@@ -273,22 +276,20 @@ add_template_transaction_local( sixtp_gdv2 *data,
     /* . template accounts. */
     /* . transactions in those accounts. */
     for ( n = txd->accts; n; n = n->next ) {
-        if ( xaccAccountGetParent( (Account*)n->data ) == NULL ) {
+        if ( gnc_account_get_parent( (Account*)n->data ) == NULL ) {
             /* remove the gnc_book_init-created account of the same name */
-            acctGroup =
-            gnc_book_get_template_group(book);
-            tmpAcct =
-            xaccGetAccountFromName( acctGroup,
+            acctRoot = gnc_book_get_template_root(book);
+            tmpAcct = gnc_account_lookup_by_name( acctRoot,
                                     xaccAccountGetName( (Account*)n->data ) );
             if ( tmpAcct != NULL ) {
 /* XXX hack alert FIXME .... Should this be 'Remove', or 'Destroy'?
  * If we just remove, then this seems to be a memory leak to me, since
  * it is never reparented.  Shouldn't it be a Destroy ???
  */
-                xaccGroupRemoveAccount( acctGroup, tmpAcct );
+                gnc_account_remove_child( acctRoot, tmpAcct );
             }
 
-            xaccGroupInsertAccount( acctGroup, (Account*)n->data );
+            gnc_account_append_child( acctRoot, (Account*)n->data );
         }
 
     }
@@ -298,8 +299,6 @@ add_template_transaction_local( sixtp_gdv2 *data,
         add_transaction_local( data, (Transaction*)n->data );
     }
 
-    xaccAccountGroupCommitEdit (acctGroup);
-
     return TRUE;
 }
 
@@ -423,20 +422,20 @@ gnc_counter_sixtp_parser_create(void)
 }
 
 static void
-print_counter_data(load_counter *data)
+debug_print_counter_data(load_counter *data)
 {
-    PINFO("Transactions: Total: %d, Loaded: %d",
-           data->transactions_total, data->transactions_loaded);
-    PINFO("Accounts: Total: %d, Loaded: %d",
-           data->accounts_total, data->accounts_loaded);
-    PINFO("Books: Total: %d, Loaded: %d",
-           data->books_total, data->books_loaded);
-    PINFO("Commodities: Total: %d, Loaded: %d",
-           data->commodities_total, data->commodities_loaded);
-    PINFO("Scheduled Tansactions: Total: %d, Loaded: %d",
-           data->schedXactions_total, data->schedXactions_loaded);
-    PINFO("Budgets: Total: %d, Loaded: %d",
-	  data->budgets_total, data->budgets_loaded);
+    DEBUG("Transactions: Total: %d, Loaded: %d",
+          data->transactions_total, data->transactions_loaded);
+    DEBUG("Accounts: Total: %d, Loaded: %d",
+          data->accounts_total, data->accounts_loaded);
+    DEBUG("Books: Total: %d, Loaded: %d",
+          data->books_total, data->books_loaded);
+    DEBUG("Commodities: Total: %d, Loaded: %d",
+          data->commodities_total, data->commodities_loaded);
+    DEBUG("Scheduled Transactions: Total: %d, Loaded: %d",
+          data->schedXactions_total, data->schedXactions_loaded);
+    DEBUG("Budgets: Total: %d, Loaded: %d",
+          data->budgets_total, data->budgets_loaded);
 }
 
 static void
@@ -471,7 +470,7 @@ file_rw_feedback (sixtp_gdv2 *gd, const char *type)
 //             counter->books_total, counter->books_loaded);
 //      printf("Commodities: Total: %d, Loaded: %d\n",
 //             counter->commodities_total, counter->commodities_loaded);
-//      printf("Scheduled Tansactions: Total: %d, Loaded: %d\n",
+//      printf("Scheduled Transactions: Total: %d, Loaded: %d\n",
 //             counter->schedXactions_total, counter->schedXactions_loaded);
 //      printf("Budgets: Total: %d, Loaded: %d\n",
 //	     counter->budgets_total, counter->budgets_loaded);
@@ -651,7 +650,7 @@ qof_session_load_from_xml_file_v2_full(
     FileBackend *fbe, QofBook *book,
     sixtp_push_handler push_handler, gpointer push_user_data)
 {
-    AccountGroup *grp;
+    Account *root;
     QofBackend *be = &fbe->be;
     sixtp_gdv2 *gd;
     sixtp *top_parser;
@@ -741,7 +740,7 @@ qof_session_load_from_xml_file_v2_full(
         xaccEnableDataScrubbing();
         goto bail;
     }
-    DEBUGCMD (print_counter_data(&gd->counter));
+    debug_print_counter_data(&gd->counter);
 
     /* destroy the parser */
     sixtp_destroy (top_parser);
@@ -758,19 +757,21 @@ qof_session_load_from_xml_file_v2_full(
     qof_object_foreach_backend (GNC_FILE_BACKEND, scrub_cb, &be_data);
 
     /* fix price quote sources */
-    grp = gnc_book_get_group(book);
-    xaccGroupScrubQuoteSources (grp, gnc_book_get_commodity_table(book));
+    root = gnc_book_get_root_account(book);
+    xaccAccountTreeScrubQuoteSources (root, gnc_book_get_commodity_table(book));
 
     /* Fix account and transaction commodities */
-    xaccGroupScrubCommodities (grp);
+    xaccAccountTreeScrubCommodities (root);
 
     /* Fix split amount/value */
-    xaccGroupScrubSplits (grp);
+    xaccAccountTreeScrubSplits (root);
 
     /* commit all groups, this completes the BeginEdit started when the
      * account_end_handler finished reading the account.
      */
-    xaccAccountGroupCommitEdit (grp);
+    gnc_account_foreach_descendant(root,
+				   (AccountCb) xaccAccountCommitEdit,
+				   NULL);
 
     /* start logging again */
     xaccLogEnable ();
@@ -859,7 +860,7 @@ static void write_pricedb (FILE *out, QofBook *book, sixtp_gdv2 *gd);
 static void write_transactions (FILE *out, QofBook *book, sixtp_gdv2 *gd);
 static void write_template_transaction_data (FILE *out, QofBook *book, sixtp_gdv2 *gd);
 static void write_schedXactions(FILE *out, QofBook *book, sixtp_gdv2 *gd);
-static void write_budget (QofEntity *ent, gpointer data);
+static void write_budget (QofInstance *ent, gpointer data);
 
 static void
 write_counts_cb (const char *type, gpointer data_p, gpointer be_data_p)
@@ -937,11 +938,11 @@ write_book(FILE *out, QofBook *book, sixtp_gdv2 *gd)
                  gnc_commodity_table_get_size(
                      gnc_book_get_commodity_table(book)),
                  "account",
-                 1 + xaccGroupGetNumSubAccounts(gnc_book_get_group(book)),
+                 1 + gnc_account_n_descendants(gnc_book_get_root_account(book)),
                  "transaction",
                  gnc_book_count_transactions(book),
                  "schedxaction",
-                 g_list_length( gnc_book_get_schedxactions(book) ),
+                 g_list_length(gnc_book_get_schedxactions(book)->sx_list),
 		 "budget", qof_collection_count(
                      qof_book_get_collection(book, GNC_ID_BUDGET)),
 		 NULL);
@@ -1049,26 +1050,26 @@ write_transactions(FILE *out, QofBook *book, sixtp_gdv2 *gd)
 
     be_data.out = out;
     be_data.gd = gd;
-    xaccGroupForEachTransaction(gnc_book_get_group(book),
-                                xml_add_trn_data,
-                                (gpointer) &be_data);
+    xaccAccountTreeForEachTransaction(gnc_book_get_root_account(book),
+				      xml_add_trn_data,
+				      (gpointer) &be_data);
 }
 
 static void
 write_template_transaction_data( FILE *out, QofBook *book, sixtp_gdv2 *gd )
 {
-    AccountGroup *ag;
+    Account *ra;
     struct file_backend be_data;
 
     be_data.out = out;
     be_data.gd = gd;
 
-    ag = gnc_book_get_template_group(book);
-    if ( xaccGroupGetNumSubAccounts(ag) > 0 )
+    ra = gnc_book_get_template_root(book);
+    if ( gnc_account_n_descendants(ra) > 0 )
     {
         fprintf( out, "<%s>\n", TEMPLATE_TRANSACTION_TAG );
-        write_account_group( out, ag, gd );
-        xaccGroupForEachTransaction( ag, xml_add_trn_data, (gpointer)&be_data );
+        write_account_tree( out, ra, gd );
+        xaccAccountTreeForEachTransaction( ra, xml_add_trn_data, (gpointer)&be_data );
         fprintf( out, "</%s>\n", TEMPLATE_TRANSACTION_TAG );
     }
 }
@@ -1076,29 +1077,28 @@ write_template_transaction_data( FILE *out, QofBook *book, sixtp_gdv2 *gd )
 static void
 write_schedXactions( FILE *out, QofBook *book, sixtp_gdv2 *gd)
 {
-    GList *schedXactions;
-    SchedXaction *tmpSX;
-    xmlNodePtr node;
+     GList *schedXactions;
+     SchedXaction *tmpSX;
+     xmlNodePtr node;
+     
+     schedXactions = gnc_book_get_schedxactions(book)->sx_list;
 
-    /* get list of scheduled transactions from QofBook */
-    schedXactions = gnc_book_get_schedxactions( book );
+     if ( schedXactions == NULL )
+          return;
 
-    if ( schedXactions == NULL )
-        return;
-
-    do {
-        tmpSX = schedXactions->data;
-        node = gnc_schedXaction_dom_tree_create( tmpSX );
-        xmlElemDump( out, NULL, node );
-        fprintf( out, "\n" );
-        xmlFreeNode( node );
-        gd->counter.schedXactions_loaded++;
-        run_callback(gd, "schedXactions");
-    } while ( (schedXactions = schedXactions->next) );
+     do {
+          tmpSX = schedXactions->data;
+          node = gnc_schedXaction_dom_tree_create( tmpSX );
+          xmlElemDump( out, NULL, node );
+          fprintf( out, "\n" );
+          xmlFreeNode( node );
+          gd->counter.schedXactions_loaded++;
+          run_callback(gd, "schedXactions");
+     } while ( (schedXactions = schedXactions->next) );
 }
 
 static void
-write_budget (QofEntity *ent, gpointer data)
+write_budget (QofInstance *ent, gpointer data)
 {
     xmlNodePtr node;
     struct file_backend* be = data;
@@ -1181,10 +1181,10 @@ gnc_book_write_to_xml_filehandle_v2(QofBook *book, FILE *out)
     gd->counter.commodities_total =
       gnc_commodity_table_get_size(gnc_book_get_commodity_table(book));
     gd->counter.accounts_total = 1 + 
-      xaccGroupGetNumSubAccounts(gnc_book_get_group(book));
+      gnc_account_n_descendants(gnc_book_get_root_account(book));
     gd->counter.transactions_total = gnc_book_count_transactions(book);
     gd->counter.schedXactions_total =
-      g_list_length( gnc_book_get_schedxactions(book));
+      g_list_length(gnc_book_get_schedxactions(book)->sx_list);
     gd->counter.budgets_total = qof_collection_count(
         qof_book_get_collection(book, GNC_ID_BUDGET));
 
@@ -1203,14 +1203,14 @@ gboolean
 gnc_book_write_accounts_to_xml_filehandle_v2(QofBackend *be, QofBook *book, FILE *out)
 {
     gnc_commodity_table *table;
-    AccountGroup *grp;
+    Account *root;
     int ncom, nacc;
     sixtp_gdv2 *gd;
 
     if (!out) return FALSE;
 
-    grp = gnc_book_get_group(book);
-    nacc = 1 + xaccGroupGetNumSubAccounts(grp);
+    root = gnc_book_get_root_account(book);
+    nacc = 1 + gnc_account_n_descendants(root);
 
     table = gnc_book_get_commodity_table(book);
     ncom = gnc_commodity_table_get_size(table);
@@ -1238,6 +1238,64 @@ gnc_book_write_accounts_to_xml_filehandle_v2(QofBackend *be, QofBook *book, FILE
 
 #define BUFLEN 4096
 
+/* Compress or decompress function that is to be run in a separate thread.
+ * Returns 1 on success or 0 otherwise, stuffed into a pointer type. */
+static gpointer
+gz_thread_func(gz_thread_params_t *params)
+{
+    gchar buffer[BUFLEN];
+    guint bytes;
+    gssize written;
+    gzFile *file;
+    gint success = 0;
+
+#ifdef G_OS_WIN32
+    {
+        gchar *conv_name = g_win32_locale_filename_from_utf8(params->filename);
+        gchar *perms;
+
+        if (!conv_name) {
+            g_warning("Could not convert '%s' to system codepage",
+                      params->filename);
+            goto cleanup_gz_thread_func;
+        }
+
+        if (strchr(params->perms, 'b'))
+            perms = g_strdup(params->perms);
+        else
+            perms = g_strdup_printf("%cb%s", *params->perms, params->perms + 1);
+
+        file = gzopen(conv_name, perms);
+        g_free(perms);
+        g_free(conv_name);
+    }
+#else /* !G_OS_WIN32 */
+    file = gzopen(params->filename, params->perms);
+#endif /* G_OS_WIN32 */
+
+    if (file == NULL) {
+        g_warning("Child threads gzopen failed");
+        goto cleanup_gz_thread_func;
+    }
+
+    if (params->compress)
+        while ((bytes = read(params->fd, buffer, BUFLEN)) > 0)
+            gzwrite(file, buffer, bytes);
+    else
+        while ((bytes = gzread(file, buffer, BUFLEN)) > 0)
+            written = write(params->fd, buffer, bytes);
+
+    gzclose(file);
+    success = 1;
+
+cleanup_gz_thread_func:
+    g_free(params->filename);
+    g_free(params->perms);
+    g_free(params);
+
+    return GINT_TO_POINTER(success);
+}
+
 static FILE *
 try_gz_open (const char *filename, const char *perms, gboolean use_gzip,
              gboolean compress)
@@ -1246,128 +1304,72 @@ try_gz_open (const char *filename, const char *perms, gboolean use_gzip,
       use_gzip = TRUE;
 
   if (!use_gzip)
-    return fopen(filename, perms);
+    return g_fopen(filename, perms);
 
-#ifdef _WIN32
-  PWARN("Compression not implemented on Windows. Opening uncompressed file.");
-  return fopen(filename, perms);
-
-  /* Potential implementation: Windows doesn't have pipe(); use
-     the g_spawn glib wrappers. */
   {
-    /* Start gzip from a command line, not by fork(). */
-    gchar *argv[] = {compress ? "gzip" : "gunzip",
-                     NULL};
-    GPid child_pid;
-    GError *error;
-    int child_stdin;
-
-    g_assert_not_reached(); /* Not yet correctly implemented. */
-
-    if ( !g_spawn_async_with_pipes(NULL, argv,
-				   NULL, G_SPAWN_SEARCH_PATH,
-				   NULL, NULL, 
-				   &child_pid,
-				   &child_stdin, NULL, NULL,
-				   &error) ) {
-      PWARN("G_spawn call failed. Opening uncompressed file.");
-      return fopen(filename, perms);
-    }
-    /* FIXME: Now need to set up the child process to write to the
-       file. */
-
-    return fdopen(child_stdin, compress ? "w" : "r");
-
-    /* Eventually the GPid must be cleanup up, but not here? */
-    /* g_spawn_close_pid(child_pid); */
-  }
-#else
-  {
-    /* Normal Posix platform (non-windows) */
     int filedes[2];
-    pid_t pid;
-
-    /* avoid reading from file that is still being written to
-       by a child process */
-    g_assert(gzip_child_pid == 0);
+    GThread *thread;
+    GError *error = NULL;
+    gz_thread_params_t *params;
+    FILE *file;
 
     if (pipe(filedes) < 0) {
-      PWARN("Pipe call failed. Opening uncompressed file.");
-      return fopen(filename, perms);
+      g_warning("Pipe call failed. Opening uncompressed file.");
+      return g_fopen(filename, perms);
     }
 
-    pid = fork();
-    switch (pid) {
-    case -1:
-      PWARN("Fork call failed. Opening uncompressed file.");
-      return fopen(filename, perms);
+    params = g_new(gz_thread_params_t, 1);
+    params->fd = filedes[compress ? 0 : 1];
+    params->filename = g_strdup(filename);
+    params->perms = g_strdup(perms);
+    params->compress = compress;
 
-    case 0: /* child */ {
-      char buffer[BUFLEN];
-      unsigned bytes;
-      ssize_t written;
-      gzFile *file;
+    thread = g_thread_create((GThreadFunc) gz_thread_func, params, TRUE, &error);
+    if (!thread) {
+      g_warning("Could not create thread for (de)compression: %s",
+                error->message);
+      g_error_free(error);
+      g_free(params->filename);
+      g_free(params->perms);
+      g_free(params);
+      close(filedes[0]);
+      close(filedes[1]);
 
-      file = gzopen(filename, perms);
-      if (file == NULL) {
-        PWARN("child gzopen failed\n");
-        exit(0);
-      }
-      if (compress) {
-        close(filedes[1]);
-        while ((bytes = read(filedes[0], buffer, BUFLEN)) > 0)
-          gzwrite(file, buffer, bytes);
-      }
-      else
-      {
-        close(filedes[0]);
-        while ((bytes = gzread(file, buffer, BUFLEN)) > 0)
-          written = write(filedes[1], buffer, bytes);
-      }
-      gzclose(file);
-      _exit(0);
+      return g_fopen(filename, perms);
     }
 
-    default: /* parent */
-      if (compress) {
-        /* the calling code must wait_for_gzip() */
-        gzip_child_pid = pid;
-      }
-      sleep(2);
-      if (compress) {
-        close(filedes[0]);
-        return fdopen(filedes[1], "w");
-      }
-      else
-      {
-        close(filedes[1]);
-        return fdopen(filedes[0], "r");
-      }
-    }
+    if (compress)
+      file = fdopen(filedes[1], "w");
+    else
+      file = fdopen(filedes[0], "r");
+
+    G_LOCK(threads);
+    if (!threads)
+      threads = g_hash_table_new(g_direct_hash, g_direct_equal);
+
+    g_hash_table_insert(threads, file, thread);
+    G_UNLOCK(threads);
+
+    return file;
   }
-#endif
 }
 
 static gboolean
-wait_for_gzip()
+wait_for_gzip(FILE *file)
 {
-    pid_t retval;
+    gboolean retval = TRUE;
 
-    if (gzip_child_pid == 0)
-        return TRUE;
+    G_LOCK(threads);
+    if (threads) {
+        GThread *thread = g_hash_table_lookup(threads, file);
+        if (thread) {
+            g_hash_table_remove(threads, file);
+            retval = GPOINTER_TO_INT(g_thread_join(thread));
+        }
+    }
+    G_UNLOCK(threads);
 
-#ifdef HAVE_SYS_WAIT_H
-    retval = waitpid(gzip_child_pid, NULL, WUNTRACED);
-#else
-    /* FIXME: Windows doesn't have waitpid. According to glib's
-       g_spawn_async_with_pipes(), we should use one of the
-       g_spawn functions and some Win32-API WaitFor*() function
-       here. For now, we ignore that race condition. */
-    retval = 1;
-#endif
-    gzip_child_pid = 0;
-
-    return retval != -1;
+    return retval;
 }
 
 gboolean
@@ -1394,7 +1396,7 @@ gnc_book_write_to_xml_file_v2(
     }
 
     if (compress)
-        return wait_for_gzip();
+        return wait_for_gzip(out);
 
     return TRUE;
 }
@@ -1412,7 +1414,7 @@ gnc_book_write_accounts_to_xml_file_v2(
 {
     FILE *out;
 
-    out = fopen(filename, "w");
+    out = g_fopen(filename, "w");
     if (out == NULL)
     {
         return FALSE;
@@ -1435,7 +1437,7 @@ static gboolean
 is_gzipped_file(const gchar *name)
 {
     unsigned char buf[2];
-    int fd = open(name, O_RDONLY);
+    int fd = g_open(name, O_RDONLY, 0);
 
     if (fd == -1) {
         return FALSE;
@@ -1465,7 +1467,19 @@ gnc_is_xml_data_file_v2(const gchar *name, gboolean *with_encoding)
         char first_chunk[256];
         int num_read;
 
+#ifdef G_OS_WIN32
+        {
+            gchar *conv_name = g_win32_locale_filename_from_utf8(name);
+            if (!conv_name)
+                g_warning("Could not convert '%s' to system codepage", name);
+            else {
+                file = gzopen(conv_name, "rb");
+                g_free(conv_name);
+            }
+        }
+#else
         file = gzopen(name, "r");
+#endif
         if (file == NULL)
             return FALSE;
 
@@ -1710,8 +1724,11 @@ gnc_xml2_find_ambiguous(const gchar *filename, GList *encodings,
         g_hash_table_destroy(processed);
     if (ascii)
         g_free(ascii);
-    if (file)
+    if (file) {
         fclose(file);
+        if (is_compressed)
+            wait_for_gzip(file);
+    }
 
     return (clean_return) ? n_impossible : -1;
 }
@@ -1827,8 +1844,11 @@ parse_with_subst_push_handler (xmlParserCtxtPtr xml_context,
         g_string_free(output, TRUE);
     if (ascii != (GIConv) -1)
         g_iconv_close(ascii);
-    if (file)
+    if (file) {
         fclose(file);
+        if (is_compressed)
+            wait_for_gzip(file);
+    }
 }
 
 gboolean
