@@ -21,6 +21,7 @@
  *  02110-1301, USA.
  */
  
+#include "config.h"
 #include <glib.h>
 #include <libguile.h>
 #include <string.h>
@@ -44,11 +45,11 @@
 static const gchar *da_ending = ".gnucash-xea";
 
 static void
-test_load_file(QofBook *book, const char *filename)
+test_load_file(const char *filename)
 {
     GncExampleAccount *gea;
 
-    gea = gnc_read_example_account(book, filename);
+    gea = gnc_read_example_account(filename);
 
     if(gea != NULL)
     {
@@ -65,10 +66,9 @@ test_load_file(QofBook *book, const char *filename)
 static void
 guile_main (void *closure, int argc, char **argv)
 {
-    const char *location = getenv("GNC_ACCOUNT_PATH");
+    const char *location = g_getenv("GNC_ACCOUNT_PATH");
     GSList *list = NULL;
-    DIR *ea_dir;
-    QofBook *book;
+    GDir *ea_dir;
 
     if (!location)
     {
@@ -78,42 +78,31 @@ guile_main (void *closure, int argc, char **argv)
     gnc_module_system_init();
     gnc_module_load("gnucash/engine", 0);
 
-    book = qof_book_new ();
-
-    if((ea_dir = opendir(location)) == NULL)
+    if((ea_dir = g_dir_open(location, 0, NULL)) == NULL)
     {
         failure("unable to open ea directory");
     }
     else
     {
-        struct dirent *entry;
+        const gchar *entry;
 
-        while((entry = readdir(ea_dir)) != NULL)
+        while((entry = g_dir_read_name(ea_dir)) != NULL)
         {
-            struct stat file_info;
-            if(strstr(entry->d_name, da_ending) != NULL)
+            if(g_str_has_suffix(entry, da_ending))
             {
-                char *to_open = g_strdup_printf("%s/%s", location,
-                                                entry->d_name);
-                if(stat(to_open, &file_info) != 0)
+                gchar *to_open = g_build_filename(location, entry, (gchar*)NULL);
+                if (!g_file_test(to_open, G_FILE_TEST_IS_DIR))
                 {
-                    failure("unable to stat file");
-                }
-                else
-                {
-                    if(!S_ISDIR(file_info.st_mode))
-                    {
-                        test_load_file(book, to_open);
-                    }
+                    test_load_file(to_open);
                 }
                 g_free(to_open);
             }
         }
     }
-    closedir(ea_dir);
+    g_dir_close(ea_dir);
     
     {
-        list = gnc_load_example_account_list(book, location);
+        list = gnc_load_example_account_list(location);
 
         do_test(list != NULL, "gnc_load_example_account_list");
         
@@ -129,5 +118,5 @@ int
 main (int argc, char ** argv)
 {
   scm_boot_guile (argc, argv, guile_main, NULL);
-  return 0;
+  exit(get_rv());
 }
