@@ -27,8 +27,8 @@
 
 #include <gnome.h>
 #include <glib/gi18n.h>
-#include <g-wrap-wct.h>
 #include <libguile.h>
+#include "swig-runtime.h"
 
 #include "gncObject.h"
 #include "QueryCore.h"
@@ -38,7 +38,6 @@
 #include "gnc-component-manager.h"
 #include "gnc-ui.h"
 #include "gnc-gconf-utils.h"
-#include "gnc-gkeyfile-utils.h"
 #include "gnc-gui-query.h"
 #include "gnc-ui-util.h"
 #include "qof.h"
@@ -54,10 +53,6 @@
 
 #include "gncEntryLedger.h"
 
-#ifndef HAVE_GLIB26
-#include "gkeyfile.h"
-#endif
-
 #include "gnc-plugin-page.h"
 #include "gnc-general-search.h"
 #include "dialog-date-close.h"
@@ -570,7 +565,7 @@ gnc_invoice_window_printCB (GtkWidget *widget, gpointer data)
   func = scm_c_eval_string ("gnc:invoice-report-create");
   g_return_if_fail (SCM_PROCEDUREP (func));
 
-  arg = gw_wcp_assimilate_ptr (invoice, scm_c_eval_string("<gnc:GncInvoice*>"));
+  arg = SWIG_NewPointerObj(invoice, SWIG_TypeQuery("_p__gncInvoice"), 0);
   args = scm_cons (arg, args);
 
   /* scm_gc_protect_object(func); */
@@ -735,7 +730,6 @@ void gnc_invoice_window_new_invoice_cb (GtkWidget *widget, gpointer data)
 void gnc_business_call_owner_report (GncOwner *owner, Account *acc)
 {
   int id;
-  SCM qtype;
   SCM args;
   SCM func;
   SCM arg;
@@ -748,20 +742,17 @@ void gnc_business_call_owner_report (GncOwner *owner, Account *acc)
   g_return_if_fail (SCM_PROCEDUREP (func));
 
   if (acc) {
-    qtype = scm_c_eval_string("<gnc:Account*>");
-    g_return_if_fail (qtype != SCM_UNDEFINED);
+    swig_type_info * qtype = SWIG_TypeQuery("_p_Account");
+    g_return_if_fail (qtype);
 
-    arg = gw_wcp_assimilate_ptr (acc, qtype);
+    arg = SWIG_NewPointerObj(acc, qtype, 0);
     g_return_if_fail (arg != SCM_UNDEFINED);
     args = scm_cons (arg, args);
   } else {
     args = scm_cons (SCM_BOOL_F, args);
   }
 
-  qtype = scm_c_eval_string("<gnc:GncOwner*>");
-  g_return_if_fail (qtype != SCM_UNDEFINED);
-
-  arg = gw_wcp_assimilate_ptr (owner, qtype);
+  arg = SWIG_NewPointerObj(owner, SWIG_TypeQuery("_p__gncOwner"), 0);
   g_return_if_fail (arg != SCM_UNDEFINED);
   args = scm_cons (arg, args);
 
@@ -1685,10 +1676,10 @@ gnc_invoice_new_page (GNCBook *bookp, InvoiceDialogType type,
   return iw;
 }
 
-#define KEY_INVOICE_TYPE	"Invoice Type"
-#define KEY_INVOICE_GUID	"Invoice GUID"
-#define KEY_OWNER_TYPE		"Owner Type"
-#define KEY_OWNER_GUID		"Owner GUID"
+#define KEY_INVOICE_TYPE        "InvoiceType"
+#define KEY_INVOICE_GUID        "InvoiceGUID"
+#define KEY_OWNER_TYPE          "OwnerType"
+#define KEY_OWNER_GUID          "OwnerGUID"
 
 GncPluginPage *
 gnc_invoice_recreate_page (GKeyFile *key_file,
@@ -1704,7 +1695,7 @@ gnc_invoice_recreate_page (GKeyFile *key_file,
   GncOwner owner = { 0 };
 
   /* Get Invoice Type */
-  tmp_string = gnc_key_file_get_string(key_file, group_name,
+  tmp_string = g_key_file_get_string(key_file, group_name,
 				     KEY_INVOICE_TYPE, &error);
   if (error) {
     g_warning("Error reading group %s key %s: %s.",
@@ -1715,7 +1706,7 @@ gnc_invoice_recreate_page (GKeyFile *key_file,
   g_free(tmp_string);
 
   /* Get Invoice GUID */
-  tmp_string = gnc_key_file_get_string(key_file, group_name,
+  tmp_string = g_key_file_get_string(key_file, group_name,
 				     KEY_INVOICE_GUID, &error);
   if (error) {
     g_warning("Error reading group %s key %s: %s.",
@@ -1735,7 +1726,7 @@ gnc_invoice_recreate_page (GKeyFile *key_file,
   g_free(tmp_string);
 
   /* Get Owner Type */
-  owner_type = gnc_key_file_get_string(key_file, group_name,
+  owner_type = g_key_file_get_string(key_file, group_name,
 				     KEY_OWNER_TYPE, &error);
   if (error) {
     g_warning("Error reading group %s key %s: %s.",
@@ -1744,7 +1735,7 @@ gnc_invoice_recreate_page (GKeyFile *key_file,
   }
 
   /* Get Owner GUID */
-  tmp_string = gnc_key_file_get_string(key_file, group_name,
+  tmp_string = g_key_file_get_string(key_file, group_name,
 				     KEY_OWNER_GUID, &error);
   if (error) {
     g_warning("Error reading group %s key %s: %s.",
@@ -2284,7 +2275,7 @@ gnc_invoice_search (GncInvoice *start, GncOwner *owner, GNCBook *book)
   }
   if (emp_params == NULL) {
     emp_params = gnc_search_param_prepend (emp_params,
-					   _("Voucher Owner"), type,
+					   _("Voucher Owner"), NULL, type,
 					   INVOICE_OWNER, NULL);
     emp_params = gnc_search_param_prepend (emp_params,
 					   _("Voucher Notes"), NULL, type,
