@@ -562,7 +562,7 @@ static char * get_date_help (VirtualLocation virt_loc, gpointer user_data)
   gnc_date_cell_get_date ((DateCell *) cell, &ts);
   tt = ts.tv_sec;
   tm = localtime (&tt);
-  strftime (string, sizeof(string), "%A %d %B %Y", tm);
+  qof_strftime (string, sizeof(string), "%A %d %B %Y", tm);
 
   return g_strdup (string);
 }
