@@ -37,8 +37,21 @@
 #ifndef GNC_GKEYFILE_UTILS_H
 #define GNC_GKEYFILE_UTILS_H
 
-#ifndef HAVE_GLIB26
-#include "gkeyfile.h"
+
+#ifndef HAVE_GLIB_2_12
+gdouble
+g_key_file_get_double (GKeyFile *key_file, const gchar *group_name,
+                       const gchar *key, GError **error);
+
+void
+g_key_file_set_double  (GKeyFile *key_file, const gchar *group_name,
+                        const gchar *key, gdouble value);
+gdouble*
+g_key_file_get_double_list (GKeyFile *key_file, const gchar *group_name,
+                            const gchar *key, gsize *length, GError **error);
+void
+g_key_file_set_double_list (GKeyFile *key_file, const gchar *group_name, 
+                            const gchar *key, gdouble list[], gsize length);
 #endif
 
 
@@ -58,7 +71,8 @@
  */
 GKeyFile *gnc_key_file_load_from_file (const gchar *file,
 				       gboolean ignore_error,
-				       gboolean return_empty_struct);
+				       gboolean return_empty_struct,
+				       GError **caller_error);
 
 
 /** Write a key/value file from memory to disk.  If there is no data
@@ -77,31 +91,6 @@ gboolean gnc_key_file_save_to_file (const gchar *file,
 				    GKeyFile *key_file,
 				    GError **error);
 
-
-
-/* Compatability functions to handle reading key names both with and
- * without embedded spaces.  The 2.0 release uses names containing
- * spaces, while 2.2 uses names without spaces. These functions allow
- * you to fall back to using 2.0 after trying a 2.2 release.  */ 
-gboolean gnc_key_file_get_boolean (GKeyFile *key_file,
-				   const gchar *group_name,
-				   const gchar *key,
-				   GError **error);
-gint gnc_key_file_get_integer (GKeyFile *key_file,
-			       const gchar *group_name,
-			       const gchar *key,
-			       GError **error);
-gint *gnc_key_file_get_integer_list (GKeyFile *key_file,
-				     const gchar *group_name,
-				     const gchar *key,
-				     gsize *length,
-				     GError **error);
-gchar *gnc_key_file_get_string (GKeyFile *key_file,
-				const gchar *group_name,
-				const gchar *key,
-				GError **error);
-
-
 #endif /* GNC_GKEYFILE_UTILS_H */
 /** @} */
 /** @} */
