@@ -58,10 +58,7 @@ ToDo:
 #include <glib.h>
 #include <glib/gi18n.h>
 
-#include "Account.h"
 #include "AccountP.h"
-#include "Group.h"
-#include "GroupP.h"
 #include "Scrub2.h"
 #include "Scrub3.h"
 #include "Transaction.h"
@@ -82,16 +79,17 @@ gboolean
 xaccAccountHasTrades (Account *acc)
 {
    gnc_commodity *acc_comm;
-   SplitList *node;
+   SplitList *splits, *node;
 
    if (!acc) return FALSE;
 
    if (xaccAccountIsPriced (acc))
       return TRUE;
       
-   acc_comm = acc->commodity;
+   acc_comm = xaccAccountGetCommodity(acc);
 
-   for (node=acc->splits; node; node=node->next)
+   splits = xaccAccountGetSplitList(acc);
+   for (node=splits; node; node=node->next)
    {
       Split *s = node->data;
       Transaction *t = s->parent;
@@ -193,7 +191,8 @@ xaccAccountFindEarliestOpenLot (Account *acc, gnc_numeric sign,
                                 gnc_commodity *currency)
 {
    GNCLot *lot;
-   ENTER (" sign=%" G_GINT64_FORMAT "/%" G_GINT64_FORMAT, sign.num, sign.denom);
+   ENTER (" sign=%" G_GINT64_FORMAT "/%" G_GINT64_FORMAT, sign.num, 
+          sign.denom);
       
    lot = xaccAccountFindOpenLot (acc, sign, currency,
                    G_MAXUINT64, earliest_pred);
@@ -220,7 +219,7 @@ xaccAccountFindLatestOpenLot (Account *acc, gnc_numeric sign,
 /* Similar to GetOrMakeAccount, but different in important ways */
 
 static Account *
-GetOrMakeLotOrphanAccount (AccountGroup *root, gnc_commodity * currency)
+GetOrMakeLotOrphanAccount (Account *root, gnc_commodity * currency)
 {
   char * accname;
   Account * acc;
@@ -238,16 +237,16 @@ GetOrMakeLotOrphanAccount (AccountGroup *root, gnc_commodity * currency)
                          gnc_commodity_get_mnemonic (currency), NULL);
 
   /* See if we've got one of these going already ... */
-  acc = xaccGetAccountFromName (root, accname);
+  acc = gnc_account_lookup_by_name(root, accname);
 
   if (acc == NULL)
   {
     /* Guess not. We'll have to build one. */
-    acc = xaccMallocAccount (root->book);
+    acc = xaccMallocAccount (gnc_account_get_book(root));
     xaccAccountBeginEdit (acc);
     xaccAccountSetName (acc, accname);
     xaccAccountSetCommodity (acc, currency);
-    xaccAccountSetType (acc, INCOME);
+    xaccAccountSetType (acc, ACCT_TYPE_INCOME);
     xaccAccountSetDescription (acc, _("Realized Gain/Loss"));
     xaccAccountSetNotes (acc, 
          _("Realized Gains or Losses from "
@@ -255,7 +254,7 @@ GetOrMakeLotOrphanAccount (AccountGroup *root, gnc_commodity * currency)
            "that haven't been recorded elsewhere."));
 
     /* Hang the account off the root. */
-    xaccGroupInsertAccount (root, acc);
+    gnc_account_append_child (root, acc);
     xaccAccountCommitEdit (acc);
   }
 
@@ -272,6 +271,7 @@ xaccAccountSetDefaultGainAccount (Account *acc, Account *gain_acct)
   KvpFrame *cwd;
   KvpValue *vvv;
   const char * cur_name;
+  gnc_commodity *acc_comm;
 
   if (!acc || !gain_acct) return;
 
@@ -279,12 +279,13 @@ xaccAccountSetDefaultGainAccount (Account *acc, Account *gain_acct)
   cwd = kvp_frame_get_frame_slash (cwd, "/lot-mgmt/gains-act/");
 
   /* Accounts are indexed by thier unique currency name */
-  cur_name = gnc_commodity_get_unique_name (acc->commodity);
+  acc_comm = xaccAccountGetCommodity(acc);
+  cur_name = gnc_commodity_get_unique_name (acc_comm);
 
   xaccAccountBeginEdit (acc);
   vvv = kvp_value_new_guid (xaccAccountGetGUID (gain_acct));
   kvp_frame_set_slot_nc (cwd, cur_name, vvv);
-  xaccAccountSetSlots_nc (acc, acc->inst.kvp_data);
+  qof_instance_set_slots(QOF_INSTANCE(acc), acc->inst.kvp_data);
   xaccAccountCommitEdit (acc);
 }
 
@@ -309,7 +310,7 @@ xaccAccountGetDefaultGainAccount (Account *acc, gnc_commodity * currency)
   vvv = kvp_frame_get_slot (cwd, cur_name);
   gain_acct_guid = kvp_value_get_guid (vvv);
 
-  gain_acct = xaccAccountLookup (gain_acct_guid, acc->inst.book);
+  gain_acct = xaccAccountLookup (gain_acct_guid, qof_instance_get_book(acc));
   return gain_acct;
 }
 
@@ -337,21 +338,21 @@ GetOrMakeGainAcct (Account *acc, gnc_commodity * currency)
   vvv = kvp_frame_get_slot (cwd, cur_name);
   gain_acct_guid = kvp_value_get_guid (vvv);
 
-  gain_acct = xaccAccountLookup (gain_acct_guid, acc->inst.book);
+  gain_acct = xaccAccountLookup (gain_acct_guid, qof_instance_get_book(acc));
 
   /* If there is no default place to put gains/losses 
    * for this account, then create such a place */
   if (NULL == gain_acct)
   {
-      AccountGroup *root;
+      Account *root;
 
       xaccAccountBeginEdit (acc);
-      root = xaccAccountGetRoot(acc);
+      root = gnc_account_get_root(acc);
       gain_acct = GetOrMakeLotOrphanAccount (root, currency);
 
       vvv = kvp_value_new_guid (xaccAccountGetGUID (gain_acct));
       kvp_frame_set_slot_nc (cwd, cur_name, vvv);
-      xaccAccountSetSlots_nc (acc, acc->inst.kvp_data);
+      qof_instance_set_slots(QOF_INSTANCE(acc), acc->inst.kvp_data);
       xaccAccountCommitEdit (acc);
 
   }
@@ -528,7 +529,7 @@ xaccSplitAssignToLot (Split *split, GNCLot *lot)
 
       /* Put the remainder of the balance into a new split, 
        * which is in other respects just a clone of this one. */
-      new_split = xaccMallocSplit (acc->inst.book);
+      new_split = xaccMallocSplit (qof_instance_get_book(acc));
 
       /* Copy most of the split attributes */
       xaccSplitSetMemo (new_split, xaccSplitGetMemo (split));
@@ -577,7 +578,7 @@ MakeDefaultLot (Account *acc)
    gint64 id;
    char buff[200];
 
-   lot = gnc_lot_new (acc->inst.book);
+   lot = gnc_lot_new (qof_instance_get_book(acc));
 
    /* Provide a reasonable title for the new lot */
    id = kvp_frame_get_gint64 (xaccAccountGetSlots (acc), "/lot-mgmt/next-id");
@@ -615,7 +616,7 @@ xaccSplitAssign (Split *split)
 
    ENTER ("(split=%p)", split);
 
-   pcy = acc->policy;
+   pcy = gnc_account_get_policy(acc);
    xaccAccountBeginEdit (acc);
 
    /* If we are here, this split does not belong to any lot.
@@ -661,7 +662,7 @@ xaccSplitGetCapGainsSplit (const Split *split)
 
    /* Both splits will be in the same collection, so search there. */
    gains_split = (Split*) qof_collection_lookup_entity (
-       split->inst.entity.collection, gains_guid);
+       qof_instance_get_collection(split), gains_guid);
    PINFO ("split=%p has gains-split=%p", split, gains_split);
    return gains_split;
 }
@@ -683,8 +684,8 @@ xaccSplitGetGainsSourceSplit (const Split *split)
    if (!source_guid) return NULL;
 
    /* Both splits will be in the same collection, so search there. */
-   source_split = (Split*) qof_collection_lookup_entity (split->inst.entity.collection, 
-                                                         source_guid);
+   source_split = (Split*) qof_collection_lookup_entity(
+       qof_instance_get_collection(split), source_guid);
    PINFO ("split=%p has source-split=%p", split, source_split);
    return source_split;
 }
@@ -708,7 +709,7 @@ xaccSplitComputeCapGains(Split *split, Account *gain_acc)
    if (!split) return;
    lot = split->lot;
    if (!lot) return;
-   pcy = lot->account->policy;
+   pcy = gnc_account_get_policy(lot->account);
    currency = split->parent->common_currency;
 
    ENTER ("(split=%p gains=%p status=0x%x lot=%s)", split, 
@@ -848,7 +849,7 @@ xaccSplitComputeCapGains(Split *split, Account *gain_acc)
                                 gnc_numeric_abs(split->amount)))
    {
       GList *n;
-      for (n=lot->splits; n; n=n->next) 
+      for (n = lot->splits; n; n = n->next) 
       {
          Split *s = n->data;
          PINFO ("split amt=%s", gnc_num_dbg_to_string(s->amount));
@@ -867,7 +868,7 @@ xaccSplitComputeCapGains(Split *split, Account *gain_acc)
          gnc_numeric_negative_p(split->amount)))
    {
       GList *n;
-      for (n=lot->splits; n; n=n->next) 
+      for (n = lot->splits; n; n = n->next) 
       {
          Split *s = n->data;
          PINFO ("split amt=%s", gnc_num_dbg_to_string(s->amount));
@@ -944,7 +945,7 @@ xaccSplitComputeCapGains(Split *split, Account *gain_acc)
       if (NULL == lot_split)
       {
          Account *lot_acc = lot->account;
-         QofBook *book = lot_acc->inst.book;
+         QofBook *book = qof_instance_get_book(lot_acc);
 
          new_gain_split = TRUE;
          
@@ -1061,9 +1062,11 @@ xaccSplitGetCapGains(Split * split)
    if (!split) return gnc_numeric_zero();
    ENTER("(split=%p)", split);
 
-   if (GAINS_STATUS_UNKNOWN == split->gains) xaccSplitDetermineGainStatus(split);
+   if (GAINS_STATUS_UNKNOWN == split->gains) 
+       xaccSplitDetermineGainStatus(split);
    if ((split->gains & GAINS_STATUS_A_VDIRTY) || 
-       (split->gains_split && (split->gains_split->gains & GAINS_STATUS_A_VDIRTY)))
+       (split->gains_split && 
+        (split->gains_split->gains & GAINS_STATUS_A_VDIRTY)))
    {
       xaccSplitComputeCapGains (split, NULL);
    }
@@ -1097,13 +1100,14 @@ xaccLotComputeCapGains (GNCLot *lot, Account *gain_acc)
     * to mark all splits dirty if the opening splits are dirty. */
 
    ENTER("(lot=%p)", lot);
-   pcy = lot->account->policy;
-   for (node=lot->splits; node; node=node->next)
+   pcy = gnc_account_get_policy(lot->account);
+   for (node = lot->splits; node; node = node->next)
    {
       Split *s = node->data;
       if (pcy->PolicyIsOpeningSplit(pcy,lot,s))
       {
-         if (GAINS_STATUS_UNKNOWN == s->gains) xaccSplitDetermineGainStatus (s);
+         if (GAINS_STATUS_UNKNOWN == s->gains) 
+             xaccSplitDetermineGainStatus(s);
          if (s->gains & GAINS_STATUS_VDIRTY) 
          { 
             is_dirty = TRUE; 
@@ -1114,14 +1118,14 @@ xaccLotComputeCapGains (GNCLot *lot, Account *gain_acc)
 
    if (is_dirty)
    {
-      for (node=lot->splits; node; node=node->next)
+      for (node = lot->splits; node; node = node->next)
       {
          Split *s = node->data;
          s->gains |= GAINS_STATUS_VDIRTY;
       }
    }
 
-   for (node=lot->splits; node; node=node->next)
+   for (node = lot->splits; node; node = node->next)
    {
       Split *s = node->data;
       xaccSplitComputeCapGains (s, gain_acc);
