@@ -47,7 +47,7 @@
 ( "Burundi Franc" "franc" "centime" "ISO4217" "BIF" "108" 1 1 )
 ( "CFA Franc BEAC" "franc" "centime" "ISO4217" "XAF" "950" 1 1 )
 ( "CFA Franc BCEAO" "franc" "centime" "ISO4217" "XOF" "952" 1 1 )
-( "CFP Franc Pacifique" "franc" "centime" "ISO4217" "XPF" "953" 100 100 )
+( "CFP Franc Pacifique" "franc" "centime" "ISO4217" "XPF" "953" 1 1 )
 ( "Cambodia Riel" "riel" "sen" "ISO4217" "KHR" "116" 100 100 )
 ( "Canadian Dollar" "dollar" "cent" "ISO4217" "CAD" "124" 100 100 )
 ( "Cape Verde Escudo" "escudo" "centavo" "ISO4217" "CVE" "132" 100 100 )
@@ -126,6 +126,7 @@
 ( "Mauritanian Ouguiya" "ouguiya" "khoum"  "ISO4217" "MRO" "478" 5 5)
 ( "Mauritius Rupee" "rupee" "cent"  "ISO4217" "MUR" "480" 100 100 )
 ( "Mexican Peso" "peso" "centavo" "ISO4217" "MXN" "484" 100 100 ) ;;sicne Jan 1993
+( "Moldovan Leu" "leu" "ban" "ISO4217" "MDL" "498" 100 100 )
 ( "Mongolian Tugrik" "tugrik" "mongo" "ISO4217" "MNT" "496" 100 100 )
 ( "Moroccan Dirham" "dirham" "centime"  "ISO4217" "MAD" "504" 100 100 )
 ( "Mozambique Metical" "metical" "centavo"  "ISO4217" "MZM" "508" 100 100 )
@@ -194,6 +195,7 @@
 ( "Vanuatu Vatu" "vatu" "centime" "ISO4217" "VUV" "548" 1 1 )
 ( "Venezuelan Bolivar" "bolivar" "centimo" "ISO4217" "VEB" "862" 100 100 )
 ( "Vietnamese Dong" "dong" "hao" "ISO4217" "VND" "704" 100 100 )
+( "Yemeni Riyal" "riyal" "fils" "ISO4217" "YER" "886" 100 100 )
 ( "Yugoslav Dinar" "dinar" "para"  "ISO4217" "YUM"  "890" 100 100)
 ( "Zambian Kwacha" "kwacha" "ngwee"  "ISO4217" "ZMK" "894" 100 100 )
 ( "Zimbabwe Dollar" "dollar" "cent" "ISO4217" "ZWD" "716" 100 100 )
