@@ -29,11 +29,13 @@
 
 #include "Account.h"
 #include "AccountP.h"
-#include "Group.h"
-#include "GroupP.h"
 #include "gnc-engine.h"
+#include "gnc-session.h"
 #include "Transaction.h"
 #include "TransactionP.h"
+#include "Recurrence.h"
+#include "SchedXaction.h"
+#include "SX-book.h"
 
 #include "test-engine-stuff.h"
 #include "test-stuff.h"
@@ -45,8 +47,8 @@ static GHashTable *exclude_kvp_types = NULL;
 static gint kvp_max_depth = 5;
 static gint kvp_frame_max_elements = 10;
 
-static gint max_group_depth = 1;
-static gint max_group_accounts = 3;
+static gint max_tree_depth = 1;
+static gint max_level_accounts = 3;
 static gint max_total_accounts = 10;
 static gint max_trans_num = 1000;
 static gint total_num_accounts = 0;
@@ -69,15 +71,15 @@ gboolean gnc_engine_debug_random = FALSE;
 /* Set control parameters governing the run. */
 
 void
-set_max_group_depth (gint max_group_depth_in)
+set_max_account_tree_depth (gint max_tree_depth_in)
 {
-  max_group_depth = MAX (max_group_depth_in, 1);
+  max_tree_depth = MAX (max_tree_depth_in, 1);
 }
 
 void
-set_max_group_accounts (gint max_group_accounts_in)
+set_max_accounts_per_level (gint max_level_accounts_in)
 {
-  max_group_accounts = MAX (max_group_accounts_in, 1);
+  max_level_accounts = MAX (max_level_accounts_in, 1);
 }
 
 void
@@ -445,9 +447,9 @@ get_random_gnc_numeric(void)
     }
     else
     {
-       gint64 norm = RAND_IN_RANGE (10ULL);
+       gint64 norm = RAND_IN_RANGE (8ULL);
 
-       /* multiple of 10, between 1 and 10 000 million */
+       /* multiple of 10, between 1 and 10 million */
        deno = 1;
        while (norm) 
        {
@@ -459,7 +461,7 @@ get_random_gnc_numeric(void)
     /* Arbitrary random numbers can cause pointless overflow 
      * during calculations.  Limit dynamic range in hopes 
      * of avoiding overflow. */
-    numer = get_random_gint64()/100000;
+    numer = get_random_gint64()/1000000;
     if (0 == numer) numer = 1;
     /* Make sure we have a non-zero denominator */
     if (0 == deno) deno = 1;
@@ -659,7 +661,7 @@ make_random_changes_to_price (QofBook *book, GNCPrice *p)
   g_free (string);
 
   string = get_random_string ();
-  gnc_price_set_type (p, string);
+  gnc_price_set_typestr (p, string);
   g_free (string);
 
   gnc_price_set_value (p, get_random_gnc_numeric ());
@@ -838,7 +840,7 @@ account_add_subaccounts (QofBook *book, Account *account, int depth)
   {
     Account *sub = get_random_account (book);
 
-    xaccAccountInsertSubAccount (account, sub);
+    gnc_account_append_child (account, sub);
 
     total_num_accounts ++;
     if (total_num_accounts > max_total_accounts) return;
@@ -848,64 +850,40 @@ account_add_subaccounts (QofBook *book, Account *account, int depth)
 }
 
 static void
-make_random_group_depth (QofBook *book, AccountGroup *group, int depth)
-{
-  int num_accounts;
-
-  g_return_if_fail (book);
-  g_return_if_fail (group);
-
-  if (depth <= 0)
-    return;
-
-  num_accounts = get_random_int_in_range (1, max_group_accounts);
-
-  while (num_accounts-- > 0)
-  {
-    Account *account = get_random_account (book);
-
-    xaccGroupInsertAccount (group, account);
-    total_num_accounts++;
-
-    account_add_subaccounts (book, account, depth - 1);
-  }
-}
-
-static void
-make_random_group (QofBook *book, AccountGroup *group)
+make_random_account_tree (QofBook *book, Account *root)
 {
   int depth;
 
   g_return_if_fail (book);
-  g_return_if_fail (group);
+  g_return_if_fail (root);
 
   total_num_accounts = 0;
-  depth = get_random_int_in_range (1, max_group_depth);
+  depth = get_random_int_in_range (1, max_tree_depth);
 
-  make_random_group_depth (book, group, depth);
+  account_add_subaccounts (book, root, depth);
 
   /* Make sure we have at least two accounts! */
   if (total_num_accounts <= 1)
-    make_random_group_depth (book, group, 1);
+    account_add_subaccounts (book, root, 1);
 }
 
-AccountGroup *
-get_random_group (QofBook *book)
+Account *
+get_random_account_tree (QofBook *book)
 {
-  AccountGroup * group;
+  Account * root;
 
   g_return_val_if_fail (book, NULL);
 
-  group = xaccGetAccountGroup (book);
-  if (!group)
+  root = gnc_book_get_root_account (book);
+  if (!root)
   {
-    group = xaccMallocAccountGroup (book);
-    xaccSetAccountGroup (book, group);
+    root = xaccMallocAccount (book);
+    gnc_book_set_root_account (book, root);
   }
 
-  make_random_group (book, group);
+  make_random_account_tree (book, root);
 
-  return group;
+  return root;
 }
 
 /* ================================================================= */
@@ -1073,7 +1051,7 @@ add_trans_helper (Transaction *trans, gpointer data)
 }
 
 void
-make_random_changes_to_group (QofBook *book, AccountGroup *group)
+make_random_changes_to_level (QofBook *book, Account *parent)
 {
   Account *new_account;
   Account *account;
@@ -1082,24 +1060,24 @@ make_random_changes_to_group (QofBook *book, AccountGroup *group)
   GList *splits;
   GList *node;
 
-  g_return_if_fail (group && book);
+  g_return_if_fail (parent && book);
 
-  accounts = xaccGroupGetSubAccounts (group);
+  accounts = gnc_account_get_descendants (parent);
 
   /* Add a new account */
   new_account = get_random_account (book);
 
   if (get_random_boolean () || !accounts)
-    xaccGroupInsertAccount (group, new_account);
+    gnc_account_append_child (parent, new_account);
   else
   {
     account = get_random_list_element (accounts);
 
-    xaccAccountInsertSubAccount (account, new_account);
+    gnc_account_append_child (account, new_account);
   }
 
   g_list_free (accounts);
-  accounts = xaccGroupGetSubAccounts (group);
+  accounts = gnc_account_get_descendants (parent);
 
   /* Add some new transactions */
   add_random_transactions_to_book (book, get_random_int_in_range (1, 6));
@@ -1115,7 +1093,7 @@ make_random_changes_to_group (QofBook *book, AccountGroup *group)
 
   /* Mess with the transactions & splits */
   transes = NULL;
-  xaccGroupForEachTransaction (group, add_trans_helper, &transes);
+  xaccAccountTreeForEachTransaction (parent, add_trans_helper, &transes);
 
   for (node = transes; node; node = node->next)
   {
@@ -1161,7 +1139,7 @@ make_random_changes_to_group (QofBook *book, AccountGroup *group)
   g_list_free (splits);
   g_list_free (accounts);
 
-  accounts = xaccGroupGetSubAccounts (group);
+  accounts = gnc_account_get_descendants (parent);
 
   /* move some accounts around */
   if (accounts && (g_list_length (accounts) > 1))
@@ -1181,7 +1159,7 @@ make_random_changes_to_group (QofBook *book, AccountGroup *group)
 
       if (!a2)
       {
-        xaccGroupInsertAccount (group, a1);
+        gnc_account_append_child (parent, a1);
         continue;
       }
 
@@ -1193,7 +1171,7 @@ make_random_changes_to_group (QofBook *book, AccountGroup *group)
         continue;
       }
 
-      xaccAccountInsertSubAccount (a2, a1);
+      gnc_account_append_child (a2, a1);
     }
   }
 
@@ -1203,8 +1181,7 @@ make_random_changes_to_group (QofBook *book, AccountGroup *group)
 Account*
 get_random_account(QofBook *book)
 {
-    AccountGroup *grp;
-    Account *ret;
+    Account *root, *ret;
     int tmp_int;
 
     ret = xaccMallocAccount(book);
@@ -1214,7 +1191,7 @@ get_random_account(QofBook *book)
     set_account_random_string_from_array(ret, xaccAccountSetName,
                                          sane_account_names);
 
-    tmp_int = get_random_int_in_range(BANK, NUM_ACCOUNT_TYPES - 1);
+    tmp_int = get_random_int_in_range(ACCT_TYPE_BANK, NUM_ACCOUNT_TYPES - 1);
     xaccAccountSetType(ret, tmp_int);
 
     set_account_random_string(ret, xaccAccountSetCode);
@@ -1222,15 +1199,15 @@ get_random_account(QofBook *book)
 
     xaccAccountSetCommodity(ret, get_random_commodity(book));
 
-    xaccAccountSetSlots_nc(ret, get_random_kvp_frame());
+    qof_instance_set_slots(QOF_INSTANCE(ret), get_random_kvp_frame());
 
-    grp = xaccGetAccountGroup (book);
-    if (!grp) 
+    root = gnc_book_get_root_account (book);
+    if (!root) 
     {
-        grp = xaccMallocAccountGroup (book);
-        xaccSetAccountGroup (book, grp);
+        root = xaccMallocAccount (book);
+        gnc_book_set_root_account (book, root);
     }
-    xaccGroupInsertAccount (grp, ret);
+    gnc_account_append_child (root, ret);
     xaccAccountCommitEdit(ret);
 
     return ret;
@@ -1247,7 +1224,7 @@ make_random_changes_to_account (QofBook *book, Account *account)
 
     set_account_random_string (account, xaccAccountSetName);
 
-    tmp_int = get_random_int_in_range (BANK, CREDITLINE);
+    tmp_int = get_random_int_in_range (ACCT_TYPE_BANK, ACCT_TYPE_CREDITLINE);
     xaccAccountSetType (account, tmp_int);
 
     set_account_random_string (account, xaccAccountSetCode);
@@ -1255,7 +1232,7 @@ make_random_changes_to_account (QofBook *book, Account *account)
 
     xaccAccountSetCommodity (account, get_random_commodity(book));
 
-    xaccAccountSetSlots_nc (account, get_random_kvp_frame());
+    qof_instance_set_slots(QOF_INSTANCE(account), get_random_kvp_frame());
 
     xaccAccountCommitEdit (account);
 }
@@ -1430,7 +1407,7 @@ get_random_transaction_with_currency(QofBook *book,
     numstr = g_new0(gchar, 10);
     if (!account_list) 
     {
-      account_list = xaccGroupGetSubAccounts (xaccGetAccountGroup (book));
+      account_list = gnc_account_get_descendants (gnc_book_get_root_account (book));
     }
 
     /* Gotta have at least two different accounts */
@@ -1878,7 +1855,7 @@ get_random_book (void)
 
   book = qof_book_new ();
 
-  get_random_group (book);
+  get_random_account_tree (book);
   get_random_pricedb (book);
 
   return book;
@@ -1894,7 +1871,7 @@ get_random_session (void)
 
   book = qof_session_get_book (session);
 
-  get_random_group (book);
+  get_random_account_tree (book);
   get_random_pricedb (book);
 
   return session;
@@ -1910,7 +1887,7 @@ add_random_transactions_to_book (QofBook *book, gint num_transactions)
 
   g_return_if_fail (book);
 
-  accounts = xaccGroupGetSubAccounts (xaccGetAccountGroup (book));
+  accounts = gnc_account_get_descendants (gnc_book_get_root_account (book));
   g_return_if_fail (accounts);
 
   table = gnc_commodity_table_get_table (book);
@@ -1931,7 +1908,7 @@ make_random_changes_to_book (QofBook *book)
 {
   g_return_if_fail (book);
 
-  make_random_changes_to_group (book, xaccGetAccountGroup (book));
+  make_random_changes_to_level (book, gnc_book_get_root_account (book));
   make_random_changes_to_pricedb (book, gnc_pricedb_get_db (book));
 
 #if 0
@@ -2160,3 +2137,61 @@ make_trans_query (Transaction *trans, TestQueryTypes query_types)
 
   return q;
 }
+
+static Recurrence*
+daily_freq(GDate* start, int multiplier)
+{
+     Recurrence *r = g_new0(Recurrence, 1);
+     recurrenceSet(r, multiplier, PERIOD_DAY, start);
+     return r;
+}
+
+static Recurrence*
+once_freq(GDate *when)
+{
+     Recurrence *r = g_new0(Recurrence, 1);
+     recurrenceSet(r, 1, PERIOD_ONCE, when);
+     return r;
+}
+
+static SchedXaction*
+add_sx(gchar *name, GDate *start, GDate *end, GDate *last_occur, Recurrence *r)
+{
+     QofBook *book = qof_session_get_book(gnc_get_current_session());
+     SchedXaction *sx = xaccSchedXactionMalloc(book);
+     xaccSchedXactionSetName(sx, name);
+     xaccSchedXactionSetStartDate(sx, start);
+     if (end != NULL)
+          xaccSchedXactionSetEndDate(sx, end);
+     if (last_occur != NULL)
+          xaccSchedXactionSetLastOccurDate(sx, last_occur);
+     {
+         GList *recurrences = NULL;
+         recurrences = g_list_append(recurrences, r);
+         gnc_sx_set_schedule(sx, recurrences);
+     }
+
+     gnc_sxes_add_sx(gnc_book_get_schedxactions(book), sx);
+
+     return sx;
+}
+
+SchedXaction*
+add_daily_sx(gchar *name, GDate *start, GDate *end, GDate *last_occur)
+{
+     return add_sx(name, start, end, last_occur, daily_freq(start, 1));
+}
+
+SchedXaction*
+add_once_sx(gchar *name, GDate *when)
+{
+     return add_sx(name, when, NULL, NULL, once_freq(when));
+}
+
+void
+remove_sx(SchedXaction *sx)
+{
+     QofBook *book = qof_session_get_book(gnc_get_current_session());
+     SchedXactions *sxes = gnc_book_get_schedxactions(book);
+     gnc_sxes_del_sx(sxes, sx);
+}
