@@ -23,15 +23,10 @@
 
 #include "config.h"
 
-#ifdef HAVE_GTK26 
 #include <gtk/gtk.h>
-#else
-#undef GNOME_DISABLE_DEPRECATED
-#include <gnome.h>
-#endif
 #include <gdk/gdk.h>
 #include <glib/gi18n.h>
-#include <g-wrap-wct.h>
+#include "swig-runtime.h"
 
 #include "gnc-tree-model-budget.h" //FIXME?
 #include "gnc-budget.h"
@@ -43,12 +38,14 @@
 #include "gnc-account-sel.h"
 #include "gnc-tree-view-account.h"
 #include "gnc-commodity-edit.h"
+#include "gnc-component-manager.h"
 #include "gnc-general-select.h"
 #include "gnc-currency-edit.h"
 #include "gnc-date-edit.h"
 #include "gnc-engine.h"
 #include "gnc-gconf-utils.h"
 #include "gnc-gui-query.h"
+#include "gnc-session.h"
 #include "gnc-ui.h"
 #include "guile-util.h"
 #include "option-util.h"
@@ -56,6 +53,7 @@
 #include "gnc-date-format.h"
 #include "misc-gnome-utils.h"
 
+#define FUNC_NAME __FUNCTION__
 /* TODO: clean up "register-stocks" junk
  */
 
@@ -63,6 +61,8 @@
 /* This static indicates the debugging module that this .o belongs to.  */
 static QofLogModule log_module = GNC_MOD_GUI;
 
+#define DIALOG_OPTIONS_CM_CLASS "dialog-options"
+
 /*
  * Point where preferences switch control method from a set of
  * notebook tabs to a list.
@@ -220,7 +220,6 @@ gnc_rd_option_rel_set_cb(GtkWidget *widget, gpointer *raw_option)
   return;
 }
 
-#ifdef HAVE_GTK26
 static void
 gnc_image_option_update_preview_cb (GtkFileChooser *chooser,
 				    GNCOption *option)
@@ -234,10 +233,10 @@ gnc_image_option_update_preview_cb (GtkFileChooser *chooser,
 
   ENTER("chooser %p, option %p", chooser, option);
   filename = gtk_file_chooser_get_preview_filename(chooser);
-  DEBUG("chooser preview name is %s.", filename);
+  DEBUG("chooser preview name is %s.", filename ? filename : "(null)");
   if (filename == NULL) {
     filename = g_strdup(g_object_get_data(G_OBJECT(chooser), LAST_SELECTION));
-    DEBUG("using last selection of %s", filename);
+    DEBUG("using last selection of %s", filename ? filename : "(null)");
     if (filename == NULL) {
       LEAVE("no usable name");
       return;
@@ -268,14 +267,6 @@ gnc_image_option_selection_changed_cb (GtkFileChooser *chooser,
     return;
   g_object_set_data_full(G_OBJECT(chooser), LAST_SELECTION, filename, g_free);
 }
-#else
-static void
-gnc_image_option_clear_selection_cb (GtkButton *button,
-				     GtkEntry *entry)
-{
-   gtk_entry_set_text(entry, "");
-}
-#endif
 
 /********************************************************************\
  * gnc_option_set_ui_value_internal                                 *
@@ -745,8 +736,12 @@ gnc_option_create_radiobutton_widget(char *name, GNCOption *option)
 
   /* Create the tooltips */
   tooltips = gtk_tooltips_new ();
+#ifdef HAVE_GTK_2_10
+  g_object_ref_sink(tooltips);
+#else
   g_object_ref (tooltips);
   gtk_object_sink (GTK_OBJECT (tooltips));
+#endif
 
   /* Iterate over the options and create a radio button for each one */
   for (i = 0; i < num_values; i++)
@@ -908,100 +903,91 @@ gnc_option_create_account_widget(GNCOption *option, char *name, GtkTooltips *too
 }
 
 static void
-gnc_option_list_select_cb(GtkCList *clist, gint row, gint column,
-                          GdkEventButton *event, gpointer data)
+gnc_option_list_changed_cb(GtkTreeSelection *selection,
+			   GNCOption *option)
 {
-  GNCOption *option = data;
+  GtkTreeView *view;
 
-  gtk_clist_set_row_data(clist, row, GINT_TO_POINTER(TRUE));
-  gnc_option_changed_widget_cb(GTK_WIDGET(clist), option);
-}
-
-static void
-gnc_option_list_unselect_cb(GtkCList *clist, gint row, gint column,
-                            GdkEventButton *event, gpointer data)
-{
-  GNCOption *option = data;
-
-  gtk_clist_set_row_data(clist, row, GINT_TO_POINTER(FALSE));
-  gnc_option_changed_widget_cb(GTK_WIDGET(clist), option);
+  view = gtk_tree_selection_get_tree_view(selection);
+  gnc_option_changed_widget_cb(GTK_WIDGET(view), option);
 }
 
 static void
 gnc_option_list_select_all_cb(GtkWidget *widget, gpointer data)
 {
   GNCOption *option = data;
+  GtkTreeView *view;
+  GtkTreeSelection *selection;
 
-  gtk_clist_select_all(GTK_CLIST(gnc_option_get_widget (option)));
-  gnc_option_changed_widget_cb(widget, option);
+  view = GTK_TREE_VIEW(gnc_option_get_widget (option));
+  selection = gtk_tree_view_get_selection(view);
+  gtk_tree_selection_select_all(selection);
+  gnc_option_changed_widget_cb(GTK_WIDGET(view), option);
 }
 
 static void
 gnc_option_list_clear_all_cb(GtkWidget *widget, gpointer data)
 {
   GNCOption *option = data;
+  GtkTreeView *view;
+  GtkTreeSelection *selection;
 
-  gtk_clist_unselect_all(GTK_CLIST(gnc_option_get_widget (option)));
-  gnc_option_changed_widget_cb(widget, option);
+  view = GTK_TREE_VIEW(gnc_option_get_widget (option));
+  selection = gtk_tree_view_get_selection(view);
+  gtk_tree_selection_unselect_all(selection);
+  gnc_option_changed_widget_cb(GTK_WIDGET(view), option);
 }
 
 static GtkWidget *
 gnc_option_create_list_widget(GNCOption *option, char *name, GtkTooltips *tooltips)
 {
-  GtkWidget *scroll_win;
-  GtkWidget *top_hbox;
+  GtkListStore *store;
+  GtkTreeView *view;
+  GtkTreeIter iter;
+  GtkTreeViewColumn *column;
+  GtkCellRenderer *renderer;
+  GtkTreeSelection *selection;
+
   GtkWidget *button;
   GtkWidget *frame;
-  GtkWidget *clist;
   GtkWidget *hbox;
   GtkWidget *bbox;
   gint num_values;
-  gint width;
   gint i;
 
-  top_hbox = gtk_hbox_new(FALSE, 0);
-
   frame = gtk_frame_new(name);
-  gtk_box_pack_start(GTK_BOX(top_hbox), frame, FALSE, FALSE, 0);
-
   hbox = gtk_hbox_new(FALSE, 0);
   gtk_container_add(GTK_CONTAINER(frame), hbox);
 
-  clist = gtk_clist_new(1);
-  gtk_clist_column_titles_hide(GTK_CLIST(clist));
-  gtk_clist_set_selection_mode(GTK_CLIST(clist), GTK_SELECTION_MULTIPLE);
+  store = gtk_list_store_new(1, G_TYPE_STRING);
+  view = GTK_TREE_VIEW(gtk_tree_view_new_with_model(GTK_TREE_MODEL(store)));
+  g_object_unref(store);
+  renderer = gtk_cell_renderer_text_new();
+  column = gtk_tree_view_column_new_with_attributes("", renderer,
+						    "text", 0,
+						    NULL);
+  gtk_tree_view_append_column(view, column);
+  gtk_tree_view_set_headers_visible(view, FALSE);
 
   num_values = gnc_option_num_permissible_values(option);
   for (i = 0; i < num_values; i++)
   {
-    gchar *text[1];
     gchar *string;
 
     string = gnc_option_permissible_value_name(option, i);
-    if (string != NULL)
-    {
-      text[0] = *string ? _(string) : "";
-      gtk_clist_append(GTK_CLIST(clist), text);
-      gtk_clist_set_row_data(GTK_CLIST(clist), i, GINT_TO_POINTER(FALSE));
-      free(string);
-    }
-    else
-    {
-      PERR("bad value name\n");
-    }
+    gtk_list_store_append(store, &iter);
+    gtk_list_store_set(store, &iter,
+		       0, string ? string : "",
+		       -1);
   }
 
-  scroll_win = gtk_scrolled_window_new(NULL, NULL);
-  gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scroll_win),
-                                 GTK_POLICY_NEVER, 
-                                 GTK_POLICY_AUTOMATIC);
+  gtk_box_pack_start(GTK_BOX(hbox), GTK_WIDGET(view), FALSE, FALSE, 0);
 
-  width = gtk_clist_columns_autosize(GTK_CLIST(clist));
-  gtk_widget_set_size_request(scroll_win, width + 50, -1);
+  selection = gtk_tree_view_get_selection(view);
+  gtk_tree_selection_set_mode(selection, GTK_SELECTION_MULTIPLE);
+  g_signal_connect(selection, "changed",
+		   G_CALLBACK(gnc_option_list_changed_cb), option);
 
-  gtk_box_pack_start(GTK_BOX(hbox), scroll_win, FALSE, FALSE, 0);
-  gtk_container_set_border_width(GTK_CONTAINER(scroll_win), 5);
-  gtk_container_add(GTK_CONTAINER(scroll_win), clist);
 
   bbox = gtk_vbutton_box_new();
   gtk_button_box_set_layout(GTK_BUTTON_BOX(bbox), GTK_BUTTONBOX_SPREAD);
@@ -1028,9 +1014,9 @@ gnc_option_create_list_widget(GNCOption *option, char *name, GtkTooltips *toolti
   g_signal_connect(G_OBJECT(button), "clicked",
 		   G_CALLBACK(gnc_option_default_cb), option);
 
-  gnc_option_set_widget (option, clist);
+  gnc_option_set_widget (option, GTK_WIDGET(view));
 
-  return top_hbox;
+  return frame;
 }
 
 static void
@@ -1220,7 +1206,7 @@ gnc_options_dialog_append_page(GNCOptionWin * propertybox,
 
 
 /********************************************************************\
- * gnc_build_options_dialog_contents                                *
+ * gnc_options_dialog_build_contents                                *
  *   builds an options dialog given a property box and an options   *
  *   database                                                       *
  *                                                                  *
@@ -1229,7 +1215,7 @@ gnc_options_dialog_append_page(GNCOptionWin * propertybox,
  * Return: nothing                                                  *
 \********************************************************************/
 void
-gnc_build_options_dialog_contents(GNCOptionWin *propertybox,
+gnc_options_dialog_build_contents(GNCOptionWin *propertybox,
                                   GNCOptionDB  *odb)
 {
   GNCOptionSection *section;
@@ -1251,8 +1237,12 @@ gnc_build_options_dialog_contents(GNCOptionWin *propertybox,
   propertybox->tips = gtk_tooltips_new();
   propertybox->option_db = odb;
 
+#ifdef HAVE_GTK_2_10
+  g_object_ref_sink(propertybox->tips);
+#else
   g_object_ref (propertybox->tips);
   gtk_object_sink (GTK_OBJECT (propertybox->tips));
+#endif
 
   num_sections = gnc_option_db_num_sections(odb);
   default_section_name = gnc_option_db_get_default_section(odb);
@@ -1314,6 +1304,8 @@ gnc_options_dialog_notebook(GNCOptionWin * win)
 void
 gnc_options_dialog_response_cb(GtkDialog *dialog, gint response, GNCOptionWin *window)
 {
+  GNCOptionWinCallback close_cb;
+
   switch (response) {
    case GTK_RESPONSE_HELP:
     if(window->help_cb)
@@ -1323,8 +1315,11 @@ gnc_options_dialog_response_cb(GtkDialog *dialog, gint response, GNCOptionWin *w
    case GTK_RESPONSE_OK:
    case GTK_RESPONSE_APPLY:
     gnc_options_dialog_changed_internal (window->dialog, FALSE);
+    close_cb = window->close_cb;
+    window->close_cb = NULL;
     if (window->apply_cb)
       window->apply_cb (window, window->apply_cb_data);
+    window->close_cb = close_cb;
     if (response == GTK_RESPONSE_APPLY)
       break;
     /* fall through */
@@ -1391,6 +1386,13 @@ gnc_options_register_stocks (void)
 #endif
 }
 
+static void
+component_close_handler (gpointer data)
+{
+  GNCOptionWin *window = data;
+  gtk_dialog_response(GTK_DIALOG(window->dialog), GTK_RESPONSE_CANCEL);
+}
+
 /* gnc_options_dialog_new:
  *
  *   - Opens the preferences glade file
@@ -1405,6 +1407,7 @@ gnc_options_dialog_new(gchar *title)
   GNCOptionWin * retval;
   GladeXML *xml;
   GtkWidget * hbox;
+  gint component_id;
 
   retval = g_new0(GNCOptionWin, 1);
   xml = gnc_glade_xml_new ("preferences.glade", "GnuCash Options");
@@ -1424,6 +1427,11 @@ gnc_options_dialog_new(gchar *title)
   gtk_widget_show(retval->notebook);
   gtk_box_pack_start(GTK_BOX(hbox), retval->notebook, TRUE, TRUE, 5);
 
+  component_id = gnc_register_gui_component (DIALOG_OPTIONS_CM_CLASS,
+                                             NULL, component_close_handler,
+                                             retval);
+  gnc_gui_component_set_session (component_id, gnc_get_current_session());
+
   return retval;
 }
 
@@ -1477,6 +1485,8 @@ gnc_options_dialog_destroy(GNCOptionWin * win)
 {
   if (!win) return;
 
+  gnc_unregister_gui_component_by_data(DIALOG_OPTIONS_CM_CLASS, win);
+
   gtk_widget_destroy(win->dialog);
 
   if(win->tips) {
@@ -1815,8 +1825,7 @@ gnc_option_set_ui_widget_account_sel (GNCOption *option, GtkBox *page_box,
   value = gnc_account_sel_new();
   gnc_account_sel_set_acct_filters(GNC_ACCOUNT_SEL(value), acct_type_list);
 
-  g_signal_connect(G_OBJECT(gnc_account_sel_gtk_entry(GNC_ACCOUNT_SEL(value))),
-		   "changed",
+  g_signal_connect(value, "changed",
 		   G_CALLBACK(gnc_option_changed_widget_cb), option);
 
   gnc_option_set_widget (option, value);
@@ -1840,7 +1849,6 @@ gnc_option_set_ui_widget_list (GNCOption *option, GtkBox *page_box,
 {
   GtkWidget *value;
   GtkWidget *eventbox;
-  gint num_lines;
 
   *enclosing = gnc_option_create_list_widget(option, name, tooltips);
   value = gnc_option_get_widget (option);
@@ -1854,21 +1862,8 @@ gnc_option_set_ui_widget_list (GNCOption *option, GtkBox *page_box,
 
   gtk_tooltips_set_tip(tooltips, eventbox, documentation, NULL);
 
-  //gtk_widget_realize(value);
-
   gnc_option_set_ui_value(option, FALSE);
-
-  g_signal_connect(G_OBJECT(value), "select_row",
-		   G_CALLBACK(gnc_option_list_select_cb), option);
-  g_signal_connect(G_OBJECT(value), "unselect_row",
-		   G_CALLBACK(gnc_option_list_unselect_cb), option);
-
-  num_lines = gnc_option_num_permissible_values(option);
-  num_lines = MIN(num_lines, 9) + 1;
-
-  gtk_clist_set_row_height(GTK_CLIST(value), 0);
-  gtk_widget_set_size_request(value, -1, GTK_CLIST(value)->row_height * num_lines);
-  gtk_widget_show_all(*enclosing);
+  gtk_widget_show(*enclosing);
   return value;
 }
 
@@ -2022,9 +2017,6 @@ gnc_option_set_ui_widget_pixmap (GNCOption *option, GtkBox *page_box,
   GtkWidget *value;
   GtkWidget *label;
   GtkWidget *button;
-#ifndef HAVE_GTK26
-  GtkWidget *entry;
-#endif
   gchar *colon_name;
 
   ENTER("option %p(%s), name %s", option, gnc_option_name(option), name);
@@ -2038,7 +2030,6 @@ gnc_option_set_ui_widget_pixmap (GNCOption *option, GtkBox *page_box,
   button = gtk_button_new_with_label(_("Clear"));
   gtk_tooltips_set_tip(tooltips, button, _("Clear any selected image file."), NULL);
 
-#ifdef HAVE_GTK26
   value = gtk_file_chooser_button_new(_("Select image"),
 				      GTK_FILE_CHOOSER_ACTION_OPEN);
   gtk_tooltips_set_tip(tooltips, value, _("Select an image file."), NULL);
@@ -2054,19 +2045,7 @@ gnc_option_set_ui_widget_pixmap (GNCOption *option, GtkBox *page_box,
 		   G_CALLBACK(gnc_image_option_update_preview_cb), option);
   g_signal_connect_swapped(G_OBJECT (button), "clicked",
 		   G_CALLBACK(gtk_file_chooser_unselect_all), value);
-#else
-  value = gnome_pixmap_entry_new(NULL, _("Select pixmap"),
-				 FALSE);
-  gtk_tooltips_set_tip(tooltips, value, _("Select an image file."), NULL);
-  gnome_pixmap_entry_set_preview(GNOME_PIXMAP_ENTRY(value), FALSE);
 
-  entry = gnome_pixmap_entry_gtk_entry (GNOME_PIXMAP_ENTRY(value));
-  g_signal_connect(G_OBJECT (entry), "changed",
-		   G_CALLBACK(gnc_option_changed_widget_cb), option);
-  g_signal_connect(G_OBJECT (button), "clicked",
-		   G_CALLBACK(gnc_image_option_clear_selection_cb), entry);
-#endif
-    
   gnc_option_set_widget (option, value);
   gnc_option_set_ui_value(option, FALSE);
 
@@ -2391,11 +2370,11 @@ gnc_option_set_ui_value_account_sel (GNCOption *option, gboolean use_default,
   Account *acc = NULL;
 
   if (value != SCM_BOOL_F) {
-    if (!gw_wcp_p(value))
-      scm_misc_error("gnc_option_set_ui_value_account_sel",
-		     "Option Value not a gw:wcp.", value);
+    if (!SWIG_IsPointer(value))
+        scm_misc_error("gnc_option_set_ui_value_account_sel",
+                       "Option Value not a wcp.", value);
       
-    acc = gw_wcp_get_ptr(value);
+    acc = SWIG_MustGetPtr(value, SWIG_TypeQuery("_p_Account"), 4, 0);
   }
 	
   gnc_account_sel_set_account (GNC_ACCOUNT_SEL(widget), acc);
@@ -2407,13 +2386,12 @@ static gboolean
 gnc_option_set_ui_value_list (GNCOption *option, gboolean use_default,
 				 GtkWidget *widget, SCM value)
 {
-  gint num_rows, row;
+  GtkTreeSelection *selection;
+  GtkTreePath *path;
+  gint row;
 
-  gtk_clist_unselect_all(GTK_CLIST(widget));
-
-  num_rows = gnc_option_num_permissible_values(option);
-  for (row = 0; row < num_rows; row++)
-    gtk_clist_set_row_data(GTK_CLIST(widget), row, GINT_TO_POINTER(FALSE));
+  selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(widget));
+  gtk_tree_selection_unselect_all(selection);
 
   while (SCM_LISTP(value) && !SCM_NULLP(value))
   {
@@ -2428,8 +2406,9 @@ gnc_option_set_ui_value_list (GNCOption *option, gboolean use_default,
       return TRUE;
     }
 
-    gtk_clist_select_row(GTK_CLIST(widget), row, 0);
-    gtk_clist_set_row_data(GTK_CLIST(widget), row, GINT_TO_POINTER(TRUE));
+    path = gtk_tree_path_new_from_indices(row, -1);
+    gtk_tree_selection_select_path(selection, path);
+    gtk_tree_path_free(path);
   }
 
   if (!SCM_LISTP(value) || !SCM_NULLP(value))
@@ -2513,21 +2492,14 @@ gnc_option_set_ui_value_pixmap (GNCOption *option, gboolean use_default,
 
     if (string && *string)
     {
-#ifdef HAVE_GTK26
       gchar *test;
       DEBUG("string = %s", string);
       gtk_file_chooser_select_filename(GTK_FILE_CHOOSER(widget), string);
       test = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(widget));
       g_object_set_data_full(G_OBJECT(widget), LAST_SELECTION,
 			     g_strdup(string), g_free);
-      DEBUG("Set %s, retrieved %s", string, test);
+      DEBUG("Set %s, retrieved %s", string, test ? test : "(null)");
       gnc_image_option_update_preview_cb(GTK_FILE_CHOOSER(widget), option);
-#else
-      GtkEntry *entry;
-      DEBUG("string = %s", string);
-      entry = GTK_ENTRY(gnome_pixmap_entry_gtk_entry(GNOME_PIXMAP_ENTRY(widget)));
-      gtk_entry_set_text(entry, string);
-#endif
     }
     LEAVE("FALSE");
     return FALSE;
@@ -2545,12 +2517,12 @@ static gboolean gnc_option_set_ui_value_budget(
     GtkTreeModel *tm;
     GtkTreeIter iter;
 
-    if (value != SCM_BOOL_F) {
-        if (!gw_wcp_p(value))
+    if (!SCM_NULLP(value)) {
+        if (!SWIG_IsPointer(value))
             scm_misc_error("gnc_option_set_ui_value_budget",
-                           "Option Value not a gw:wcp.", value);
+                           "Option Value not a wcp.", value);
 
-        bgt = gw_wcp_get_ptr(value);
+        bgt = SWIG_MustGetPtr(value, SWIG_TypeQuery("GncBudget *"), 4, 0);
         cb = GTK_COMBO_BOX(widget);
         tm = gtk_combo_box_get_model(cb);
         if (gnc_tree_model_budget_get_iter_for_budget(tm, &iter, bgt))
@@ -2782,7 +2754,7 @@ gnc_option_get_ui_value_account_list (GNCOption *option, GtkWidget *widget)
   list = gnc_tree_view_account_get_selected_accounts (tree);
 
   /* handover list */
-  result = gnc_glist_to_scm_list(list, scm_c_eval_string("<gnc:Account*>"));
+  result = gnc_glist_to_scm_list(list, "_p_Account");
   g_list_free(list);
   return result;
 }
@@ -2799,7 +2771,7 @@ gnc_option_get_ui_value_account_sel (GNCOption *option, GtkWidget *widget)
   if (!acc)
     return SCM_BOOL_F;
 
-  return gw_wcp_assimilate_ptr(acc, scm_c_eval_string("<gnc:Account*>"));
+  return SWIG_NewPointerObj(acc, SWIG_TypeQuery("_p_Account"), 0);
 }
 
 static SCM
@@ -2819,26 +2791,29 @@ gnc_option_get_ui_value_budget(GNCOption *option, GtkWidget *widget)
     if (!bgt)
         return SCM_BOOL_F;
 
-    return gw_wcp_assimilate_ptr(bgt, scm_c_eval_string("<gnc:Budget*>"));
+    return SWIG_NewPointerObj(bgt, SWIG_TypeQuery("_p_gnc_budget_private"), 0);
 }
 
 static SCM
 gnc_option_get_ui_value_list (GNCOption *option, GtkWidget *widget)
 {
+  GtkTreeSelection *selection;
+  GtkTreePath *path;
   SCM result;
   gboolean selected;
-  GtkCList *clist;
   gint num_rows;
   gint row;
 
-  clist = GTK_CLIST(widget);
+  selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(widget));
   num_rows = gnc_option_num_permissible_values(option);
   result = scm_c_eval_string("'()");
 
   for (row = 0; row < num_rows; row++)
   {
-    selected = GPOINTER_TO_INT(gtk_clist_get_row_data(clist, row));
-    if (selected)
+   path = gtk_tree_path_new_from_indices(row, -1);
+   selected = gtk_tree_selection_path_is_selected(selection, path);
+   gtk_tree_path_free(path);
+   if (selected)
       result = scm_cons(gnc_option_permissible_value(option, row), result);
   }
 
@@ -2900,22 +2875,14 @@ gnc_option_get_ui_value_font (GNCOption *option, GtkWidget *widget)
 static SCM
 gnc_option_get_ui_value_pixmap (GNCOption *option, GtkWidget *widget)
 {
-#ifdef HAVE_GTK26
   gchar *string;
   SCM result;
 
   string = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(widget));
-  DEBUG("filename %s", string);
+  DEBUG("filename %s", string ? string : "(null)");
   result = scm_makfrom0str(string ? string : "");
-  if (string)
-    g_free(string);
+  g_free(string);
   return result;
-#else
-  GnomePixmapEntry * p = GNOME_PIXMAP_ENTRY(widget);
-  char             * string = gnome_pixmap_entry_get_filename(p);
-
-  return (scm_makfrom0str(string ? string : ""));
-#endif
 }
 
 static SCM
@@ -3020,7 +2987,7 @@ GNCOptionDef_t * gnc_options_ui_get_option (const char *option_name)
 
 void gnc_options_ui_initialize (void)
 {
-
+  SWIG_GetModule(NULL); /* Work-around for SWIG bug. */
   //  gnc_options_register_stocks ();
   g_return_if_fail (optionTable == NULL);
   optionTable = g_hash_table_new (g_str_hash, g_str_equal);
