@@ -26,7 +26,6 @@
 #include <errno.h>
 #include <libguile.h>
 #include <string.h>
-#include <g-wrap-wct.h>
 
 #include "dialog-utils.h"
 #include "druid-gnc-xml-import.h"
@@ -41,11 +40,11 @@
 #include "gnc-ui.h"
 #include "gnc-ui-util.h"
 #include "gnc-window.h"
-#include "gnc-gconf-utils.h"
 #include "gnc-plugin-file-history.h"
 #include "qof.h"
 #include "TransLog.h"
 #include "gnc-session.h"
+#include "gnc-autosave.h"
 
 #define GCONF_SECTION "dialogs/export_accounts"
 
@@ -130,14 +129,9 @@ gnc_file_dialog (const char * title,
     gtk_dialog_add_button(GTK_DIALOG(file_box),
 			  okbutton, GTK_RESPONSE_ACCEPT);
 
-  if (starting_dir) {
-    gchar *dir_name;
-
-    /* Ensure we have a directory name.  The set function fails otherwise. */
-    dir_name = g_path_get_dirname(starting_dir);
-    gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER (file_box), dir_name);
-    g_free(dir_name);
-  }
+  if (starting_dir)
+    gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER (file_box),
+					starting_dir);
 
   gtk_window_set_modal(GTK_WINDOW(file_box), TRUE);
   /*
@@ -181,7 +175,7 @@ gnc_file_dialog (const char * title,
     file_name = g_strdup(internal_name);
   }
   gtk_widget_destroy(GTK_WIDGET(file_box));
-  LEAVE("%s", file_name);
+  LEAVE("%s", file_name ? file_name : "(null)");
   return file_name;
 }
 
@@ -197,7 +191,6 @@ show_session_error (QofBackendError io_error,
   const char *fmt, *label;
   gint response;
 
-  gnc_destroy_splash_screen(); /* Just in case */
   if (NULL == newfile) { newfile = _("(null)"); }
 
   switch (io_error)
@@ -205,12 +198,12 @@ show_session_error (QofBackendError io_error,
     case ERR_BACKEND_NO_ERR:
       uh_oh = FALSE;
       break;
-	
-	case ERR_BACKEND_NO_HANDLER: {
-		fmt = _("No suitable backend was found for %s.");
-		gnc_error_dialog(parent, fmt, newfile);
-		break;
-	}
+
+    case ERR_BACKEND_NO_HANDLER:
+      fmt = _("No suitable backend was found for %s.");
+      gnc_error_dialog(parent, fmt, newfile);
+      break;
+
     case ERR_BACKEND_NO_BACKEND:
       fmt = _("The URL %s is not supported by this version of GnuCash.");
       gnc_error_dialog (parent, fmt, newfile);
@@ -546,16 +539,22 @@ gboolean
 gnc_file_query_save (gboolean can_cancel)
 {
   GtkWidget *parent = gnc_ui_get_toplevel();
+  QofBook *current_book;
 
   if (!gnc_current_session_exist())
       return TRUE;
+
+  current_book = qof_session_get_book (gnc_get_current_session ());
+  /* Remove any pending auto-save timeouts */
+  gnc_autosave_remove_timer(current_book);
+
   /* If user wants to mess around before finishing business with
    * the old file, give em a chance to figure out what's up.  
    * Pose the question as a "while" loop, so that if user screws
    * up the file-selection dialog, we don't blow em out of the water;
    * instead, give them another chance to say "no" to the verify box.
    */
-  while (qof_book_not_saved(qof_session_get_book (gnc_get_current_session ())))
+  while (qof_book_not_saved(current_book))
   {
     GtkWidget *dialog;
     gint response;
@@ -571,7 +570,7 @@ gnc_file_query_save (gboolean can_cancel)
 				    GTK_MESSAGE_QUESTION,
 				    GTK_BUTTONS_NONE,
 				    "%s", title);
-    oldest_change = qof_book_get_dirty_time(qof_session_get_book (gnc_get_current_session ()));
+    oldest_change = qof_book_get_dirty_time(current_book);
     minutes = (time(NULL) - oldest_change) / 60 + 1;
     gtk_message_dialog_format_secondary_text(GTK_MESSAGE_DIALOG(dialog),
 					     message, minutes);
@@ -668,8 +667,6 @@ gnc_post_file_open (const char * filename)
                  );
     int rc;
 
-    gnc_destroy_splash_screen(); /* Just in case */
-
     dialog = gtk_message_dialog_new(NULL,
 				    0,
 				    GTK_MESSAGE_WARNING,
@@ -745,7 +742,7 @@ gnc_post_file_open (const char * filename)
 
   if (!uh_oh)
   {
-    AccountGroup *new_group;
+    Account *new_root;
 
     char * logpath = xaccResolveFilePath(newfile);
     PINFO ("logpath=%s", logpath ? logpath : "(null)");
@@ -777,12 +774,12 @@ gnc_post_file_open (const char * filename)
 
     uh_oh = show_session_error (io_err, newfile, GNC_FILE_DIALOG_OPEN);
 
-    new_group = gnc_book_get_group (qof_session_get_book (new_session));
-    if (uh_oh) new_group = NULL;
+    new_root = gnc_book_get_root_account (qof_session_get_book (new_session));
+    if (uh_oh) new_root = NULL;
 
     /* Umm, came up empty-handed, but no error: 
      * The backend forgot to set an error. So make one up. */
-    if (!uh_oh && !new_group) 
+    if (!uh_oh && !new_root) 
     {
       uh_oh = show_session_error (ERR_BACKEND_MISC, newfile,
 				  GNC_FILE_DIALOG_OPEN);
@@ -798,11 +795,11 @@ gnc_post_file_open (const char * filename)
     qof_session_destroy (new_session);
     xaccLogEnable();
 
-    /* well, no matter what, I think it's a good idea to have a
-     * topgroup around.  For example, early in the gnucash startup
+    /* well, no matter what, I think it's a good idea to have a root
+     * account around.  For example, early in the gnucash startup
      * sequence, the user opens a file; if this open fails for any
-     * reason, we don't want to leave them high & dry without a
-     * topgroup, because if the user continues, then bad things will
+     * reason, we don't want to leave them high & dry without a root
+     * account, because if the user continues, then bad things will
      * happen. */
     gnc_get_current_session ();
 
@@ -838,16 +835,21 @@ gboolean
 gnc_file_open (void)
 {
   const char * newfile;
-  char *lastfile;
+  char *lastfile = NULL;
+  gchar *last_file_dir = NULL;
   gboolean result;
 
   if (!gnc_file_query_save (TRUE))
     return FALSE;
 
   lastfile = gnc_history_get_last();
-  newfile = gnc_file_dialog (_("Open"), NULL, lastfile, GNC_FILE_DIALOG_OPEN);
   if (lastfile)
+    last_file_dir = g_path_get_dirname(lastfile);
+  newfile = gnc_file_dialog (_("Open"), NULL, last_file_dir, GNC_FILE_DIALOG_OPEN);
+  if (lastfile != NULL)
     g_free(lastfile);
+  if (last_file_dir != NULL)
+    g_free(last_file_dir);
   result = gnc_post_file_open (newfile);
 
   /* This dialogue can show up early in the startup process. If the
@@ -878,21 +880,17 @@ gnc_file_export_file(const char * newfile)
   QofBackendError io_err = ERR_BACKEND_NO_ERR;
   gchar *default_dir;
 
-  default_dir = gnc_gconf_get_string(GCONF_SECTION, KEY_LAST_PATH, NULL);
-  if (default_dir == NULL)
-    gnc_init_default_directory(&default_dir);
-
   if (!newfile) {
+    default_dir = gnc_get_default_directory (GCONF_SECTION);
     newfile =  gnc_file_dialog (_("Export"), NULL, default_dir, GNC_FILE_DIALOG_EXPORT);
     g_free(default_dir);
-    default_dir = NULL;
     if (!newfile)
       return;
   }
 
   /* Remember the directory as the default. */
-  gnc_extract_directory(&default_dir, newfile);
-  gnc_gconf_set_string(GCONF_SECTION, KEY_LAST_PATH, default_dir, NULL);
+  default_dir = g_path_get_dirname(newfile);
+  gnc_set_default_directory (GCONF_SECTION, default_dir);
   g_free(default_dir);
   
   qof_event_suspend();
@@ -1021,15 +1019,14 @@ gnc_file_save_as (void)
 
   last = gnc_history_get_last();
   if (last) {
-    gnc_extract_directory(&default_dir, last);
+    default_dir = g_path_get_dirname(last);
     g_free(last);
   } else {
-    gnc_init_default_directory(&default_dir);
+    default_dir = gnc_get_default_directory(GCONF_SECTION);
   }
   filename = gnc_file_dialog (_("Save"), NULL, default_dir, 
-		  GNC_FILE_DIALOG_SAVE);
-  if (default_dir)
-    free(default_dir);
+			      GNC_FILE_DIALOG_SAVE);
+  g_free(default_dir);
   if (!filename) return;
 
   /* Check to see if the user specified the same file as the current
@@ -1099,6 +1096,12 @@ gnc_file_save_as (void)
     return;
   }
 
+  /* Prevent race condition between swapping the contents of the two
+   * sessions, and actually installing the new session as the current
+   * one. Any event callbacks that occur in this interval will have
+   * problems if they check for the current book. */
+  qof_event_suspend();
+
   /* if we got to here, then we've successfully gotten a new session */
   /* close up the old file session (if any) */
   qof_session_swap_data (session, new_session);
@@ -1111,6 +1114,8 @@ gnc_file_save_as (void)
    */
   gnc_set_current_session(new_session);
 
+  qof_event_resume();
+
   /* --------------- END CORE SESSION CODE -------------- */
 
   /* oops ... file already exists ... ask user what to do... */
