@@ -95,6 +95,7 @@ typedef struct _GncPluginPagePrivate
 	gboolean use_new_window;
 
 	gchar *page_name;
+	gchar *page_long_name;
 	gchar *uri;
 	gchar *statusbar_text;
 } GncPluginPagePrivate;
@@ -769,6 +770,37 @@ gnc_plugin_page_set_page_name (GncPluginPage *page, const gchar *name)
 }
 
 
+/*  Retrieve the long name of this page.  This is the string used in
+ *  the tooltip that is attached to the pate name in the notebook
+ *  tab. */
+const gchar *
+gnc_plugin_page_get_page_long_name (GncPluginPage *page)
+{
+  GncPluginPagePrivate *priv;
+
+  g_return_val_if_fail (GNC_IS_PLUGIN_PAGE (page), NULL);
+
+  priv = GNC_PLUGIN_PAGE_GET_PRIVATE(page);
+  return priv->page_long_name;
+}
+
+
+/*  Set the long name of this page.  This is the string used in the
+ *  tooltip that is attached to the pate name in the notebook tab. */
+void
+gnc_plugin_page_set_page_long_name (GncPluginPage *page, const gchar *name)
+{
+  GncPluginPagePrivate *priv;
+
+  g_return_if_fail (GNC_IS_PLUGIN_PAGE (page));
+
+  priv = GNC_PLUGIN_PAGE_GET_PRIVATE(page);
+  if (priv->page_long_name)
+    g_free(priv->page_long_name);
+  priv->page_long_name = g_strdup(name);
+}
+
+
 /*  Retrieve the Uniform Resource Identifier for this page. */
 const gchar *
 gnc_plugin_page_get_uri (GncPluginPage *page)
