@@ -28,22 +28,16 @@
 #include <glib/gi18n.h>
 #include <string.h>
 
-#ifndef HAVE_GLIB26
-#include "gkeyfile.h"
-#endif
-
 #include "gnc-tree-view.h"
 #include "gnc-tree-model-account.h"
 #include "gnc-tree-model-account-types.h"
 #include "gnc-tree-view-account.h"
 
 #include "Account.h"
-#include "Group.h"
 #include "gnc-accounting-period.h"
 #include "gnc-commodity.h"
 #include "gnc-component-manager.h"
 #include "gnc-engine.h"
-#include "gnc-gkeyfile-utils.h"
 #include "gnc-glib-utils.h"
 #include "gnc-gobject-utils.h"
 #include "gnc-hooks.h"
@@ -72,8 +66,6 @@ static gboolean gnc_tree_view_account_filter_helper (GtkTreeModel *model,
                                                      GtkTreeIter *iter,
                                                      gpointer data);
 
-static Account *gtva_get_top_level_from_model (GtkTreeModel *s_model);
-
 static void gtva_setup_column_renderer_edited_cb(GncTreeViewAccount *account_view,
                                                  GtkTreeViewColumn *column,
                                                  GtkCellRenderer *renderer,
@@ -291,7 +283,7 @@ sort_by_string (GtkTreeModel *f_model,
   result = safe_utf8_collate(str1, str2);
   if (result != 0)
     return result;
-  return xaccAccountOrder(&account1, &account2);
+  return xaccAccountOrder(account1, account2);
 }
 
 static gint
@@ -305,7 +297,7 @@ sort_by_code (GtkTreeModel *f_model,
   sort_cb_setup (f_model, f_iter_a, f_iter_b, &account_a, &account_b);
 
   /* Default ordering uses this column first. */
-  return xaccAccountOrder(&account_a, &account_b);
+  return xaccAccountOrder(account_a, account_b);
 }
 
 static gint
@@ -330,7 +322,7 @@ sort_by_xxx_value (xaccGetBalanceInCurrencyFn fn,
   result = gnc_numeric_compare(balance_a, balance_b);
   if (result != 0)
     return result;
-  return xaccAccountOrder(&account_a, &account_b);
+  return xaccAccountOrder(account_a, account_b);
 }
 
 static gint
@@ -413,7 +405,7 @@ sort_by_placeholder (GtkTreeModel *f_model,
     return -1;
   else if (flag_a < flag_b)
     return 1;
-  return xaccAccountOrder(&account_a, &account_b);
+  return xaccAccountOrder(account_a, account_b);
 }
 
 static gint
@@ -439,7 +431,7 @@ sort_by_xxx_period_value (GtkTreeModel *f_model,
   result = gnc_numeric_compare(b1, b2);
   if (result != 0)
     return result;
-  return xaccAccountOrder((const Account **)&acct1, (const Account **)&acct2);
+  return xaccAccountOrder(acct1, acct2);
 }
 
 static gint
@@ -471,7 +463,7 @@ sort_by_total_period_value (GtkTreeModel *f_model,
  * model.
  */
 GtkTreeView *
-gnc_tree_view_account_new_with_group (AccountGroup *group, gboolean show_root)
+gnc_tree_view_account_new_with_root (Account *root, gboolean show_root)
 {
   GncTreeView *view;
   GtkTreeModel *model, *f_model, *s_model;
@@ -487,7 +479,7 @@ gnc_tree_view_account_new_with_group (AccountGroup *group, gboolean show_root)
   priv = GNC_TREE_VIEW_ACCOUNT_GET_PRIVATE(GNC_TREE_VIEW_ACCOUNT (view));
 
   /* Create/get a pointer to the existing model for this set of books. */
-  model = gnc_tree_model_account_new (group);
+  model = gnc_tree_model_account_new (root);
 
   /* Set up the view private filter layer on the common model. */
   if (!show_root)
@@ -508,7 +500,7 @@ gnc_tree_view_account_new_with_group (AccountGroup *group, gboolean show_root)
   /* Set default visibilities */
   gtk_tree_view_set_headers_visible (GTK_TREE_VIEW(view), FALSE);
 
-  sample_type = xaccAccountGetTypeStr(CREDIT);
+  sample_type = xaccAccountGetTypeStr(ACCT_TYPE_CREDIT);
   sample_commodity = gnc_commodity_get_fullname(gnc_default_currency());
 
   priv->name_column 
@@ -684,10 +676,10 @@ gnc_tree_view_account_new_with_group (AccountGroup *group, gboolean show_root)
 GtkTreeView *
 gnc_tree_view_account_new (gboolean show_root)
 {
-  AccountGroup *group;
+  Account *root;
 
-  group = gnc_book_get_group (gnc_get_current_book ());
-  return gnc_tree_view_account_new_with_group (group, show_root);
+  root = gnc_book_get_root_account (gnc_get_current_book ());
+  return gnc_tree_view_account_new_with_root (root, show_root);
 }
 
 /************************************************************/
@@ -952,34 +944,6 @@ gnc_tree_view_account_filter_by_type_selection(Account* acct, gpointer data)
 /*           Account Tree View Get/Set Functions            */
 /************************************************************/
 
-static Account *
-gtva_get_top_level_from_model (GtkTreeModel *s_model)
-{
-  GtkTreeModel *model, *f_model;
-
-  g_return_val_if_fail (GTK_TREE_MODEL_SORT (s_model), NULL);
-
-  f_model = gtk_tree_model_sort_get_model (GTK_TREE_MODEL_SORT (s_model));
-  model = gtk_tree_model_filter_get_model (GTK_TREE_MODEL_FILTER (f_model));
-
-  return gnc_tree_model_account_get_toplevel (GNC_TREE_MODEL_ACCOUNT (model));
-}
-
-/*
- * Return the account associated with the top level pseudo-account for
- * the tree.
- */
-Account *
-gnc_tree_view_account_get_top_level (GncTreeViewAccount *view)
-{
-  GtkTreeModel *s_model;
-
-  g_return_val_if_fail (GNC_IS_TREE_VIEW_ACCOUNT (view), NULL);
-  s_model = gtk_tree_view_get_model (GTK_TREE_VIEW (view));
-
-  return gtva_get_top_level_from_model (s_model);
-}
-
 /*
  * Retrieve the selected account from an account tree view.  The
  * account tree must be in single selection mode.
@@ -1038,6 +1002,8 @@ gnc_tree_view_account_get_account_from_iter (GtkTreeModel *s_model,
   g_return_val_if_fail (GTK_IS_TREE_MODEL_SORT(s_model), NULL);
   g_return_val_if_fail (s_iter != NULL, NULL);
 
+  ENTER("model %p, iter %p", s_model, s_iter);
+
   gtk_tree_model_sort_convert_iter_to_child_iter (GTK_TREE_MODEL_SORT(s_model),
 						  &f_iter,
 						  s_iter);
@@ -1284,6 +1250,7 @@ gnc_tree_view_account_select_subaccounts (GncTreeViewAccount *view,
   GtkTreeSelection *selection;
   GtkTreePath *sp_account, *sp_start, *sp_end;
   GtkTreeIter si_account, si_start, si_end;
+  gboolean have_start, have_end;
   gint num_children;
 
   ENTER("view %p, account %p (%s)", view, account, xaccAccountGetName(account));
@@ -1313,8 +1280,19 @@ gnc_tree_view_account_select_subaccounts (GncTreeViewAccount *view,
   gtk_tree_view_expand_row (GTK_TREE_VIEW(view), sp_account, TRUE);
 
   /* compute start/end paths */
-  if (gtk_tree_model_iter_nth_child(s_model, &si_start, &si_account, 0) &&
-      gtk_tree_model_iter_nth_child(s_model, &si_end, &si_account, num_children - 1)) {
+  have_start = gtk_tree_model_iter_nth_child(s_model, &si_start, &si_account, 0);
+  si_end = si_account;
+  while (num_children) {
+    GtkTreeIter tmp_iter = si_end;
+    have_end = gtk_tree_model_iter_nth_child(s_model, &si_end, &tmp_iter,
+                                             num_children - 1);
+    if (have_end)
+      num_children = gtk_tree_model_iter_n_children(s_model, &si_end);
+    else
+      num_children = 0;
+  }
+
+  if (have_start && have_end) {
     sp_start = gtk_tree_model_get_path (s_model, &si_start);
     sp_end = gtk_tree_model_get_path (s_model, &si_end);
 
@@ -1861,7 +1839,8 @@ account_filter_dialog_create(AccountFilterDialog *fd, GncPluginPage *page)
   /* Set up the tree view and model */
   view = GTK_TREE_VIEW(glade_xml_get_widget (xml, FILTER_TREE_VIEW));
 
-  fd->model = gnc_tree_model_account_types_filter_using_mask(-1);
+  fd->model = gnc_tree_model_account_types_filter_using_mask
+    (~(1 << ACCT_TYPE_ROOT));
   gtk_tree_view_set_model(view, fd->model);
   g_object_unref (fd->model);
 
@@ -1889,12 +1868,12 @@ account_filter_dialog_create(AccountFilterDialog *fd, GncPluginPage *page)
   LEAVE(" ");
 }
 
-#define ACCT_COUNT    "Number of Open Accounts"
-#define ACCT_OPEN     "Open Account %d"
-#define ACCT_SELECTED "Selected Account"
-#define SHOW_HIDDEN   "Show Hidden"
-#define SHOW_ZERO     "Show Zero Total"
-#define ACCT_TYPES    "Account Types"
+#define ACCT_COUNT    "NumberOfOpenAccounts"
+#define ACCT_OPEN     "OpenAccount%d"
+#define ACCT_SELECTED "SelectedAccount"
+#define SHOW_HIDDEN   "ShowHidden"
+#define SHOW_ZERO     "ShowZeroTotal"
+#define ACCT_TYPES    "AccountTypes"
 
 typedef struct foo {
   GKeyFile *key_file;
@@ -2016,8 +1995,8 @@ tree_restore_expanded_row (GncTreeViewAccount *view,
   QofBook *book;
 
   book = qof_session_get_book(gnc_get_current_session());
-  account = xaccGetAccountFromFullName(xaccGetAccountGroup(book),
-				       account_name);
+  account = gnc_account_lookup_by_full_name(gnc_book_get_root_account(book),
+                                            account_name);
   if (account)
     gnc_tree_view_account_expand_to_account(view, account);
 }
@@ -2038,8 +2017,8 @@ tree_restore_selected_row (GncTreeViewAccount *view,
   QofBook *book;
 
   book = qof_session_get_book(gnc_get_current_session());
-  account = xaccGetAccountFromFullName(xaccGetAccountGroup(book),
-				       account_name);
+  account = gnc_account_lookup_by_full_name(gnc_book_get_root_account(book),
+					    account_name);
   if (account)
       gnc_tree_view_account_set_selected_account(view, account);
 }
@@ -2055,7 +2034,7 @@ gnc_tree_view_account_restore(GncTreeViewAccount *view,
     gboolean show;	
 
     /* Filter information. Ignore missing keys. */
-    show = gnc_key_file_get_boolean(key_file, group_name, SHOW_HIDDEN, &error);
+    show = g_key_file_get_boolean(key_file, group_name, SHOW_HIDDEN, &error);
     if (error) {
         g_warning("error reading group %s key %s: %s",
                   group_name, SHOW_HIDDEN, error->message);
@@ -2065,7 +2044,7 @@ gnc_tree_view_account_restore(GncTreeViewAccount *view,
     }
     fd->show_hidden = show;
     
-    show = gnc_key_file_get_boolean(key_file, group_name, SHOW_ZERO, &error);
+    show = g_key_file_get_boolean(key_file, group_name, SHOW_ZERO, &error);
     if (error) {
         g_warning("error reading group %s key %s: %s",
                   group_name, SHOW_ZERO, error->message);
@@ -2075,7 +2054,7 @@ gnc_tree_view_account_restore(GncTreeViewAccount *view,
     }
     fd->show_zero_total = show;
     
-    i = gnc_key_file_get_integer(key_file, group_name, ACCT_TYPES, &error);
+    i = g_key_file_get_integer(key_file, group_name, ACCT_TYPES, &error);
     if (error) {
         g_warning("error reading group %s key %s: %s",
                   group_name, ACCT_TYPES, error->message);
@@ -2086,11 +2065,11 @@ gnc_tree_view_account_restore(GncTreeViewAccount *view,
     fd->visible_types = i;
     
     /* Expanded accounts. Skip if count key missing. */
-    count = gnc_key_file_get_integer(key_file, group_name, ACCT_COUNT, &error);
+    count = g_key_file_get_integer(key_file, group_name, ACCT_COUNT, &error);
     if (error == NULL) {
         for (i = 1; i <= count; i++) {
 	    key = g_strdup_printf(ACCT_OPEN, i);
-	    value = gnc_key_file_get_string(key_file, group_name, key, &error);
+	    value = g_key_file_get_string(key_file, group_name, key, &error);
 	    if (error) {
                 g_warning("error reading group %s key %s: %s",
                           group_name, key, error->message);
@@ -2108,7 +2087,7 @@ gnc_tree_view_account_restore(GncTreeViewAccount *view,
     }
     
     /* Selected account (if any) */
-    value = gnc_key_file_get_string(key_file, group_name, ACCT_SELECTED, NULL);
+    value = g_key_file_get_string(key_file, group_name, ACCT_SELECTED, NULL);
     if (value) {
         tree_restore_selected_row(view, value);
         g_free(value);
@@ -2122,12 +2101,12 @@ gnc_tree_view_account_restore(GncTreeViewAccount *view,
 void
 gnc_tree_view_account_name_edited_cb(Account *account, GtkTreeViewColumn *col, const gchar *new_name)
 {
-  // check for accounts with the same name in our parent's group.
+  // check for accounts with the same name among our parent's children.
   // should probably factor this consistency check out to the account
-  // itself... or maybe the account group.
+  // itself....
   {
-    AccountGroup *parent = xaccAccountGetParent(account);
-    Account *existing = xaccGetAccountFromName(parent, new_name);
+    Account *parent = gnc_account_get_parent(account);
+    Account *existing = gnc_account_lookup_by_name(parent, new_name);
     if (existing != NULL && existing != account)
     {
       PERR("account with the same name [%s] already exists.", new_name);
