@@ -41,8 +41,7 @@
 #include "dialog-chart-export.h"
 #include "dialog-fincalc.h"
 #include "dialog-find-transactions.h"
-#include "dialog-scheduledxaction.h"
-#include "dialog-sxsincelast.h"
+#include "dialog-sx-since-last-run.h"
 #include "dialog-totd.h"
 #include "druid-acct-period.h"
 #include "druid-loan.h"
@@ -54,11 +53,10 @@
 #include "gnc-ui.h"
 #include "gnc-window.h"
 #include "gnc-session.h"
+#include "gnc-plugin-page-sx-list.h"
 
 /* This static indicates the debugging module that this .o belongs to.  */
-#ifdef QSF_IMPORT_NO_LONGER_BROKEN
 static QofLogModule log_module = GNC_MOD_GUI;
-#endif
 
 static void gnc_plugin_basic_commands_class_init (GncPluginBasicCommandsClass *klass);
 static void gnc_plugin_basic_commands_init (GncPluginBasicCommands *plugin);
@@ -69,20 +67,14 @@ static void gnc_main_window_cmd_file_new (GtkAction *action, GncMainWindowAction
 static void gnc_main_window_cmd_file_open (GtkAction *action, GncMainWindowActionData *data);
 static void gnc_main_window_cmd_file_save (GtkAction *action, GncMainWindowActionData *data);
 static void gnc_main_window_cmd_file_save_as (GtkAction *action, GncMainWindowActionData *data);
-#ifdef QSF_IMPORT_NO_LONGER_BROKEN
 static void gnc_main_window_cmd_file_qsf_import (GtkAction *action, GncMainWindowActionData *data);
-#endif
 static void gnc_main_window_cmd_file_export_accounts (GtkAction *action, GncMainWindowActionData *data);
-#ifdef QSF_EXPORT_NO_LONGER_BROKEN
 static void gnc_main_window_cmd_file_chart_export (GtkAction *action, GncMainWindowActionData *data);
-#endif
 static void gnc_main_window_cmd_edit_tax_options (GtkAction *action, GncMainWindowActionData *data);
 static void gnc_main_window_cmd_actions_mortgage_loan (GtkAction *action, GncMainWindowActionData *data);
 static void gnc_main_window_cmd_actions_scheduled_transaction_editor (GtkAction *action, GncMainWindowActionData *data);
 static void gnc_main_window_cmd_actions_since_last_run (GtkAction *action, GncMainWindowActionData *data);
-#ifdef BOOK_CLOSING_WORKS
 static void gnc_main_window_cmd_actions_close_books (GtkAction *action, GncMainWindowActionData *data);
-#endif
 static void gnc_main_window_cmd_tools_financial_calculator (GtkAction *action, GncMainWindowActionData *data);
 static void gnc_main_window_cmd_tools_find_transactions (GtkAction *action, GncMainWindowActionData *data);
 static void gnc_main_window_cmd_tools_price_editor (GtkAction *action, GncMainWindowActionData *data);
@@ -112,22 +104,20 @@ static GtkActionEntry gnc_plugin_actions [] = {
   { "FileSaveAsAction", GTK_STOCK_SAVE_AS, N_("Save _As..."), "<shift><control>s",
     NULL,
     G_CALLBACK (gnc_main_window_cmd_file_save_as) },
-#ifdef QSF_IMPORT_NO_LONGER_BROKEN
+#ifdef QSF_IMPORT_WORKS
   { "FileImportQSFAction", GTK_STOCK_CONVERT,
     N_("_QSF Import"), NULL,
     N_("Import a QSF object file"),
     G_CALLBACK (gnc_main_window_cmd_file_qsf_import) },
-#endif
+#endif // QSF_IMPORT_WORKS
   { "FileExportAccountsAction", GTK_STOCK_CONVERT,
     N_("Export _Accounts"), NULL,
     N_("Export the account hierarchy to a new GnuCash datafile"),
     G_CALLBACK (gnc_main_window_cmd_file_export_accounts) },
-#ifdef QSF_EXPORT_NO_LONGER_BROKEN
   { "FileExportChartAction", GTK_STOCK_CONVERT,
     N_("Export _Chart of Accounts to QSF"), NULL,
     N_("Export the chart of accounts for a date with balances as QSF"),
     G_CALLBACK (gnc_main_window_cmd_file_chart_export) },
-#endif
 
   /* Edit menu */
 
@@ -144,17 +134,17 @@ static GtkActionEntry gnc_plugin_actions [] = {
   { "ActionsScheduledTransactionEditorAction", NULL, N_("_Scheduled Transaction Editor"), NULL,
     N_("The list of Scheduled Transactions"),
     G_CALLBACK (gnc_main_window_cmd_actions_scheduled_transaction_editor) },
-  { "ActionsSinceLastRunAction", NULL, N_("_Since Last Run..."), NULL,
+  { "ActionsSinceLastRunAction", NULL, N_("Since _Last Run..."), NULL,
     N_("Create Scheduled Transactions since the last time run"),
     G_CALLBACK (gnc_main_window_cmd_actions_since_last_run) },
   { "ActionsMortgageLoanAction", NULL, N_("_Mortgage & Loan Repayment..."), NULL,
     N_("Setup scheduled transactions for repayment of a loan"),
     G_CALLBACK (gnc_main_window_cmd_actions_mortgage_loan) },
-#ifdef BOOK_CLOSING_WORKS
+#ifdef CLOSE_BOOKS_ACTUALLY_WORKS
   { "ActionsCloseBooksAction", NULL, N_("Close _Books"), NULL,
     N_("Archive old data using accounting periods"),
     G_CALLBACK (gnc_main_window_cmd_actions_close_books) },
-#endif
+#endif // CLOSE_BOOKS_ACTUALLY_WORKS
 
   /* Tools menu */
 
@@ -235,6 +225,10 @@ gnc_plugin_basic_commands_new (void)
 {
   GncPluginBasicCommands *plugin;
 
+  /* We just need to mention it, so the GType is registered and will be
+   * reflected during plugin-page restore. */
+  GNC_TYPE_PLUGIN_PAGE_SX_LIST;
+
   plugin = g_object_new (GNC_TYPE_PLUGIN_BASIC_COMMANDS, NULL);
 
   return GNC_PLUGIN (plugin);
@@ -359,13 +353,14 @@ gnc_main_window_cmd_file_save_as (GtkAction *action, GncMainWindowActionData *da
   gnc_window_set_progressbar_window (NULL);
   /* FIXME GNOME 2 Port (update the title etc.) */
 }
-#ifdef QSF_IMPORT_NO_LONGER_BROKEN
+
 static void
 qsf_file_select_ok(GtkWidget *w, GtkFileSelection *fs )
 {
   QofSession *qsf_session, *first_session;
-  const gchar *filename;
+  const gchar *filename, *message, *error_message;
   QofBook *original;
+  QofBackendError err;
 
   ENTER (" ");
   qof_event_suspend();
@@ -376,6 +371,22 @@ qsf_file_select_ok(GtkWidget *w, GtkFileSelection *fs )
   qsf_session = qof_session_new();
   qof_session_begin(qsf_session, filename, TRUE, FALSE);
   qof_session_load(qsf_session, NULL);
+  err = qof_session_get_error(qsf_session);
+  if (err != ERR_BACKEND_NO_ERR) {
+    error_message = qof_session_get_error_message(qsf_session);
+    if (!error_message)
+	error_message = "";
+    /* Translators: %d is the error number; %s is the error message as
+       text. */
+    message = g_strdup_printf(_("Error: Loading failed, error code %d - %s."), err, error_message);
+    PERR("%s", message);
+    qof_session_destroy(qsf_session);
+    qof_event_resume();
+    gnc_error_dialog(gnc_ui_get_toplevel(), message);
+    LEAVE (" ");
+    return;
+  }
+
   qof_event_resume();
   gnc_ui_qsf_import_merge_druid(first_session, qsf_session);
   LEAVE (" ");
@@ -397,7 +408,7 @@ gnc_main_window_cmd_file_qsf_import (GtkAction *action, GncMainWindowActionData
   gtk_widget_show (file_select);
   gnc_window_set_progressbar_window(NULL);
 }
-#endif
+
 static void
 gnc_main_window_cmd_file_export_accounts (GtkAction *action, GncMainWindowActionData *data)
 {
@@ -410,7 +421,6 @@ gnc_main_window_cmd_file_export_accounts (GtkAction *action, GncMainWindowAction
   /* gnc_refresh_main_window_info (); */
 }
 
-#ifdef QSF_EXPORT_NO_LONGER_BROKEN
 static void
 gnc_main_window_cmd_file_chart_export (GtkAction *action, GncMainWindowActionData *data)
 {
@@ -422,7 +432,6 @@ gnc_main_window_cmd_file_chart_export (GtkAction *action, GncMainWindowActionDat
   /* FIXME GNOME 2 Port (update the title etc.) */
   /* gnc_refresh_main_window_info (); */
 }
-#endif
 
 static void
 gnc_main_window_cmd_edit_tax_options (GtkAction *action, GncMainWindowActionData *data)
@@ -435,35 +444,53 @@ gnc_main_window_cmd_edit_tax_options (GtkAction *action, GncMainWindowActionData
 static void
 gnc_main_window_cmd_actions_scheduled_transaction_editor (GtkAction *action, GncMainWindowActionData *data)
 {
-  gnc_ui_scheduled_xaction_dialog_create ();
+        GncPluginPage *page = gnc_plugin_page_sx_list_new();
+        gnc_main_window_open_page(NULL, page);
 }
 
 static void
 gnc_main_window_cmd_actions_since_last_run (GtkAction *action, GncMainWindowActionData *data)
 {
   GncMainWindow *window;
-  gint ret;
+  GncSxInstanceModel *sx_instances;
+  GncSxSummary summary;
+  GList *auto_created_txns = NULL;
   const char *nothing_to_do_msg =
     _( "There are no Scheduled Transactions to be entered at this time." );
 	
   g_return_if_fail (data != NULL);
 
   window = data->window;
-  ret = gnc_ui_sxsincelast_dialog_create ();
-  if ( ret == 0 ) {
-    gnc_info_dialog (GTK_WIDGET(&window->gtk_window), nothing_to_do_msg);
-  } else if ( ret < 0 ) {
-    gnc_info_dialog (GTK_WIDGET(&window->gtk_window), ngettext
-		     /* Translators: %d is the number of transactions. This is a
-			ngettext(3) message. */
-		     ("There are no Scheduled Transactions to be entered at this time. "
-		      "(%d transaction automatically created)",
-		      "There are no Scheduled Transactions to be entered at this time. "
-		      "(%d transactions automatically created)",
-		      -(ret)),
-		     -(ret));
-  } /* else { this else [>0 means dialog was created] intentionally left
-     * blank. } */	       
+
+  sx_instances = gnc_sx_get_current_instances();
+  gnc_sx_instance_model_summarize(sx_instances, &summary);
+  gnc_sx_instance_model_effect_change(sx_instances, TRUE, &auto_created_txns, NULL);
+  if (summary.need_dialog)
+  {
+    gnc_ui_sx_since_last_run_dialog(sx_instances, auto_created_txns);
+    auto_created_txns = NULL;
+  }
+  else
+  {
+    if (summary.num_auto_create_no_notify_instances == 0)
+    {
+      gnc_info_dialog(GTK_WIDGET(&window->gtk_window), nothing_to_do_msg);
+    }
+    else
+    {
+      gnc_info_dialog(GTK_WIDGET(&window->gtk_window), ngettext
+                      /* Translators: %d is the number of transactions. This is a
+                         ngettext(3) message. */
+                      ("There are no Scheduled Transactions to be entered at this time. "
+                       "(%d transaction automatically created)",
+                       "There are no Scheduled Transactions to be entered at this time. "
+                       "(%d transactions automatically created)",
+                       summary.num_auto_create_no_notify_instances),
+                      summary.num_auto_create_no_notify_instances);
+    }
+  }
+  g_list_free(auto_created_txns);
+  g_object_unref(G_OBJECT(sx_instances));
 }
 
 static void
@@ -472,13 +499,11 @@ gnc_main_window_cmd_actions_mortgage_loan (GtkAction *action, GncMainWindowActio
   gnc_ui_sx_loan_druid_create ();
 }
 
-#ifdef BOOK_CLOSING_WORKS
 static void
 gnc_main_window_cmd_actions_close_books (GtkAction *action, GncMainWindowActionData *data)
 {
   gnc_acct_period_dialog();
 }
-#endif
 
 static void
 gnc_main_window_cmd_tools_price_editor (GtkAction *action, GncMainWindowActionData *data)
