@@ -36,9 +36,6 @@
 
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
-#ifndef HAVE_GLIB26
-#include "gkeyfile.h"
-#endif
 #include "gnc-plugin-page-account-tree.h"
 #include "gnc-plugin-page-register.h"
 
@@ -73,6 +70,9 @@ static QofLogModule log_module = GNC_MOD_GUI;
 #define PLUGIN_PAGE_ACCT_TREE_CM_CLASS "plugin-page-acct-tree"
 #define GCONF_SECTION "window/pages/account_tree"
 
+#define DELETE_DIALOG_FILTER  "filter"
+#define DELETE_DIALOG_ACCOUNT "account"
+
 enum {
   ACCOUNT_SELECTED,
   LAST_SIGNAL
@@ -158,7 +158,7 @@ static GtkActionEntry gnc_plugin_page_account_tree_actions [] = {
 	  G_CALLBACK (gnc_plugin_page_account_tree_cmd_open_subaccounts) },
 
 	/* Edit menu */
-	{ "EditEditAccountAction", GNC_STOCK_EDIT_ACCOUNT, N_("_Edit Account"), "<control>e",
+	{ "EditEditAccountAction", GNC_STOCK_EDIT_ACCOUNT, N_("Edit _Account"), "<control>e",
 	  N_("Edit the selected account"),
 	  G_CALLBACK (gnc_plugin_page_account_tree_cmd_edit_account) },
 	{ "EditDeleteAccountAction", GNC_STOCK_DELETE_ACCOUNT, N_("_Delete Account..."), NULL,
@@ -575,7 +575,7 @@ gnc_plugin_page_account_tree_recreate_page (GtkWidget *window,
 	account_page = GNC_PLUGIN_PAGE_ACCOUNT_TREE(page);
 	priv = GNC_PLUGIN_PAGE_ACCOUNT_TREE_GET_PRIVATE(account_page);
 
-	/* Install it now so we can them manipulate the created widget */
+	/* Install it now so we can then manipulate the created widget */
 	gnc_main_window_open_page(GNC_MAIN_WINDOW(window), page);
 
         gnc_tree_view_account_restore(GNC_TREE_VIEW_ACCOUNT(priv->tree_view), 
@@ -667,7 +667,7 @@ gnc_plugin_page_account_tree_selection_changed_cb (GtkTreeSelection *selection,
 		account = gnc_tree_view_account_get_selected_account (GNC_TREE_VIEW_ACCOUNT(view));
 		sensitive = (account != NULL);
 
-		subaccounts = (xaccAccountGetChildren(account) != NULL);
+		subaccounts = account && (gnc_account_n_children(account) != 0);
 		/* Check here for placeholder accounts, etc. */
 	}
 
@@ -691,7 +691,7 @@ gnc_plugin_page_account_tree_cmd_new_account (GtkAction *action, GncPluginPageAc
 {
 	Account *account = gnc_plugin_page_account_tree_get_current_account (page);
 
-	gnc_ui_new_account_window_with_default (NULL, account);
+	gnc_ui_new_account_window (gnc_get_current_book(), account);
 }
 
 static void
@@ -780,92 +780,42 @@ set_ok_sensitivity(GtkWidget *dialog)
 {
   GtkWidget *button;
   gpointer dmas, tmas;
+  gint dmas_cnt, tmas_cnt;
   gboolean sensitive;
 
   dmas = g_object_get_data(G_OBJECT(dialog), "dmas");
   tmas = g_object_get_data(G_OBJECT(dialog), "tmas");
+  dmas_cnt = gnc_account_sel_get_num_account(GNC_ACCOUNT_SEL(dmas));
+  tmas_cnt = gnc_account_sel_get_num_account(GNC_ACCOUNT_SEL(tmas));
+
   sensitive = (((NULL == dmas) ||
-		(!GTK_WIDGET_IS_SENSITIVE(GTK_WIDGET(dmas)) ||
-		 GTK_LIST(GNC_ACCOUNT_SEL(dmas)->combo->list)->children)) &&
+		(!GTK_WIDGET_IS_SENSITIVE(GTK_WIDGET(dmas)) || dmas_cnt)) &&
 	       ((NULL == tmas) ||
-		(!GTK_WIDGET_IS_SENSITIVE(GTK_WIDGET(tmas)) ||
-		 GTK_LIST(GNC_ACCOUNT_SEL(tmas)->combo->list)->children)));
+		(!GTK_WIDGET_IS_SENSITIVE(GTK_WIDGET(tmas)) || tmas_cnt)));
 
   button = gnc_glade_lookup_widget(dialog, "deletebutton");
   gtk_widget_set_sensitive(button, sensitive);
 }
 
-/***
- *** GNCAccountSel has an odd habit of adding a
- *** blank item when its list is otherwise empty.
- ***/
-
-static void
-exclude_account(GtkWidget *item,
-		gpointer name)
-{
-  char *text;
-
-  gtk_label_get(GTK_LABEL(GTK_BIN(item)->child), &text);
-  if ((0 == strlen(text)) || (0 == strcmp(text, name))) {
-    gtk_widget_destroy(GTK_WIDGET(item));
-  }
-}
-
-static void
-exclude_account_subtree(GtkWidget *item,
-			gpointer prefix)
-{
-  char *text;
-
-  gtk_label_get(GTK_LABEL(GTK_BIN(item)->child), &text);
-  if ((0 == strlen(text)) || 0 == strncmp(text, prefix, strlen(prefix))) {
-    gtk_widget_destroy(GTK_WIDGET(item));
-  }
-}
-
-static gint
-compare_listitem_text(gconstpointer item,
-		      gconstpointer entrytext)
-{
-  char *text;
-
-  gtk_label_get(GTK_LABEL(GTK_BIN(item)->child), &text);
-  return strcmp(text, entrytext);
-}
-
 static void
 gppat_populate_gas_list(GtkWidget *dialog,
 			GNCAccountSel *gas,
 			gboolean exclude_subaccounts)
 {
-  GtkList *list;
-  GtkEntry *entry;
-  gpointer name, filter;
+  Account *account;
+  GList *filter;
 
   g_return_if_fail(GTK_IS_DIALOG(dialog));
   if (gas == NULL)
     return;
-  list = GTK_LIST(gas->combo->list);
-  entry = GTK_ENTRY(gas->combo->entry);
-  name = g_object_get_data(G_OBJECT(dialog), "name");
-  filter = g_object_get_data(G_OBJECT(dialog), "filter");
+  account = g_object_get_data(G_OBJECT(dialog), DELETE_DIALOG_ACCOUNT);
+  filter = g_object_get_data(G_OBJECT(dialog), DELETE_DIALOG_FILTER);
 
   /* Setting the account type filter triggers GNCAccountSel population. */
   gnc_account_sel_set_acct_filters (gas, filter);
 
   /* Accounts to be deleted must be removed. */
-  gtk_container_foreach(GTK_CONTAINER(list), (exclude_subaccounts ?
-					      exclude_account_subtree :
-					      exclude_account), name);
-
-  /* The entry widget may need to be reset. */
-  if (NULL == g_list_find_custom(list->children, 
-				 gtk_entry_get_text(entry),
-				 compare_listitem_text)) {
-    gtk_entry_set_text(entry, "");
-    gtk_list_select_item(list, 0);
-  }
+  gnc_account_sel_purge_account( gas, account, exclude_subaccounts);
 
   /* The sensitivity of the OK button needs to be reevaluated. */
   set_ok_sensitivity(GTK_WIDGET(dialog));
@@ -895,7 +845,6 @@ gnc_plugin_page_account_tree_cmd_delete_account (GtkAction *action, GncPluginPag
   Account *account = gnc_plugin_page_account_tree_get_current_account (page);
   gchar *acct_name;
   GList *splits;
-  AccountGroup *children;
   delete_helper_t delete_res = { FALSE, FALSE };
   GtkWidget *widget;
   GtkWidget *window;
@@ -918,13 +867,12 @@ gnc_plugin_page_account_tree_cmd_delete_account (GtkAction *action, GncPluginPag
   }
 
   splits = xaccAccountGetSplitList(account);
-  children = xaccAccountGetChildren(account);
 
   /*
    * If the account has transactions or child accounts then conduct a
    * dialog to allow the user to specify what should be done with them.
    */
-  if ((NULL != splits) || (NULL != children)) {
+  if ((NULL != splits) || (gnc_account_n_children(account) > 0)) {
     GList *filter;
     GladeXML *xml;
     GtkWidget *label;
@@ -945,8 +893,8 @@ gnc_plugin_page_account_tree_cmd_delete_account (GtkAction *action, GncPluginPag
      * type as the one being deleted.
      */
     filter = g_list_prepend(NULL, (gpointer)xaccAccountGetType(account));
-    g_object_set_data(G_OBJECT(dialog), "filter", filter);
-    g_object_set_data(G_OBJECT(dialog), "name", acct_name);
+    g_object_set_data(G_OBJECT(dialog), DELETE_DIALOG_FILTER, filter);
+    g_object_set_data(G_OBJECT(dialog), DELETE_DIALOG_ACCOUNT, account);
 
     /*
      * Adjust the dialog based on whether the account has
@@ -973,12 +921,12 @@ gnc_plugin_page_account_tree_cmd_delete_account (GtkAction *action, GncPluginPag
     /*
      * Adjust the dialog based on whether the account has children.
      */
-    if (children != NULL) {
+    if (gnc_account_n_children(account) > 0) {
       /*
        * Check for RO txns in descendants
        */
-      xaccGroupForEachAccount(children, delete_account_helper,
-			      &delete_res, TRUE);
+      gnc_account_foreach_descendant_until(account, delete_account_helper,
+			      &delete_res);
       if (delete_res.has_ro_splits) {
 	gtk_widget_destroy(glade_xml_get_widget (xml, "sa_trans_rw"));
 	widget = glade_xml_get_widget (xml, "dtdrb");
@@ -1046,7 +994,7 @@ gnc_plugin_page_account_tree_cmd_delete_account (GtkAction *action, GncPluginPag
 	lines[++i] = g_strdup_printf("%s", format);
       }
     }
-    if (children) {
+    if (gnc_account_n_children(account) > 0) {
       if (daa) {
 	name = xaccAccountGetFullName(daa);
 	format = _("All of its sub-accounts will be moved to "
@@ -1056,7 +1004,7 @@ gnc_plugin_page_account_tree_cmd_delete_account (GtkAction *action, GncPluginPag
 	format = _("All of its subaccounts will be deleted.");
 	lines[++i] = g_strdup_printf("%s", format);
 	if (dta) {
-	  name = xaccAccountGetFullName(ta);
+	  name = xaccAccountGetFullName(dta);
 	  format = _("All sub-account transactions will be moved to "
 		     "the account %s.");
 	  lines[++i] = g_strdup_printf(format, name);
@@ -1089,23 +1037,23 @@ gnc_plugin_page_account_tree_cmd_delete_account (GtkAction *action, GncPluginPag
     gtk_widget_destroy(dialog);
 
     if (GTK_RESPONSE_ACCEPT == response) {
+      gnc_set_busy_cursor(NULL, TRUE);
       gnc_suspend_gui_refresh ();
       xaccAccountBeginEdit (account);
       if (NULL != daa) {
 	GList *acct_list, *ptr;
 
 	xaccAccountBeginEdit (daa);
-	acct_list = g_list_copy(xaccGroupGetAccountList(children));
+	acct_list = gnc_account_get_children(account);
 	for (ptr = acct_list; ptr; ptr = g_list_next(ptr))
-	  xaccAccountInsertSubAccount (daa, ptr->data);
+	  gnc_account_append_child (daa, ptr->data);
 	g_list_free(acct_list);
 	xaccAccountCommitEdit (daa);
       } else if (NULL != dta) {
 	/* Move the splits of its subaccounts, if any. */
-	xaccGroupForEachAccount (children,
-				 (gpointer (*)(Account *, gpointer))
-				 xaccAccountMoveAllSplits,
-				 dta, TRUE);
+	gnc_account_foreach_descendant(account,
+				       (AccountCb)xaccAccountMoveAllSplits,
+				       dta);
       }
       if (NULL != ta) {
 	/* Move the splits of the account to be deleted. */
@@ -1117,6 +1065,7 @@ gnc_plugin_page_account_tree_cmd_delete_account (GtkAction *action, GncPluginPag
        */
       xaccAccountDestroy (account);
       gnc_resume_gui_refresh ();
+      gnc_unset_busy_cursor(NULL);
     }
   }
   g_free(acct_name);
@@ -1216,7 +1165,8 @@ gnc_plugin_page_account_tree_cmd_scrub (GtkAction *action, GncPluginPageAccountT
 	xaccAccountScrubImbalance (account);
 
 	// XXX: Lots are disabled
-	//xaccAccountScrubLots (account);
+        if (g_getenv("GNC_AUTO_SCRUB_LOTS") != NULL)
+ 	    xaccAccountScrubLots(account);
 
 	gnc_resume_gui_refresh ();
 }
@@ -1234,7 +1184,8 @@ gnc_plugin_page_account_tree_cmd_scrub_sub (GtkAction *action, GncPluginPageAcco
 	xaccAccountTreeScrubImbalance (account);
 
 	// XXX: Lots are disabled
-	//xaccAccountTreeScrubLots (account);
+        if (g_getenv("GNC_AUTO_SCRUB_LOTS") != NULL)
+ 	    xaccAccountTreeScrubLots(account);
 
 	gnc_resume_gui_refresh ();
 }
@@ -1242,15 +1193,15 @@ gnc_plugin_page_account_tree_cmd_scrub_sub (GtkAction *action, GncPluginPageAcco
 static void
 gnc_plugin_page_account_tree_cmd_scrub_all (GtkAction *action, GncPluginPageAccountTree *page)
 {
-	AccountGroup *group = gnc_get_current_group ();
+	Account *root = gnc_get_current_root_account ();
 
 	gnc_suspend_gui_refresh ();
 
-	xaccGroupScrubOrphans (group);
-	xaccGroupScrubImbalance (group);
-
+	xaccAccountTreeScrubOrphans (root);
+	xaccAccountTreeScrubImbalance (root);
 	// XXX: Lots are disabled
-	//xaccGroupScrubLots (group);
+        if (g_getenv("GNC_AUTO_SCRUB_LOTS") != NULL)
+            xaccAccountTreeScrubLots(root);
 
 	gnc_resume_gui_refresh ();
 }
