@@ -39,16 +39,11 @@
 #include <glade/glade.h>
 #include "gnc-date-edit.h"
 
-#ifndef HAVE_GLIB26
-#include "gkeyfile.h"
-#endif
-
 #include "gnc-plugin-page-register.h"
 #include "gnc-budget.h"
 
 #include "dialog-options.h"
 #include "dialog-utils.h"
-#include "gnc-gkeyfile-utils.h"
 #include "gnc-gnome-utils.h"
 #include "gnc-html.h"
 #include "gnc-icons.h"
@@ -526,7 +521,7 @@ gnc_plugin_page_budget_recreate_page (GtkWidget *window, GKeyFile *key_file,
     g_return_val_if_fail(group_name, NULL);
     ENTER("key_file %p, group_name %s", key_file, group_name);
 
-    guid_str = gnc_key_file_get_string(key_file, group_name, BUDGET_GUID, 
+    guid_str = g_key_file_get_string(key_file, group_name, BUDGET_GUID, 
                                      &error);
     if (error) {
         g_warning("error reading group %s key %s: %s",
@@ -965,13 +960,19 @@ budget_col_source(Account *account, GtkTreeViewColumn *col,
     budget = GNC_BUDGET(g_object_get_data(G_OBJECT(col), "budget"));
     period_num = GPOINTER_TO_UINT(g_object_get_data(G_OBJECT(col),
                                                     "period_num"));
-    numeric = gnc_budget_get_account_period_value(budget, account, period_num);
 
-    if (gnc_numeric_zero_p(numeric))
+    if (!gnc_budget_is_account_period_value_set(budget, account, period_num)) {
         amtbuff[0] = '\0';
-    else
-        xaccSPrintAmount (amtbuff, numeric,
-                          gnc_account_print_info (account, FALSE));
+    } else {
+      numeric = gnc_budget_get_account_period_value(budget, account, 
+                                                    period_num);
+      if (gnc_numeric_check(numeric)) {
+          strcpy(amtbuff, "error");
+      } else {
+          xaccSPrintAmount(amtbuff, numeric,
+                           gnc_account_print_info(account, FALSE));
+      }
+    }
 
     return g_strdup(amtbuff);
 }
@@ -982,7 +983,7 @@ budget_col_edited(Account *account, GtkTreeViewColumn *col,
 {
     GncBudget *budget;
     guint period_num;
-    gnc_numeric numeric = gnc_numeric_zero();
+    gnc_numeric numeric = gnc_numeric_error(GNC_ERROR_ARG);
 
     if (!xaccParseAmount (new_text, TRUE, &numeric, NULL) &&
         !(new_text && *new_text == '\0'))
@@ -993,7 +994,11 @@ budget_col_edited(Account *account, GtkTreeViewColumn *col,
 
     budget = GNC_BUDGET(g_object_get_data(G_OBJECT(col), "budget"));
 
-    gnc_budget_set_account_period_value(budget, account, period_num, numeric);
+    if (new_text && *new_text == '\0')
+        gnc_budget_unset_account_period_value(budget, account, period_num);
+    else
+        gnc_budget_set_account_period_value(budget, account, period_num, 
+                                            numeric);
 }
 
 static void
