@@ -34,12 +34,11 @@
 
 #include "config.h"
 
+#include <libguile.h>
+#include "guile-mappings.h"
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
-#ifndef HAVE_GLIB26
-#include "gkeyfile.h"
-#endif
-#include <g-wrap-wct.h>
+#include "swig-runtime.h"
 
 #include "gnc-plugin-page-register.h"
 #include "gnc-plugin-register.h"
@@ -58,7 +57,6 @@
 #include "gnc-date-edit.h"
 #include "gnc-engine.h"
 #include "gnc-event.h"
-#include "gnc-gkeyfile-utils.h"
 #include "gnc-gnome-utils.h"
 #include "gnc-gobject-utils.h"
 #include "gnc-gui-query.h"
@@ -75,8 +73,6 @@
 #include "window-reconcile.h"
 #include "window-report.h"
 
-#include "gtk-compat.h"
-
 /* This static indicates the debugging module that this .o belongs to.  */
 static QofLogModule log_module = GNC_MOD_GUI;
 
@@ -99,6 +95,7 @@ static void gnc_plugin_page_register_update_edit_menu (GncPluginPage *page, gboo
 static gboolean gnc_plugin_page_register_finish_pending (GncPluginPage *page);
 
 static gchar *gnc_plugin_page_register_get_tab_name (GncPluginPage *plugin_page);
+static gchar *gnc_plugin_page_register_get_long_name (GncPluginPage *plugin_page);
 
 /* Callbacks for the "Sort By" dialog */
 void gnc_plugin_page_register_sort_button_cb(GtkToggleButton *button, GncPluginPageRegister *page);
@@ -150,10 +147,11 @@ static void gnc_plugin_page_register_cmd_transaction_report (GtkAction *action,
 
 static void gnc_plugin_page_help_changed_cb( GNCSplitReg *gsr, GncPluginPageRegister *register_page );
 static void gnc_plugin_page_register_refresh_cb (GHashTable *changes, gpointer user_data);
+static void gnc_plugin_page_register_close_cb (gpointer user_data);
 
 static void gnc_plugin_page_register_ui_update (gpointer various, GncPluginPageRegister *page);
 static void gppr_account_destroy_cb (Account *account);
-static void gnc_plugin_page_register_event_handler (QofEntity *entity,
+static void gnc_plugin_page_register_event_handler (QofInstance *entity,
 						    QofEventId event_type,
 						    GncPluginPageRegister *page,
 						    GncEventData *ed);
@@ -180,7 +178,7 @@ static GtkActionEntry gnc_plugin_page_register_actions [] =
 	{ "EditPasteAction", GTK_STOCK_PASTE, N_("_Paste"), NULL,
 	  N_("Paste the clipboard content at the cursor position"),
 	  G_CALLBACK (gnc_plugin_page_register_cmd_paste) },
-	{ "EditEditAccountAction", GNC_STOCK_EDIT_ACCOUNT, N_("Edit Account"), "<control>e",
+	{ "EditEditAccountAction", GNC_STOCK_EDIT_ACCOUNT, N_("Edit _Account"), "<control>e",
 	  N_("Edit the selected account"),
 	  G_CALLBACK (gnc_plugin_page_register_cmd_edit_account) },
 
@@ -235,7 +233,7 @@ static GtkActionEntry gnc_plugin_page_register_actions [] =
 	{ "ActionsStockSplitAction", NULL, N_("Stoc_k Split..."), NULL,
 	  N_("Record a stock split or a stock merger"),
 	  G_CALLBACK (gnc_plugin_page_register_cmd_stock_split) },
-	{ "ActionsLotsAction", NULL, N_("_Lot Viewer..."), NULL,
+	{ "ActionsLotsAction", NULL, N_("View _Lots..."), NULL,
 	  N_("Bring up the lot viewer/editor window"),
 	  G_CALLBACK (gnc_plugin_page_register_cmd_lots) },
 	{ "BlankTransactionAction", GTK_STOCK_GOTO_BOTTOM, N_("_Blank Transaction"), NULL,
@@ -250,20 +248,18 @@ static GtkActionEntry gnc_plugin_page_register_actions [] =
 	{ "ScheduleTransactionAction", GNC_STOCK_SCHEDULE, N_("Sche_dule..."), NULL,
 	  N_("Create a Scheduled Transaction with the current transaction as a template"),
 	  G_CALLBACK (gnc_plugin_page_register_cmd_schedule) },
-	{ "ScrubAllAction", NULL, N_("_All transactions"), NULL,
-	  NULL,
+	{ "ScrubAllAction", NULL, N_("_All transactions"), NULL, NULL,
 	  G_CALLBACK (gnc_plugin_page_register_cmd_scrub_all) },
-	{ "ScrubCurrentAction", NULL, N_("_This transaction"), NULL,
-	  NULL,
+	{ "ScrubCurrentAction", NULL, N_("_This transaction"), NULL, NULL,
 	  G_CALLBACK (gnc_plugin_page_register_cmd_scrub_current) },
 
 	/* Reports menu */
 
 	{ "ReportsAccountReportAction", NULL, N_("Account Report"), NULL,
-	  N_("Open a register report window for this transaction"),
+	  N_("Open a register report for this Account"),
 	  G_CALLBACK (gnc_plugin_page_register_cmd_account_report) },
 	{ "ReportsAcctTransReportAction", NULL, N_("Account Transaction Report"), NULL,
-	  N_("Open a register report window for this transaction"),
+	  N_("Open a register report for the selected Transaction"),
 	  G_CALLBACK (gnc_plugin_page_register_cmd_transaction_report) },
 };
 static guint gnc_plugin_page_register_n_actions = G_N_ELEMENTS (gnc_plugin_page_register_actions);
@@ -458,6 +454,10 @@ gnc_plugin_page_register_new_common (GNCLedgerDisplay *ledger)
 	gnc_plugin_page_set_page_name(plugin_page, label);
 	g_free(label);
 
+	label = gnc_plugin_page_register_get_long_name(plugin_page);
+        gnc_plugin_page_set_page_long_name(plugin_page, label);
+        g_free(label);
+
 	q = gnc_ledger_display_get_query (ledger);
 	book_list = qof_query_get_books (q);
 	for (item = book_list; item; item = g_list_next(item))
@@ -752,7 +752,8 @@ gnc_plugin_page_register_create_widget (GncPluginPage *plugin_page)
 	priv->component_manager_id =
 	  gnc_register_gui_component(GNC_PLUGIN_PAGE_REGISTER_NAME,
 				     gnc_plugin_page_register_refresh_cb,
-				     NULL, page);
+				     gnc_plugin_page_register_close_cb,
+				     page);
 	gnc_gui_component_set_session (priv->component_manager_id,
 				       gnc_get_current_session());
 	acct = gnc_plugin_page_register_get_account(page);
@@ -830,10 +831,10 @@ static const gchar *style_names[] = {
   NULL
 };
 
-#define KEY_REGISTER_TYPE	"Register Type"
-#define KEY_ACCOUNT_NAME	"Account Name"
-#define KEY_REGISTER_STYLE	"Register Style"
-#define KEY_DOUBLE_LINE		"Double Line Mode"
+#define KEY_REGISTER_TYPE       "RegisterType"
+#define KEY_ACCOUNT_NAME        "AccountName"
+#define KEY_REGISTER_STYLE      "RegisterStyle"
+#define KEY_DOUBLE_LINE         "DoubleLineMode"
 
 #define LABEL_ACCOUNT		"Account"
 #define LABEL_SUBACCOUNT	"SubAccount"
@@ -932,7 +933,7 @@ gnc_plugin_page_register_restore_edit_menu (GncPluginPage *page,
   priv = GNC_PLUGIN_PAGE_REGISTER_GET_PRIVATE(page);
 
   /* Convert the style name to an index */
-  style_name = gnc_key_file_get_string(key_file, group_name,
+  style_name = g_key_file_get_string(key_file, group_name,
 				     KEY_REGISTER_STYLE, &error);
   for (i = 0 ; style_names[i]; i++) {
     if (g_ascii_strcasecmp(style_name, style_names[i]) == 0) {
@@ -951,7 +952,7 @@ gnc_plugin_page_register_restore_edit_menu (GncPluginPage *page,
 
   /* Update the  double line action on this page */
   use_double_line =
-    gnc_key_file_get_boolean(key_file, group_name, KEY_DOUBLE_LINE, &error);
+    g_key_file_get_boolean(key_file, group_name, KEY_DOUBLE_LINE, &error);
   DEBUG("Setting double_line_mode: %d", use_double_line);
   action = gnc_plugin_page_get_action(page, "ViewStyleDoubleLineAction");
   gtk_toggle_action_set_active(GTK_TOGGLE_ACTION(action), use_double_line);
@@ -986,18 +987,18 @@ gnc_plugin_page_register_recreate_page (GtkWidget *window,
   ENTER("key_file %p, group_name %s", key_file, group_name);
 
   /* Create the new page. */
-  reg_type = gnc_key_file_get_string(key_file, group_name,
+  reg_type = g_key_file_get_string(key_file, group_name,
 					 KEY_REGISTER_TYPE, &error);
   DEBUG("Page type: %s", reg_type);
   if ((g_ascii_strcasecmp(reg_type, LABEL_ACCOUNT) == 0) ||
       (g_ascii_strcasecmp(reg_type, LABEL_SUBACCOUNT) == 0)) {
     include_subs = (g_ascii_strcasecmp(reg_type, LABEL_SUBACCOUNT) == 0);
     DEBUG("Include subs: %d", include_subs);
-    acct_name = gnc_key_file_get_string(key_file, group_name,
+    acct_name = g_key_file_get_string(key_file, group_name,
 				      KEY_ACCOUNT_NAME, &error);
     book = qof_session_get_book(gnc_get_current_session());
-    account = xaccGetAccountFromFullName(xaccGetAccountGroup(book),
-					 acct_name);
+    account = gnc_account_lookup_by_full_name(gnc_book_get_root_account(book),
+					      acct_name);
     g_free(acct_name);
     if (account == NULL) {
       LEAVE("Bad account name");
@@ -1158,6 +1159,37 @@ gnc_plugin_page_register_get_tab_name (GncPluginPage *plugin_page)
 	return g_strdup(_("unknown"));
 }
 
+static gchar *
+gnc_plugin_page_register_get_long_name (GncPluginPage *plugin_page)
+{
+	GncPluginPageRegisterPrivate *priv;
+	GNCLedgerDisplayType ledger_type;
+  	GNCLedgerDisplay *ld;
+	SplitRegister *reg;
+	Account *leader;
+
+	g_return_val_if_fail (GNC_IS_PLUGIN_PAGE_REGISTER (plugin_page), _("unknown"));
+
+	priv = GNC_PLUGIN_PAGE_REGISTER_GET_PRIVATE(plugin_page);
+	ld = priv->ledger;
+	reg = gnc_ledger_display_get_split_register (ld);
+	ledger_type = gnc_ledger_display_type (ld);
+	leader = gnc_ledger_display_leader (ld);
+
+	switch (ledger_type) {
+	 case LD_SINGLE:
+	  return g_strdup(xaccAccountGetFullName (leader));
+
+	 case LD_SUBACCOUNT:
+	  return g_strdup_printf("%s+", xaccAccountGetFullName (leader));
+
+	 default:
+	  break;
+	}
+
+        return NULL;
+}
+
 /************************************************************/
 /*                     "Sort By" Dialog                     */
 /************************************************************/
@@ -1726,7 +1758,7 @@ report_helper (GNCLedgerDisplay *ledger, Split *split, Query *query)
   SplitRegister *reg = gnc_ledger_display_get_split_register (ledger);
   Account *account;
   char *str;
-  SCM qtype;
+  swig_type_info * qtype;
   SCM args;
   SCM func;
   SCM arg;
@@ -1759,19 +1791,19 @@ report_helper (GNCLedgerDisplay *ledger, Split *split, Query *query)
     g_return_val_if_fail (query != NULL, -1);
   }
 
-  qtype = scm_c_eval_string("<gnc:Query*>");
-  g_return_val_if_fail (qtype != SCM_UNDEFINED, -1);
+  qtype = SWIG_TypeQuery ("_p__QofQuery");
+  g_return_val_if_fail (qtype, -1);
 
-  arg = gw_wcp_assimilate_ptr (query, qtype);
+  arg = SWIG_NewPointerObj (query, qtype, 0);
   args = scm_cons (arg, args);
   g_return_val_if_fail (arg != SCM_UNDEFINED, -1);
 
 
   if (split)
   {
-    qtype = scm_c_eval_string("<gnc:Split*>");
-    g_return_val_if_fail (qtype != SCM_UNDEFINED, -1);
-    arg = gw_wcp_assimilate_ptr (split, qtype);
+    qtype = SWIG_TypeQuery ("_p_Split");
+    g_return_val_if_fail (qtype, -1);
+    arg = SWIG_NewPointerObj (split, qtype, 0);
   }
   else
   {
@@ -1781,11 +1813,11 @@ report_helper (GNCLedgerDisplay *ledger, Split *split, Query *query)
   g_return_val_if_fail (arg != SCM_UNDEFINED, -1);
 
 
-  qtype = scm_c_eval_string("<gnc:Account*>");
-  g_return_val_if_fail (qtype != SCM_UNDEFINED, -1);
+  qtype = SWIG_TypeQuery ("_p_Account");
+  g_return_val_if_fail (qtype, -1);
 
   account = gnc_ledger_display_leader (ledger);
-  arg = gw_wcp_assimilate_ptr (account, qtype);
+  arg = SWIG_NewPointerObj (account, qtype, 0);
   args = scm_cons (arg, args);
   g_return_val_if_fail (arg != SCM_UNDEFINED, -1);
 
@@ -1809,10 +1841,6 @@ gnc_plugin_page_register_cmd_print_check (GtkAction *action,
   SplitRegister * reg;
   Split         * split;
   Transaction   * trans;
-  const char    * payee;
-  const char    * memo;
-  gnc_numeric   amount;
-  time_t        date;
 
 
   ENTER("(action %p, plugin_page %p)", action, plugin_page);
@@ -1826,15 +1854,7 @@ gnc_plugin_page_register_cmd_print_check (GtkAction *action,
 
   if(split && trans)
   {
-    payee  = xaccTransGetDescription(trans);
-    memo   = xaccTransGetNotes(trans);
-    if (memo == NULL)
-      memo = "";
-    amount = xaccSplitGetAmount(split);
-    amount = gnc_numeric_abs (amount);
-    date   = xaccTransGetDate(trans);
-
-    gnc_ui_print_check_dialog_create(plugin_page, payee, amount, date, memo);
+    gnc_ui_print_check_dialog_create(plugin_page, split);
   }
   LEAVE(" ");
 }
@@ -2576,7 +2596,7 @@ gnc_plugin_page_register_cmd_scrub_current (GtkAction *action,
 {
   GncPluginPageRegisterPrivate *priv;
   Query *query;
-  AccountGroup *root;
+  Account *root;
   Transaction *trans;
   SplitRegister *reg;
 
@@ -2599,7 +2619,7 @@ gnc_plugin_page_register_cmd_scrub_current (GtkAction *action,
   }
 
   gnc_suspend_gui_refresh();
-  root = gnc_get_current_group();
+  root = gnc_get_current_root_account();
   xaccTransScrubOrphans(trans);
   xaccTransScrubImbalance(trans, root, NULL);
   gnc_resume_gui_refresh();
@@ -2612,7 +2632,7 @@ gnc_plugin_page_register_cmd_scrub_all (GtkAction *action,
 {
   GncPluginPageRegisterPrivate *priv;
   Query *query;
-  AccountGroup *root;
+  Account *root;
   Transaction *trans;
   Split *split;
   GList *node;
@@ -2629,7 +2649,7 @@ gnc_plugin_page_register_cmd_scrub_all (GtkAction *action,
   }
 
   gnc_suspend_gui_refresh();
-  root = gnc_get_current_group();
+  root = gnc_get_current_root_account();
 
   for (node = xaccQueryGetSplits(query); node; node = node->next)
   {
@@ -2794,6 +2814,13 @@ gnc_plugin_page_register_refresh_cb (GHashTable *changes, gpointer user_data)
   gnc_plugin_page_register_ui_update(NULL, page);
 }
 
+static void
+gnc_plugin_page_register_close_cb (gpointer user_data)
+{
+  GncPluginPage *plugin_page = GNC_PLUGIN_PAGE(user_data);
+  gnc_main_window_close_page (plugin_page);
+}
+
 /** This function is called when an account has been edited and an
  *  "extreme" change has been made to it.  (E.G. Changing from a
  *  credit card account to an expense account.  This rouine is
@@ -2853,7 +2880,7 @@ gppr_account_destroy_cb (Account *account)
  *  @param ed
  */
 static void
-gnc_plugin_page_register_event_handler (QofEntity *entity,
+gnc_plugin_page_register_event_handler (QofInstance *entity,
 					QofEventId event_type,
 					GncPluginPageRegister *page,
 					GncEventData *ed)
