@@ -31,8 +31,8 @@
 #include "config.h"
 
 #include <gtk/gtk.h>
-#include "gtk-compat.h"
 #include <glib/gi18n.h>
+#include "glib-compat.h"
 
 #include "Scrub.h"
 #include "Scrub3.h"
@@ -117,14 +117,14 @@ typedef struct _startRecnWindowData
  * change!  These macros define the account types for which an auto interest
  * xfer dialog could pop up, if the user's preferences allow it.
  */
-#define account_type_has_auto_interest_charge(type)  (((type) == CREDIT) || \
-                                                      ((type) == LIABILITY) ||\
-						      ((type) == PAYABLE))
+#define account_type_has_auto_interest_charge(type)  (((type) == ACCT_TYPE_CREDIT) || \
+                                                      ((type) == ACCT_TYPE_LIABILITY) ||\
+						      ((type) == ACCT_TYPE_PAYABLE))
 
-#define account_type_has_auto_interest_payment(type) (((type) == BANK)  || \
-                                                      ((type) == ASSET) || \
-                                                      ((type) == MUTUAL) || \
-						      ((type) == RECEIVABLE))
+#define account_type_has_auto_interest_payment(type) (((type) == ACCT_TYPE_BANK)  || \
+                                                      ((type) == ACCT_TYPE_ASSET) || \
+                                                      ((type) == ACCT_TYPE_MUTUAL) || \
+						      ((type) == ACCT_TYPE_RECEIVABLE))
 
 #define account_type_has_auto_interest_xfer(type) \
   (  account_type_has_auto_interest_charge(type) || \
@@ -655,6 +655,7 @@ startRecnWindow(GtkWidget *parent, Account *account,
   /* Create the dialog box */
   xml = gnc_glade_xml_new ("reconcile.glade", "Reconcile Start Dialog");
   dialog = glade_xml_get_widget (xml, "Reconcile Start Dialog");
+  glade_xml_signal_autoconnect_full(xml, gnc_glade_autoconnect_full_func, &data);
   title = gnc_recn_make_window_name (account);
   gtk_window_set_title(GTK_WINDOW(dialog), title);
   g_free (title);
@@ -722,7 +723,7 @@ startRecnWindow(GtkWidget *parent, Account *account,
     else if( account_type_has_auto_interest_charge( data.account_type ) )
       gtk_button_set_label(GTK_BUTTON(interest), _("Enter _Interest Charge...") );
     else {
-      gtk_widget_hide(interest);
+      gtk_widget_destroy(interest);
       interest = NULL;
     }
 
@@ -733,9 +734,6 @@ startRecnWindow(GtkWidget *parent, Account *account,
        gtk_widget_set_sensitive(GTK_WIDGET(interest), FALSE);
     }
 
-    glade_xml_signal_autoconnect_full(xml, gnc_glade_autoconnect_full_func,
-				      &data);
-
     gtk_widget_show_all(dialog);
 
     gtk_widget_grab_focus(gnc_amount_edit_gtk_entry
@@ -754,7 +752,7 @@ startRecnWindow(GtkWidget *parent, Account *account,
   if (result == GTK_RESPONSE_OK)
   {
     *new_ending = gnc_amount_edit_get_amount (GNC_AMOUNT_EDIT (end_value));
-    *statement_date = gnc_date_edit_get_date(GNC_DATE_EDIT(date_value));
+    *statement_date = gnc_date_edit_get_date_end(GNC_DATE_EDIT(date_value));
 
     if (gnc_reverse_balance(account))
       *new_ending = gnc_numeric_neg (*new_ending);
@@ -980,7 +978,7 @@ gnc_reconcile_window_set_titles(RecnWindow *recnData)
   if (formal)
     title = _("Debits");
   else
-    title = gnc_get_debit_string(NO_TYPE);
+    title = gnc_get_debit_string(ACCT_TYPE_NONE);
 
   gtk_frame_set_label(GTK_FRAME(recnData->debit_frame), title);
 
@@ -990,7 +988,7 @@ gnc_reconcile_window_set_titles(RecnWindow *recnData)
   if (formal)
     title = _("Credits");
   else
-    title = gnc_get_credit_string(NO_TYPE);
+    title = gnc_get_credit_string(ACCT_TYPE_NONE);
 
   gtk_frame_set_label(GTK_FRAME(recnData->credit_frame), title);
 
@@ -1229,7 +1227,8 @@ gnc_recn_scrub_cb(GtkAction *action, gpointer data)
   xaccAccountTreeScrubImbalance (account);
 
   // XXX: Lots are disabled.
-  //xaccAccountTreeScrubLots (account);
+  if (g_getenv("GNC_AUTO_SCRUB_LOTS") != NULL)
+      xaccAccountTreeScrubLots(account);
 
   gnc_resume_gui_refresh ();
 }
@@ -1285,30 +1284,36 @@ gnc_get_reconcile_info (Account *account,
                         gnc_numeric *new_ending,
                         time_t *statement_date)
 {
+  GDate date;
   time_t today;
   struct tm tm;
 
+  g_date_clear(&date, 1);
+
   if (xaccAccountGetReconcileLastDate (account, statement_date))
   {
     int months = 1, days = 0;
 
-    tm = * localtime (statement_date);
+    g_date_set_time_t(&date, *statement_date);
 
-    /* How far should the date be moved?  Args unchanged on failure. */
     xaccAccountGetReconcileLastInterval (account, &months, &days);
 
     if (months) {
-      /*
-       * Add in the months and normalize
-       */
-      date_add_months(&tm, months, TRUE);
+      gboolean was_last_day_of_month = g_date_is_last_of_month(&date);
+
+      g_date_add_months(&date, months);
+
+      /* Track last day of the month, i.e. 1/31 -> 2/28 -> 3/31 */ 
+      if (was_last_day_of_month)
+      {
+        g_date_set_day(&date, g_date_get_days_in_month(g_date_get_month(&date),
+                                                       g_date_get_year(&date)));
+      }
     } else {
-      /*
-       * Add in the days (weeks if multiple of seven).
-       */
-      tm.tm_mday += days;
+      g_date_add_days(&date, days);
     }
-    tm.tm_isdst = -1;
+
+    g_date_to_struct_tm(&date, &tm);
     gnc_tm_set_day_end (&tm);
     *statement_date = mktime (&tm);
 
@@ -1393,7 +1398,7 @@ recn_set_watches (RecnWindow *recnData)
 
   include_children = xaccAccountGetReconcileChildrenStatus(account);
   if (include_children)
-    accounts = xaccAccountGetDescendants(account);
+    accounts = gnc_account_get_descendants(account);
 
   /* match the account */
   accounts = g_list_prepend (accounts, account);
@@ -1848,7 +1853,8 @@ find_payment_account(Account *account)
         continue;
 
       type = xaccAccountGetType(a);
-      if ((type == BANK) || (type == CASH) || (type == ASSET))
+      if ((type == ACCT_TYPE_BANK) || (type == ACCT_TYPE_CASH) ||
+	  (type == ACCT_TYPE_ASSET))
         return a;
     }
   }
@@ -1898,7 +1904,7 @@ recnFinishCB (GtkAction *action, RecnWindow *recnData)
   xaccAccountSetReconcileLastDate (account, date);
 
   if (auto_payment &&
-      (xaccAccountGetType (account) == CREDIT) &&
+      (xaccAccountGetType (account) == ACCT_TYPE_CREDIT) &&
       (gnc_numeric_negative_p (recnData->new_ending)))
   {
     Account *payment_account;
