@@ -1,6 +1,7 @@
 /********************************************************************\
  * druid-hbci-initial.c -- hbci creation functionality              *
  * Copyright (C) 2002 Christian Stimming                            *
+ * Copyright (c) 2006 David Hampton <hampton@employees.org>         *
  *                                                                  *
  * This program is free software; you can redistribute it and/or    *
  * modify it under the terms of the GNU General Public License as   *
@@ -24,9 +25,12 @@
 
 #include <gnome.h>
 #include <glib/gi18n.h>
+#include <glib/gstdio.h>
 #include <sys/types.h>
 #include <sys/stat.h>
-#include <sys/wait.h>
+#ifdef HAVE_SYS_WAIT_H
+#    include <sys/wait.h>
+#endif
 #include <fcntl.h>
 #include <unistd.h>
 
@@ -44,14 +48,25 @@
 #include "gnc-html.h"
 //#include "import-account-matcher.h"
 #include "gnc-component-manager.h"
+#include "gnc-session.h"
 
 #include <aqbanking/banking.h>
 #include <aqbanking/version.h>
 #include <gwenhywfar/stringlist.h>
 #include <gwenhywfar/version.h>
 
+#define DRUID_HBCI_IMPORT_CM_CLASS "druid-hbci-import"
 /* #define DEFAULT_HBCI_VERSION 201 */
 
+enum account_list_cols {
+  ACCOUNT_LIST_COL_INDEX = 0,
+  ACCOUNT_LIST_COL_HBCI_NAME,
+  ACCOUNT_LIST_COL_HBCI_ACCT,
+  ACCOUNT_LIST_COL_GNC_NAME,
+  ACCOUNT_LIST_COL_CHECKED,
+  NUM_ACCOUNT_LIST_COLS
+};
+
 struct _hbciinitialinfo 
 {
   GtkWidget *window;
@@ -62,34 +77,23 @@ struct _hbciinitialinfo
   
   /* account match page */
   GtkWidget *accountpage;
-  GtkWidget *accountlist;
+  GtkTreeView *accountview;
+  GtkListStore *accountstore;
     
   /* OpenHBCI stuff */
   AB_BANKING *api;
   GNCInteractor *interactor;
 
-  /* account match: row_number (int) -> hbci_account */
-  GHashTable *hbci_hash;
   /* hbci_account (direct) -> gnucash_account  -- DO NOT DELETE THE KEYS! */
   GHashTable *gnc_hash;
 
 };
 
-static gboolean
-hash_remove (gpointer key, gpointer value, gpointer user_data) 
-{
-  free (key);
-  return TRUE;
-}
+/* Is TRUE as long as the druid is opened and running. Is being
+   used to catch a window close event during waiting for a child
+   process. */
+static gboolean hbci_druid_is_active = FALSE;
 
-static void
-delete_hash (GHashTable *hash) 
-{
-  if (hash != NULL) {
-    g_hash_table_foreach_remove (hash, &hash_remove, NULL);
-    g_hash_table_destroy (hash);
-  }
-}
 static void
 reset_initial_info (HBCIInitialInfo *info)
 {
@@ -100,8 +104,6 @@ reset_initial_info (HBCIInitialInfo *info)
   }
   info->api = NULL;
 
-  delete_hash (info->hbci_hash);
-  info->hbci_hash = NULL;
   if (info->gnc_hash != NULL)
     g_hash_table_destroy (info->gnc_hash);
   info->gnc_hash = NULL;
@@ -112,6 +114,8 @@ delete_initial_druid (HBCIInitialInfo *info)
 {
   if (info == NULL) return;
 
+  gnc_unregister_gui_component_by_data(DRUID_HBCI_IMPORT_CM_CLASS, info);
+
   reset_initial_info (info);
   
   /* if (info->interactor)
@@ -120,6 +124,7 @@ delete_initial_druid (HBCIInitialInfo *info)
   if (info->window != NULL) 
     gtk_widget_destroy (info->window);
 
+  hbci_druid_is_active = FALSE;
   g_free (info);
 }
 
@@ -155,48 +160,47 @@ static AB_ACCOUNT *
 update_accountlist_acc_cb (AB_ACCOUNT *hacc, gpointer user_data)
 {
   HBCIInitialInfo *info = user_data;
-  gchar *row_text[3];
+  gchar *gnc_name, *hbci_name;
   Account *gacc;
-  int row;
-  gint *row_key;
+  GtkTreeIter iter;
 
   g_assert(hacc);
   g_assert(info);
-  row_text[2] = "";
-  
-  row_text[0] = gnc_hbci_account_longname(hacc);
+
+  hbci_name = gnc_hbci_account_longname(hacc);
 		
   /* Get corresponding gnucash account */
   gacc = g_hash_table_lookup (info->gnc_hash, hacc);
 
   /* Build the text for the gnucash account. */
   if (gacc == NULL)
-    row_text[1] = "";
+    gnc_name = g_strdup("");
   else 
-    row_text[1] = xaccAccountGetFullName (gacc);
+    gnc_name = xaccAccountGetFullName (gacc);
 
-  /* Add this row to the list */
-  row = gtk_clist_append (GTK_CLIST (info->accountlist), row_text);
-
-  /* Set the "new" checkbox. */
-  gnc_clist_set_check (GTK_CLIST (info->accountlist), row, 2,
-		       FALSE);
-
-  /* Store the row_number -> hbci_account hash reference. */
-  row_key = g_new(gint, 1);
-  *row_key = row;
-  g_hash_table_insert (info->hbci_hash, row_key, (AB_ACCOUNT*)hacc);
+  gtk_list_store_append(info->accountstore, &iter);
+  gtk_list_store_set(info->accountstore, &iter,
+		     ACCOUNT_LIST_COL_HBCI_NAME, hbci_name,
+		     ACCOUNT_LIST_COL_HBCI_ACCT, hacc,
+		     ACCOUNT_LIST_COL_GNC_NAME, gnc_name,
+		     ACCOUNT_LIST_COL_CHECKED, FALSE,
+		     -1);
 
+  g_free(gnc_name);
+  g_free(hbci_name);
   return NULL;
 }
 
-/* Update the account list GtkCList widget */
+/* Update the account list GtkListStore widget */
 static void
 update_accountlist (HBCIInitialInfo *info)
 {
-  int sel_row = 0;
   AB_BANKING *banking;
   AB_ACCOUNT_LIST2 *acclist;
+  GtkTreeModel *model;
+  GtkTreeSelection *selection;
+  GtkTreeIter iter;
+  GtkTreePath *path = NULL;
 
   g_assert(info);
   banking = info->api;
@@ -204,15 +208,12 @@ update_accountlist (HBCIInitialInfo *info)
   g_assert(info->gnc_hash);
 
   /* Store old selected row here. */
-  sel_row = (GTK_CLIST(info->accountlist))->focus_row;
+  selection = gtk_tree_view_get_selection(info->accountview);
+  if (gtk_tree_selection_get_selected(selection, &model, &iter))
+    path = gtk_tree_model_get_path(model, &iter);
 
   /* Delete old list */
-  gtk_clist_freeze (GTK_CLIST (info->accountlist));
-  gtk_clist_clear (GTK_CLIST (info->accountlist));
-
-  /* Delete old hash with row_number -> hbci_account */
-  delete_hash (info->hbci_hash);
-  info->hbci_hash = g_hash_table_new (&g_int_hash, &g_int_equal);
+  gtk_list_store_clear(info->accountstore);
   
   /* Go through all HBCI accounts */
   acclist = AB_Banking_GetAccounts(banking);
@@ -221,16 +222,15 @@ update_accountlist (HBCIInitialInfo *info)
 			      update_accountlist_acc_cb,
 			      info);
   else
-    printf("update_accountlist: Oops, account list from AB_Banking is NULL.\n");
+    g_warning("update_accountlist: Oops, account list from AB_Banking is NULL.\n");
 
-  /* printf("update_accountlist: HBCI hash has %d entries.\n", g_hash_table_size(info->hbci_hash)); */
-  /* printf("update_accountlist: GNC hash has %d entries.\n", g_hash_table_size(info->gnc_hash)); */
-  
-  gtk_clist_thaw (GTK_CLIST (info->accountlist));
+  /* g_message("update_accountlist: GNC hash has %d entries.\n", g_hash_table_size(info->gnc_hash)); */
 
-  /* move to the old selected row */
-  (GTK_CLIST(info->accountlist))->focus_row = sel_row;
-  gtk_clist_moveto(GTK_CLIST(info->accountlist), sel_row, 0, 0.0, 0.0);
+  if (path) {
+    gtk_tree_selection_select_path(selection, path);
+    gtk_tree_view_scroll_to_cell(info->accountview, path, NULL, FALSE, 0.0, 0.0);
+    gtk_tree_path_free(path);
+  }
 }
 /*
  * end update_accountlist 
@@ -283,8 +283,7 @@ static gboolean banking_has_accounts(AB_BANKING *banking)
 
 
 static void
-on_cancel (GnomeDruid *gnomedruid,
-	   gpointer user_data)
+cm_close_handler(gpointer user_data)
 {
   HBCIInitialInfo *info = user_data;
 
@@ -294,6 +293,13 @@ on_cancel (GnomeDruid *gnomedruid,
   delete_initial_druid(info);
 }
 
+static void
+on_cancel (GnomeDruid *gnomedruid,
+	   gpointer user_data)
+{
+  cm_close_handler(user_data);
+}
+
 static void
 on_finish (GnomeDruidPage *gnomedruidpage,
 	   gpointer arg1,
@@ -349,23 +355,30 @@ on_accountlist_prepare (GnomeDruidPage *gnomedruidpage,
 
 
 static void
-on_accountlist_select_row (GtkCList *clist, gint row,
-			   gint column, GdkEvent *event,
-			   gpointer user_data)
+on_accountlist_changed (GtkTreeSelection *selection,
+			gpointer          user_data)     
 {
   HBCIInitialInfo *info = user_data;
   AB_ACCOUNT *hbci_acc;
   Account *gnc_acc, *old_value;
-  gchar *longname;
+  gchar *longname, *gnc_name;
   gnc_commodity *currency = NULL;
+  GtkTreeModel *model;
+  GtkTreeIter iter;
   
-  hbci_acc = g_hash_table_lookup (info->hbci_hash, &row);
+  if (!gtk_tree_selection_get_selected(selection, &model, &iter))
+    return;
+  gtk_tree_selection_unselect_iter(selection, &iter);
+  gtk_tree_model_get(model, &iter,
+		     ACCOUNT_LIST_COL_HBCI_ACCT, &hbci_acc,
+		     -1);
+
   if (hbci_acc) {
     old_value = g_hash_table_lookup (info->gnc_hash, hbci_acc);
 
-    printf("on_accountlist_select_row: Selected hbci_acc id %s; old_value %p \n",
+    /* g_message("on_accountlist_select_row: Selected hbci_acc id %s; old_value %p \n",
 	   AB_Account_GetAccountNumber(hbci_acc),
-	   old_value);
+	   old_value); */
 
     longname = gnc_hbci_account_longname(hbci_acc);
     if (AB_Account_GetCurrency (hbci_acc) && 
@@ -376,26 +389,42 @@ on_accountlist_select_row (GtkCList *clist, gint row,
     }
 
     gnc_acc = gnc_import_select_account(info->window,
-					NULL, TRUE, longname, currency, BANK,
-					old_value, NULL);
+					NULL, TRUE, longname, currency,
+					ACCT_TYPE_BANK, old_value, NULL);
     g_free(longname);
 
     if (gnc_acc) {
       if (old_value) 
 	g_hash_table_remove (info->gnc_hash, hbci_acc);
-      
       g_hash_table_insert (info->gnc_hash, hbci_acc, gnc_acc);
+      gnc_name = xaccAccountGetFullName (gnc_acc);
+      gtk_list_store_set(info->accountstore, &iter,
+			 ACCOUNT_LIST_COL_GNC_NAME, gnc_name,
+			 -1);
+      g_free(gnc_name);
+    } else {
+      gtk_list_store_set(info->accountstore, &iter,
+			 ACCOUNT_LIST_COL_GNC_NAME, "",
+			 -1);
     }
-    
-    /* update display */
-    update_accountlist(info);
   } /* hbci_acc */
 }
 
 
 
+static void
+on_child_exit (GPid pid, gint status, gpointer data)
+{
+  gint *data_status = data;
+#ifdef G_OS_WIN32
+  *data_status = status;
+#else
+  *data_status = WEXITSTATUS (status);
+#endif
 
-
+  g_spawn_close_pid (pid);
+  gtk_main_quit ();
+}
 
 
 #if (AQBANKING_VERSION_MAJOR > 1) || \
@@ -421,14 +450,15 @@ on_aqhbci_button (GtkButton *button,
 
   /* This is the point where we look for and start an external
      application shipped with aqhbci that contains the setup druid for
-     HBCI related stuff. It requires qt (but not kde). This
+     AqBanking related stuff. It requires qt (but not kde). This
      application contains the very verbose step-by-step setup wizard
-     for the HBCI account, and the application is shared with other
-     AqBanking-based financial managers that offer the HBCI features
+     for the AqBanking account, and the application is shared with other
+     AqBanking-based financial managers that offer the AqBanking features
      (e.g. KMyMoney). See gnucash-devel discussion here
      https://lists.gnucash.org/pipermail/gnucash-devel/2004-December/012351.html
   */
   gboolean wizard_exists;
+  gboolean qt_probably_unavailable = FALSE;
   const char *wizard_path;
   AB_BANKING *banking = info->api;
   g_assert(info->druid);
@@ -482,13 +512,15 @@ on_aqhbci_button (GtkButton *button,
 
       /* User pressed cancel in choice dialog */
       if (x == -1) {
-	GWEN_PluginDescription_List2_freeAll(pluginlist);
+	if (pluginlist)
+	  GWEN_PluginDescription_List2_freeAll(pluginlist);
 #if ((GWENHYWFAR_VERSION_MAJOR < 1) || \
      ((GWENHYWFAR_VERSION_MAJOR == 1) && \
       ((GWENHYWFAR_VERSION_MINOR < 98))))
 	/* Memory cleanup needed for gwenhywfar<1.98.x but not for
 	   gwenhywfar>=1.98.x */
-	GWEN_PluginDescription_List2_free(pluginlist);
+	if (pluginlist)
+	  GWEN_PluginDescription_List2_free(pluginlist);
 #endif
 	return;
       }
@@ -507,13 +539,15 @@ on_aqhbci_button (GtkButton *button,
   /* Allocate the backend name again because the PluginDescr list will
      be freed */
   backend_name = g_strdup (backend_name_nc);
-  GWEN_PluginDescription_List2_freeAll (pluginlist);
+  if (pluginlist)
+    GWEN_PluginDescription_List2_freeAll (pluginlist);
 #if ((GWENHYWFAR_VERSION_MAJOR < 1) || \
      ((GWENHYWFAR_VERSION_MAJOR == 1) && \
       ((GWENHYWFAR_VERSION_MINOR < 98))))
   /* Memory cleanup needed for gwenhywfar<1.98.x but not for
      gwenhywfar>=1.98.x */
-  GWEN_PluginDescription_List2_free (pluginlist);
+  if (pluginlist)
+    GWEN_PluginDescription_List2_free (pluginlist);
 #endif
   }
 
@@ -531,56 +565,81 @@ on_aqhbci_button (GtkButton *button,
 
   if (wizard_exists) {
     /* Really check whether the file exists */
-    int fd = open( wizard_path, O_RDONLY );
+    int fd = g_open( wizard_path, O_RDONLY, 0 );
     if ( fd == -1)
       wizard_exists = FALSE;
     else
       close( fd );
   }
 
+#ifdef G_OS_WIN32
+  {
+    const char *check_file = "qtdemo.exe";
+    gchar *found_program = g_find_program_in_path(check_file);
+    if (found_program) {
+      g_debug("Yes, we found the Qt demo program in %s\n", found_program);
+      g_free(found_program);
+    } else {
+      g_warning("Ouch, no Qt demo program was found. Qt not installed?\n");
+      qt_probably_unavailable = TRUE;
+    }
+  }
+#endif
+
   druid_disable_next_button(info);
   /* AB_Banking_DeactivateProvider(banking, backend_name); */
   if (wizard_exists) {
-    int wait_status;
-    int wait_result = 0;
-
     /* Call the qt wizard. See the note above about why this approach
        is chosen. */
 
+#if ((AQBANKING_VERSION_MAJOR == 2) && \
+     (AQBANKING_VERSION_MINOR >= 3))
+    /* With aqbanking>=2.3.0, we can directly activate all backends
+       here. Reduces user confusion. But in aqbanking-3.x this won't
+       be needed anymore. */
+    AB_Banking_ActivateAllProviders (info->api);
+#endif
+
     /* Reset existing mapping tables */
     AB_Banking_Fini (info->api);
-    delete_hash (info->hbci_hash);
-    info->hbci_hash = NULL;
     if (info->gnc_hash != NULL)
       g_hash_table_destroy (info->gnc_hash);
     info->gnc_hash = NULL;
-    /* In gtk2, this would be g_spawn_async or similar. */
+
     {
-      pid_t pid;
-      pid = fork();
-      switch (pid) {
-      case -1:
-	printf("Fork call failed. Cannot start AqHBCI setup wizard.");
+      GPid pid;
+      GError *error = NULL;
+      gchar *argv[2];
+      gboolean spawned;
+
+      argv[0] = g_strdup (wizard_path);
+      argv[1] = NULL;
+      spawned = g_spawn_async (NULL, argv, NULL, G_SPAWN_DO_NOT_REAP_CHILD,
+			       NULL, NULL, &pid, &error);
+      g_free (argv[0]);
+
+      if (error)
+	g_critical("Error on starting AqBanking setup wizard: Code %d: %s",
+		   error->code,
+		   error->message ? error->message : "(null)");
+
+      if (!spawned) {
+	g_critical("Could not start AqBanking setup wizard: %s",
+		   error->message ? error->message : "(null)");
+	g_error_free (error);
 	res = -1;
-	AB_Banking_Init (info->api);
-	break;
-      case 0: /* child */
-	execl(wizard_path, wizard_path, NULL);
-	printf("Fork call failed. Cannot start AqHBCI setup wizard.");
-	_exit(0);
-      default: /* parent */
-	res = 0;
-	/* wait until child is finished */
-	while (wait_result == 0) {
-	  gtk_main_iteration();
-	  wait_result = waitpid(pid, &wait_status, WNOHANG);
-	  if ((wait_result == pid) && WIFEXITED(wait_status))
-	    res = WEXITSTATUS(wait_status);
-	  else
-	    res = -8;
+      } else {
+	g_child_watch_add (pid, on_child_exit, &res);
+	hbci_druid_is_active = TRUE;
+	gtk_main ();
+	if (!hbci_druid_is_active) {
+	  /* Just in case the druid has been canceled in the meantime. */
+	  g_free (backend_name);
+	  GWEN_Buffer_free(buf);
+	  return;
 	}
-	AB_Banking_Init (info->api);
       }
+      AB_Banking_Init (info->api);
     }
 
     if (res == 0) {
@@ -590,32 +649,49 @@ on_aqhbci_button (GtkButton *button,
       if ((res == 0) || (res == AB_ERROR_FOUND))
 	druid_enable_next_button(info);
       else {
-	printf("on_aqhbci_button: Oops, after successful wizard the activation return nonzero value: %d. \n", res);
+	g_warning("on_aqhbci_button: Oops, after successful wizard the activation return nonzero value: %d. \n", res);
 	druid_disable_next_button(info);
       }
     }
     else {
-      printf("on_aqhbci_button: Oops, aqhbci wizard return nonzero value: %d. The called program was \"%s\".\n", res, wizard_path);
+      if (qt_probably_unavailable) {
+	g_warning("on_aqhbci_button: Oops, aqhbci wizard return nonzero value: %d. The called program was \"%s\".\n", res, wizard_path);
+	gnc_error_dialog
+	  (info->window,
+	   _("The external program \"AqBanking Setup Wizard\" failed "
+	     "to run successfully because the "
+	     "additional software \"Qt\" was not found.  "
+	     "Please install the \"Qt/Windows Open Source Edition\" "
+	     "from Trolltech by downloading it from www.trolltech.com"
+	     "\n\n"
+	     "If you have installed Qt already, you will have to adapt "
+	     "the PATH variable of your system appropriately.  "
+	     "Contact the GnuCash developers if you need further "
+	     "assistance on how to install Qt correctly."
+	     "\n\n"
+	     "Online Banking cannot be setup without Qt.  Press \"Close\" "
+	     "now, then \"Cancel\" to cancel the Online Banking setup."));
+      } else {
+      g_warning("on_aqhbci_button: Oops, aqhbci wizard return nonzero value: %d. The called program was \"%s\".\n", res, wizard_path);
       gnc_error_dialog
 	(info->window,
-       /* Each of the %s is the name of the backend, e.g. "aqhbci". */
-	 _("The external program \"%s Setup Wizard\" returned a nonzero "
-	   "exit code which means it has not been finished successfully. "
-	   "The further HBCI setup can only be finished if the %s "
-	   "Setup Wizard is run successfully. Please try to start and "
-	   "successfully finish the %s Setup Wizard program again."),
-	 backend_name, backend_name, backend_name);
+	 _("The external program \"AqBanking Setup Wizard\" failed "
+	   "to run successfully.  Online Banking can only be setup "
+	   "if this wizard has run successfully.  "
+	   "Please try running the \"AqBanking Setup Wizard\" again."));
+      }
       druid_disable_next_button(info);
     }
   } else {
-    printf("on_aqhbci_button: Oops, no aqhbci setup wizard found.");
+    g_warning("on_aqhbci_button: Oops, no aqhbci setup wizard found.");
     gnc_error_dialog
       (info->window,
-       /* Each of the %s is the name of the backend, e.g. "aqhbci". */
-       _("The external program \"%s Setup Wizard\" has not been found. \n\n"
-	 "The package aqbanking is supposed to install the program "
-	 "\"%s-qt3-wizard\". Please check your installation of aqbanking."),
-       backend_name, backend_name);
+       _("The external program \"AqBanking Setup Wizard\" has not "
+	 "been found. \n\n"
+	 "The aqbanking package should include the "
+	 "program \"qt3-wizard\".  Please check your installation to "
+	 "ensure this program is present.  On some distributions this "
+	 "may require installing additional packages."));
     druid_disable_next_button(info);
   }
   g_free (backend_name);
@@ -631,6 +707,10 @@ void gnc_hbci_initial_druid (void)
   HBCIInitialInfo *info;
   GladeXML *xml;
   GtkWidget *page;
+  GtkCellRenderer *renderer;
+  GtkTreeViewColumn *column;
+  GtkTreeSelection *selection;
+  gint component_id;
   
   info = g_new0 (HBCIInitialInfo, 1);
 
@@ -662,13 +742,48 @@ void gnc_hbci_initial_druid (void)
   {
     page = glade_xml_get_widget(xml, "account_match_page");
     info->accountpage = page;
-    info->accountlist = glade_xml_get_widget(xml, "account_page_list");
-    g_signal_connect (info->accountlist, "select_row",
-		      G_CALLBACK (on_accountlist_select_row), info);
+    info->accountview =
+      GTK_TREE_VIEW(glade_xml_get_widget(xml, "account_page_view"));
+    info->accountstore = gtk_list_store_new(NUM_ACCOUNT_LIST_COLS,
+					    G_TYPE_INT, G_TYPE_STRING,
+					    G_TYPE_POINTER, G_TYPE_STRING,
+					    G_TYPE_BOOLEAN);
+    gtk_tree_view_set_model(info->accountview, GTK_TREE_MODEL(info->accountstore));
+    g_object_unref(info->accountstore);
+
+    renderer = gtk_cell_renderer_text_new();
+    column = gtk_tree_view_column_new_with_attributes(_("Online Banking Account Name"),
+						      renderer,
+						      "text", ACCOUNT_LIST_COL_HBCI_NAME,
+						      NULL);
+    gtk_tree_view_append_column(info->accountview, column);
+
+    renderer = gtk_cell_renderer_text_new();
+    column = gtk_tree_view_column_new_with_attributes(_("GnuCash Account Name"),
+						      renderer,
+						      "text", ACCOUNT_LIST_COL_GNC_NAME,
+						      NULL);
+    gtk_tree_view_append_column(info->accountview, column);
+    gtk_tree_view_column_set_expand(column, TRUE);
+
+    renderer = gtk_cell_renderer_toggle_new();
+    column = gtk_tree_view_column_new_with_attributes(_("New?"),
+						      renderer,
+						      "active", ACCOUNT_LIST_COL_CHECKED,
+						      NULL);
+    gtk_tree_view_append_column(info->accountview, column);
+
+    selection = gtk_tree_view_get_selection(info->accountview);
+    g_signal_connect (selection, "changed",
+		      G_CALLBACK (on_accountlist_changed), info);
     g_signal_connect (page, "prepare", 
 		      G_CALLBACK (on_accountlist_prepare), info);
   }
 
+  component_id = gnc_register_gui_component(DRUID_HBCI_IMPORT_CM_CLASS,
+					    NULL, cm_close_handler,
+					    info);
+  gnc_gui_component_set_session(component_id, gnc_get_current_session());
 
   /*g_signal_connect (dialog, "destroy",*/
   /*                  G_CALLBACK(gnc_hierarchy_destroy_cb), NULL);*/
