@@ -46,7 +46,6 @@
 #include "gnc-engine.h"
 #include "gnc-book.h"
 #include "gnc-ui-util.h"
-#include "gnc-gconf-utils.h"
 #include "gnc-glib-utils.h"
 
 #define GCONF_SECTION "dialogs/import/ofx"
@@ -121,8 +120,8 @@ int ofx_proc_transaction_cb(struct OfxTransactionData data, void * transaction_u
   g_assert(gnc_ofx_importer_gui);
 
   if(data.account_id_valid==true){
-    account = gnc_import_select_account(NULL,
-					data.account_id, 0, NULL, NULL, NO_TYPE, NULL, NULL);
+    account = gnc_import_select_account(NULL, data.account_id, 0, NULL, NULL,
+					ACCT_TYPE_NONE, NULL, NULL);
     if(account!=NULL)
       {
 	/********** Validate the input strings to ensure utf8 ********************/
@@ -132,7 +131,7 @@ int ofx_proc_transaction_cb(struct OfxTransactionData data, void * transaction_u
 	  gnc_utf8_strip_invalid(data.memo);
 
 	/********** Create the transaction and setup transaction data ************/
-	book = xaccAccountGetBook(account);
+	book = gnc_account_get_book(account);
 	transaction = xaccMallocTransaction(book);
 	xaccTransBeginEdit(transaction);
 	
@@ -303,7 +302,7 @@ int ofx_proc_transaction_cb(struct OfxTransactionData data, void * transaction_u
 	}
 	xaccTransSetNotes(transaction, notes);
 	g_free(notes);
-	if( data.account_ptr->currency_valid == true)
+	if ( data.account_ptr && data.account_ptr->currency_valid )
 	  {
 	    DEBUG("Currency from libofx: %s",data.account_ptr->currency);
 	    currency = gnc_commodity_table_lookup( gnc_get_current_commodities (),
@@ -337,10 +336,14 @@ int ofx_proc_transaction_cb(struct OfxTransactionData data, void * transaction_u
 		  xaccSplitSetMemo(split, data.memo);
 		}
 	      }
-	    else if(data.unique_id_valid==true&&data.security_data_ptr->secname_valid==true)
+	    else if(data.unique_id_valid == true
+		    && data.security_data_valid
+		    && data.security_data_ptr != NULL
+		    && data.security_data_ptr->secname_valid == true)
 	      {
 		/************************ Process an investment transaction ******************************/
-		/* Note that the STOCK account type should be replaced with something derived from data.invtranstype*/
+		/* Note that the ACCT_TYPE_STOCK account type should be replaced with something
+		   derived from data.invtranstype*/
 		investment_commodity = gnc_import_select_commodity(data.unique_id,
 								   0,
 								   NULL,
@@ -358,7 +361,7 @@ int ofx_proc_transaction_cb(struct OfxTransactionData data, void * transaction_u
 								   1,
 								   investment_account_text, 
 								   investment_commodity,
-								   STOCK,
+								   ACCT_TYPE_STOCK,
 								   NULL,
 								   NULL);
 		    g_free (investment_account_text);
@@ -424,7 +427,7 @@ int ofx_proc_transaction_cb(struct OfxTransactionData data, void * transaction_u
 								     1,
 								     investment_account_text, 
 								     currency,
-								     INCOME,
+								     ACCT_TYPE_INCOME,
 								     NULL,
 								     NULL);
 			    income_acc_guid = xaccAccountGetGUID(income_account);
@@ -548,7 +551,7 @@ int ofx_proc_account_cb(struct OfxAccountData data, void * account_user_data)
   Account *selected_account;
   gnc_commodity_table * commodity_table;
   gnc_commodity * default_commodity;
-  GNCAccountType default_type=NO_TYPE;
+  GNCAccountType default_type=ACCT_TYPE_NONE;
   gchar * account_description;
   gchar * account_type_name = NULL;
 
@@ -571,31 +574,31 @@ int ofx_proc_account_cb(struct OfxAccountData data, void * account_user_data)
     if(data.account_type_valid==true){
       switch(data.account_type){
       case OFX_CHECKING : 
-	default_type=BANK;
+	default_type=ACCT_TYPE_BANK;
 	account_type_name = g_strdup_printf(_("Unknown OFX checking account"));
 	break;
       case OFX_SAVINGS : 
-	default_type=BANK;
+	default_type=ACCT_TYPE_BANK;
 	account_type_name = g_strdup_printf(_("Unknown OFX savings account"));
 	break;
       case OFX_MONEYMRKT : 
-	default_type=MONEYMRKT;
+	default_type=ACCT_TYPE_MONEYMRKT;
 	account_type_name = g_strdup_printf(_("Unknown OFX money market account"));
 	break;
       case OFX_CREDITLINE : 
-	default_type=CREDITLINE;
+	default_type=ACCT_TYPE_CREDITLINE;
 	account_type_name = g_strdup_printf(_("Unknown OFX credit line account"));
 	break;
       case OFX_CMA : 
-	default_type=NO_TYPE;
+	default_type=ACCT_TYPE_NONE;
 	account_type_name = g_strdup_printf(_("Unknown OFX CMA account"));
 	break;
       case OFX_CREDITCARD : 
-	default_type=CREDIT;
+	default_type=ACCT_TYPE_CREDIT;
 	account_type_name = g_strdup_printf(_("Unknown OFX credit card account"));
 	break;
       case OFX_INVESTMENT :
-	default_type=BANK;
+	default_type=ACCT_TYPE_BANK;
 	account_type_name = g_strdup_printf(_("Unknown OFX investment account"));
 	break;
       default: PERR("WRITEME: ofx_proc_account() This is an unknown account type!");
@@ -633,7 +636,7 @@ void gnc_file_ofx_import (void)
   extern int ofx_ERROR_msg;
   extern int ofx_INFO_msg;
   extern int ofx_STATUS_msg;
-  const char *selected_filename;
+  char *selected_filename;
   char *default_dir;
   LibofxContextPtr libofx_context = libofx_get_new_context();
 
@@ -644,26 +647,25 @@ void gnc_file_ofx_import (void)
   ofx_INFO_msg = true;
   ofx_STATUS_msg = false;
 
-  qof_log_check(GNC_MOD_IMPORT, QOF_LOG_TRACE);
   DEBUG("gnc_file_ofx_import(): Begin...\n");
 
-  default_dir = gnc_gconf_get_string(GCONF_SECTION, KEY_LAST_PATH, NULL);
-  if (default_dir == NULL)
-    gnc_init_default_directory(&default_dir);
+  default_dir = gnc_get_default_directory(GCONF_SECTION);
   selected_filename = gnc_file_dialog(_("Select an OFX/QFX file to process"),
 				      NULL,
 				      default_dir,
 				      GNC_FILE_DIALOG_IMPORT);
   g_free(default_dir);
-  default_dir = NULL;
 
   if(selected_filename!=NULL)
     {
+#ifdef G_OS_WIN32
+      gchar *conv_name;
+#endif
+
       /* Remember the directory as the default. */
-      gnc_extract_directory(&default_dir, selected_filename);
-      gnc_gconf_set_string(GCONF_SECTION, KEY_LAST_PATH, default_dir, NULL);
+      default_dir = g_path_get_dirname(selected_filename);
+      gnc_set_default_directory(GCONF_SECTION, default_dir);
       g_free(default_dir);
-      default_dir = NULL;
 
       /*strncpy(file,selected_filename, 255);*/
       DEBUG("Filename found: %s",selected_filename);
@@ -679,9 +681,15 @@ void gnc_file_ofx_import (void)
       ofx_set_security_cb(libofx_context, ofx_proc_security_cb, 0);
       /*ofx_set_status_cb(libofx_context, ofx_proc_status_cb, 0);*/
 
+#ifdef G_OS_WIN32
+      conv_name = g_win32_locale_filename_from_utf8(selected_filename);
+      g_free(selected_filename);
+      selected_filename = conv_name;
+#endif
 
       DEBUG("Opening selected file");
-     libofx_proc_file(libofx_context, selected_filename, AUTODETECT);
+      libofx_proc_file(libofx_context, selected_filename, AUTODETECT);
+      g_free(selected_filename);
     }
 
 }
