@@ -270,7 +270,7 @@
 ;          ((vest) 
 ;           'vest)
           (else
-           (gnc:warning-dialog #f
+           (gnc-warning-dialog '()
             (string-append
              (sprintf #f (_ "The file contains an unknown Action '%s'.")
                       read-value)
@@ -567,12 +567,12 @@
              (with-input-from-string filtered-string
                (lambda () (read)))))
        (if (number? read-val)
-           (gnc:double-to-gnc-numeric
+           (double-to-gnc-numeric
             (+ 0.0 read-val) GNC-DENOM-AUTO
             (logior (GNC-DENOM-SIGFIGS 
 		     (string-length (string-remove-char filtered-string #\.)))
                     GNC-RND-ROUND))
-           (gnc:numeric-zero))))
+           (gnc-numeric-zero))))
     ((comma)
      (let* ((filtered-string 
              (string-remove-char 
@@ -584,21 +584,21 @@
              (with-input-from-string filtered-string
                (lambda () (read)))))
        (if (number? read-val)
-           (gnc:double-to-gnc-numeric
+           (double-to-gnc-numeric
             (+ 0.0 read-val) GNC-DENOM-AUTO
             (logior (GNC-DENOM-SIGFIGS
 		     (string-length (string-remove-char filtered-string #\.)))
                     GNC-RND-ROUND))
-           (gnc:numeric-zero))))
+           (gnc-numeric-zero))))
     ((integer)
      (let ((read-val
             (with-input-from-string 
                 (string-remove-char value-string #\$)
               (lambda () (read)))))
        (if (number? read-val)
-           (gnc:double-to-gnc-numeric
+           (double-to-gnc-numeric
             (+ 0.0 read-val) 1 GNC-RND-ROUND)
-           (gnc:numeric-zero))))))
+           (gnc-numeric-zero))))))
 
 (define (qif-parse:check-number-formats amt-strings formats)
   (let ((retval formats))
@@ -621,7 +621,7 @@
                    (if (not tmp)
                        (set! all-ok #f))
                    tmp)
-                 (gnc:numeric-zero)))
+                 (gnc-numeric-zero)))
            amt-strings)))
     (if all-ok parsed #f)))
 
