@@ -14,37 +14,37 @@
 
 (define (qif-import:find-or-make-acct acct-info check-types? commodity
 				      check-commodity? default-currency
-                                      gnc-acct-hash old-group new-group)
-  (let* ((separator (string-ref (gnc:account-separator-string) 0))
+                                      gnc-acct-hash old-root new-root)
+  (let* ((separator (string-ref (gnc-get-account-separator-string) 0))
          (gnc-name (qif-map-entry:gnc-name acct-info))
          (existing-account (hash-ref gnc-acct-hash gnc-name))
          (same-gnc-account 
-          (gnc:get-account-from-full-name old-group gnc-name))
+          (gnc-account-lookup-by-full-name old-root gnc-name))
          (allowed-types 
           (qif-map-entry:allowed-types acct-info))
          (make-new-acct #f)
          (incompatible-acct #f))
     
     (define (compatible? account)
-      (let ((acc-type (gnc:account-get-type account))
-            (acc-commodity (gnc:account-get-commodity account)))
+      (let ((acc-type (xaccAccountGetType account))
+            (acc-commodity (xaccAccountGetCommodity account)))
         (and
          (if check-types? 
              (and (list? allowed-types)
                   (memv acc-type allowed-types))
              #t)
 	 (if check-commodity?
-	     (gnc:commodity-equiv? acc-commodity commodity)
+	     (gnc-commodity-equiv acc-commodity commodity)
 	     #t))))
     
     (define (make-unique-name-variant long-name short-name)
-      (if (gnc:get-account-from-full-name old-group long-name)
+      (if (not (null? (gnc-account-lookup-by-full-name old-root long-name)))
           (let loop ((count 2))
             (let* ((test-name 
                     (string-append long-name (sprintf #f " %a" count)))
                    (test-acct 
-                    (gnc:get-account-from-full-name old-group test-name)))
-              (if (and test-acct (not (compatible? test-acct)))
+                    (gnc-account-lookup-by-full-name old-root test-name)))
+              (if (and (not (null? test-acct)) (not (compatible? test-acct)))
                   (loop (+ 1 count))
                   (string-append short-name (sprintf #f " %a" count)))))
           short-name))
@@ -53,7 +53,7 @@
     ;; if the name is in use but the commodity, or type are
     ;; incompatible, we need to create a new account with a modified
     ;; name.
-    (if same-gnc-account 
+    (if (and same-gnc-account (not (null? same-gnc-account))) 
         (if (compatible? same-gnc-account)
             (begin 
               ;; everything is ok, so we can just use the same
@@ -61,7 +61,7 @@
               (set! make-new-acct #f)
               (set! incompatible-acct #f)
               (set! allowed-types 
-                    (list (gnc:account-get-type same-gnc-account))))
+                    (list (xaccAccountGetType same-gnc-account))))
             (begin 
               ;; there's an existing account with that name, so we
               ;; have to make a new acct with different properties and
@@ -77,34 +77,35 @@
     ;; here, existing-account means a previously *created* account
     ;; (possibly a new account, possibly a copy of an existing gnucash
     ;; acct)
-    (if (and existing-account (compatible? existing-account))
+    (if (and (and existing-account (not (null? existing-account))) 
+             (compatible? existing-account))
         existing-account 
-        (let ((new-acct (gnc:malloc-account (gnc:get-current-book)))
+        (let ((new-acct (xaccMallocAccount (gnc-get-current-book)))
               (parent-acct #f)
               (parent-name #f)
               (acct-name #f)
               (last-colon #f))
           (set! last-colon (string-rindex gnc-name separator))
           
-          (gnc:account-begin-edit new-acct)
+          (xaccAccountBeginEdit new-acct)
           
           ;; if this is a copy of an existing gnc account, copy the
           ;; account properties.  For incompatible existing accts,
           ;; we'll do something different later.
-          (if same-gnc-account
+          (if (and same-gnc-account (not (null? same-gnc-account)))
               (begin 
-                (gnc:account-set-name 
-                 new-acct (gnc:account-get-name same-gnc-account))
-                (gnc:account-set-description
-                 new-acct (gnc:account-get-description same-gnc-account))
-                (gnc:account-set-type
-                 new-acct (gnc:account-get-type same-gnc-account))
-                (gnc:account-set-commodity
-                 new-acct (gnc:account-get-commodity same-gnc-account))
-                (gnc:account-set-notes 
-                 new-acct (gnc:account-get-notes same-gnc-account))
-                (gnc:account-set-code 
-                 new-acct (gnc:account-get-code same-gnc-account))))
+                (xaccAccountSetName
+                 new-acct (xaccAccountGetName same-gnc-account))
+                (xaccAccountSetDescription
+                 new-acct (xaccAccountGetDescription same-gnc-account))
+                (xaccAccountSetType
+                 new-acct (xaccAccountGetType same-gnc-account))
+                (xaccAccountSetCommodity
+                 new-acct (xaccAccountGetCommodity same-gnc-account))
+                (xaccAccountSetNotes
+                 new-acct (xaccAccountGetNotes same-gnc-account))
+                (xaccAccountSetCode
+                 new-acct (xaccAccountGetCode same-gnc-account))))
           
           ;; make sure that if this is a nested account foo:bar:baz,
           ;; foo:bar and foo exist also.
@@ -121,11 +122,11 @@
           (if make-new-acct
               (begin 
                 ;; set the name, description, etc.
-                (gnc:account-set-name new-acct acct-name)
+                (xaccAccountSetName new-acct acct-name)
                 (if (qif-map-entry:description acct-info)
-                    (gnc:account-set-description 
+                    (xaccAccountSetDescription
                      new-acct (qif-map-entry:description acct-info)))
-                (gnc:account-set-commodity new-acct commodity)
+                (xaccAccountSetCommodity new-acct commodity)
                 
                 ;; if it's an incompatible account, set the
                 ;; name to be unique, and a description that 
@@ -133,32 +134,32 @@
                 (if incompatible-acct
                     (let ((new-name (make-unique-name-variant 
                                      gnc-name acct-name)))
-                      (gnc:account-set-name new-acct new-name)
-                      (gnc:account-set-description 
+                      (xaccAccountSetName new-acct new-name)
+                      (xaccAccountSetDescription
                        new-acct 
                        (_ "QIF import: Name conflict with another account."))))
                 
                 ;; set the account type.  this could be smarter. 
                 (if (qif-map-entry:allowed-types acct-info)
-                    (gnc:account-set-type 
+                    (xaccAccountSetType
                      new-acct (car (qif-map-entry:allowed-types acct-info))))))
-          (gnc:account-commit-edit new-acct)
+          (xaccAccountCommitEdit new-acct)
 
           (if last-colon
               (let ((pinfo (make-qif-map-entry)))
                 (qif-map-entry:set-qif-name! pinfo parent-name)
                 (qif-map-entry:set-gnc-name! pinfo parent-name)
                 (qif-map-entry:set-allowed-types! 
-                 acct-info (list (gnc:account-get-type new-acct)))
+                 acct-info (list (xaccAccountGetType new-acct)))
                 (qif-map-entry:set-allowed-types! 
                  pinfo (qif-map-entry:allowed-parent-types acct-info))
                 
                 (set! parent-acct (qif-import:find-or-make-acct 
                                    pinfo #t default-currency #f default-currency
-                                   gnc-acct-hash old-group new-group))))
-          (if parent-acct
-              (gnc:account-insert-subaccount parent-acct new-acct)
-              (gnc:group-insert-account new-group new-acct))
+                                   gnc-acct-hash old-root new-root))))
+          (if (and parent-acct (not (null? parent-acct)))
+              (gnc-account-append-child parent-acct new-acct)
+              (gnc-account-append-child new-root new-acct))
           
           (hash-set! gnc-acct-hash gnc-name new-acct)
           new-acct))))
@@ -177,13 +178,13 @@
                                default-currency-name window)
   (gnc:backtrace-if-exception 
    (lambda ()
-     (let* ((old-group (gnc:get-current-group))
-            (new-group (gnc:malloc-account-group (gnc:get-current-book)))
+     (let* ((old-root (gnc-get-current-root-account))
+	    (new-root (xaccMallocAccount (gnc-get-current-book)))
             (gnc-acct-hash (make-hash-table 20))
-            (separator (string-ref (gnc:account-separator-string) 0))
+            (separator (string-ref (gnc-get-account-separator-string) 0))
             (default-currency 
-              (gnc:commodity-table-find-full 
-               (gnc:book-get-commodity-table (gnc:get-current-book))
+              (gnc-commodity-table-find-full
+               (gnc-commodity-table-get-table (gnc-get-current-book))
                GNC_COMMODITY_NS_CURRENCY default-currency-name))
             (sorted-accounts-list '())
             (markable-xtns '())
@@ -192,7 +193,7 @@
                    (lambda (a b)
                      (> (length (qif-file:xtns a)) 
                         (length (qif-file:xtns b))))))
-            (progress-dialog #f)
+            (progress-dialog '())
             (work-to-do 0)
             (work-done 0))
        
@@ -265,16 +266,16 @@
                    (qif-import:find-or-make-acct acctinfo #f
                                                  security #t default-currency
                                                  gnc-acct-hash 
-                                                 old-group new-group))
+                                                 old-root new-root))
                   ((and security (or stock?
-				     (gnc:commodity-is-currency? security)))
+				     (gnc-commodity-is-currency security)))
                    (qif-import:find-or-make-acct 
                     acctinfo #f security #t default-currency
-                    gnc-acct-hash old-group new-group))
+                    gnc-acct-hash old-root new-root))
                   (#t 
                    (qif-import:find-or-make-acct 
                     acctinfo #f default-currency #t default-currency
-                    gnc-acct-hash old-group new-group)))))
+                    gnc-acct-hash old-root new-root)))))
         sorted-accounts-list)
        
        ;; before trying to mark transactions, prune down the list of 
@@ -296,9 +297,9 @@
        
        (if (> work-to-do 100)
            (begin 
-             (set! progress-dialog (gnc:progress-dialog-new window #f))
-             (gnc:progress-dialog-set-title progress-dialog (_ "Progress"))
-             (gnc:progress-dialog-set-heading progress-dialog
+             (set! progress-dialog (gnc-progress-dialog-new window #f))
+             (gnc-progress-dialog-set-title progress-dialog (_ "Progress"))
+             (gnc-progress-dialog-set-heading progress-dialog
                                               (_ "Importing transactions..."))))
        
 
@@ -308,11 +309,11 @@
            (let xloop ((xtn (car markable-xtns))
                        (rest (cdr markable-xtns)))
              (set! work-done (+ 1 work-done))
-             (if progress-dialog 
+             (if (not (null? progress-dialog)) 
                  (begin 
-                   (gnc:progress-dialog-set-value 
+                   (gnc-progress-dialog-set-value
                     progress-dialog (/ work-done work-to-do))
-                   (gnc:progress-dialog-update progress-dialog))) 
+                   (gnc-progress-dialog-update progress-dialog)))
              (if (not (qif-xtn:mark xtn))
                  (qif-import:mark-matching-xtns xtn rest))
              (if (not (null? (cdr rest)))
@@ -325,21 +326,21 @@
           (for-each 
            (lambda (xtn)
              (set! work-done (+ 1 work-done))
-             (if progress-dialog 
+             (if (not (null? progress-dialog)) 
                  (begin 
-                   (gnc:progress-dialog-set-value 
+                   (gnc-progress-dialog-set-value
                     progress-dialog (/ work-done work-to-do))
-                   (gnc:progress-dialog-update progress-dialog))) 
+                   (gnc-progress-dialog-update progress-dialog)))
              (if (not (qif-xtn:mark xtn))
                  (begin 
                    ;; create and fill in the GNC transaction
-                   (let ((gnc-xtn (gnc:transaction-create
-                                   (gnc:get-current-book))))
-                     (gnc:transaction-begin-edit gnc-xtn)
+                   (let ((gnc-xtn (xaccMallocTransaction
+                                   (gnc-get-current-book))))
+                     (xaccTransBeginEdit gnc-xtn)
 
                      ;; FIXME. This is probably wrong
-                     (gnc:transaction-set-currency gnc-xtn
-                                                   (gnc:default-currency))
+                     (xaccTransSetCurrency gnc-xtn
+                                                   (gnc-default-currency))
 
                      ;; build the transaction
                      (qif-import:qif-xtn-to-gnc-xtn 
@@ -347,15 +348,15 @@
                       qif-acct-map qif-cat-map qif-memo-map)
                      
                      ;; rebalance and commit everything
-                     (gnc:transaction-commit-edit gnc-xtn)))))
+                     (xaccTransCommitEdit gnc-xtn)))))
            (qif-file:xtns qif-file)))
         sorted-qif-files-list)
        
        ;; get rid of the progress dialog 
-       (if progress-dialog
-           (gnc:progress-dialog-destroy progress-dialog))
+       (if (not (null? progress-dialog))
+           (gnc-progress-dialog-destroy progress-dialog))
        
-       new-group))))
+       new-root))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; qif-import:qif-xtn-to-gnc-xtn
@@ -367,8 +368,8 @@
                                        gnc-acct-hash 
                                        qif-acct-map qif-cat-map qif-memo-map)
   (let ((splits (qif-xtn:splits qif-xtn))
-        (gnc-near-split (gnc:split-create (gnc:get-current-book)))
-        (near-split-total (gnc:numeric-zero))
+        (gnc-near-split (xaccMallocSplit (gnc-get-current-book)))
+        (near-split-total (gnc-numeric-zero))
         (near-acct-info #f)
         (near-acct-name #f)
         (near-acct #f)
@@ -379,31 +380,31 @@
         (qif-memo (qif-split:memo (car (qif-xtn:splits qif-xtn))))
         (qif-from-acct (qif-xtn:from-acct qif-xtn))
         (qif-cleared (qif-xtn:cleared qif-xtn))
-        (n- (lambda (n) (gnc:numeric-neg n)))
-        (nsub (lambda (a b) (gnc:numeric-sub a b 0 GNC-DENOM-LCD)))
-        (n+ (lambda (a b) (gnc:numeric-add a b 0 GNC-DENOM-LCD)))
-        (n* (lambda (a b) (gnc:numeric-mul a b 0 GNC-DENOM-REDUCE)))
-        (n/ (lambda (a b) (gnc:numeric-div a b 0 GNC-DENOM-REDUCE))))
+        (n- (lambda (n) (gnc-numeric-neg n)))
+        (nsub (lambda (a b) (gnc-numeric-sub a b 0 GNC-DENOM-LCD)))
+        (n+ (lambda (a b) (gnc-numeric-add a b 0 GNC-DENOM-LCD)))
+        (n* (lambda (a b) (gnc-numeric-mul a b 0 GNC-DENOM-REDUCE)))
+        (n/ (lambda (a b) (gnc-numeric-div a b 0 GNC-DENOM-REDUCE))))
     
     ;; set properties of the whole transaction     
-    (apply gnc:transaction-set-date gnc-xtn (qif-xtn:date qif-xtn))
+    (apply xaccTransSetDate gnc-xtn (qif-xtn:date qif-xtn))
     
     ;; fixme: bug #105 
     (if qif-payee
-        (gnc:transaction-set-description gnc-xtn qif-payee))
+        (xaccTransSetDescription gnc-xtn qif-payee))
     (if qif-number
-        (gnc:transaction-set-xnum gnc-xtn qif-number))
+        (xaccTransSetNum gnc-xtn qif-number))
     (if qif-memo
 	(begin
-	  (gnc:split-set-memo gnc-near-split qif-memo)
+	  (xaccSplitSetMemo gnc-near-split qif-memo)
 	  (if (or (not qif-payee)
 		  (equal? qif-payee ""))
-	      (gnc:transaction-set-description gnc-xtn qif-memo))))
+	      (xaccTransSetDescription gnc-xtn qif-memo))))
     
     (if (eq? qif-cleared 'cleared)        
-        (gnc:split-set-reconcile gnc-near-split #\c))
+        (xaccSplitSetReconcile gnc-near-split #\c))
     (if (eq? qif-cleared 'reconciled)
-        (gnc:split-set-reconcile gnc-near-split #\y))
+        (xaccSplitSetReconcile gnc-near-split #\y))
     
     (if (not qif-security)
         (begin 
@@ -420,8 +421,8 @@
           (for-each 
            (lambda (qif-split)
              (if (not (qif-split:mark qif-split))
-                 (let ((gnc-far-split (gnc:split-create
-                                       (gnc:get-current-book)))
+                 (let ((gnc-far-split (xaccMallocSplit
+                                       (gnc-get-current-book)))
                        (far-acct-info #f)
                        (far-acct-name #f)
                        (far-acct-type #f)
@@ -430,15 +431,15 @@
                        (memo (qif-split:memo qif-split))
                        (cat (qif-split:category qif-split)))
                    
-                   (if (not split-amt) (set! split-amt (gnc:numeric-zero)))
+                   (if (not split-amt) (set! split-amt (gnc-numeric-zero)))
                    ;; fill the splits in (near first).  This handles
                    ;; files in multiple currencies by pulling the
                    ;; currency value from the file import.
                    (set! near-split-total (n+ near-split-total split-amt))
-                   (gnc:split-set-value gnc-far-split (n- split-amt))
-                   (gnc:split-set-amount gnc-far-split (n- split-amt))
+                   (xaccSplitSetValue gnc-far-split (n- split-amt))
+                   (xaccSplitSetAmount gnc-far-split (n- split-amt))
 
-                   (if memo (gnc:split-set-memo gnc-far-split memo))
+                   (if memo (xaccSplitSetMemo gnc-far-split memo))
                    
                    ;; figure out what the far acct is
                    (cond 
@@ -475,20 +476,20 @@
                    ;; set the reconcile status. 
                    (let ((cleared (qif-split:matching-cleared qif-split)))
                      (if (eq? 'cleared cleared)
-                         (gnc:split-set-reconcile gnc-far-split #\c))
+                         (xaccSplitSetReconcile gnc-far-split #\c))
                      (if (eq? 'reconciled cleared)
-                         (gnc:split-set-reconcile gnc-far-split #\y)))
+                         (xaccSplitSetReconcile gnc-far-split #\y)))
                    
                    ;; finally, plug the split into the account 
-                   (gnc:account-insert-split far-acct gnc-far-split)
-                   (gnc:transaction-append-split gnc-xtn gnc-far-split))))
+                   (xaccSplitSetAccount gnc-far-split far-acct)
+                   (xaccSplitSetParent gnc-far-split gnc-xtn))))
            splits)
           
           ;; the value of the near split is the total of the far splits.
-          (gnc:split-set-value gnc-near-split near-split-total)
-          (gnc:split-set-amount gnc-near-split near-split-total)
-          (gnc:transaction-append-split gnc-xtn gnc-near-split)
-          (gnc:account-insert-split near-acct gnc-near-split))
+          (xaccSplitSetValue gnc-near-split near-split-total)
+          (xaccSplitSetAmount gnc-near-split near-split-total)
+          (xaccSplitSetParent gnc-near-split gnc-xtn)
+          (xaccSplitSetAccount gnc-near-split near-acct))
         
         ;; STOCK TRANSACTIONS: the near/far accounts depend on the
         ;; "action" encoded in the Number field.  It's generally the
@@ -509,10 +510,10 @@
                (commission-amt (qif-xtn:commission qif-xtn))
                (commission-split #f)
                (defer-share-price #f)
-               (gnc-far-split (gnc:split-create (gnc:get-current-book))))
+               (gnc-far-split (xaccMallocSplit (gnc-get-current-book))))
           
-          (if (not num-shares) (set! num-shares (gnc:numeric-zero)))
-          (if (not share-price) (set! share-price (gnc:numeric-zero)))
+          (if (not num-shares) (set! num-shares (gnc-numeric-zero)))
+          (if (not share-price) (set! share-price (gnc-numeric-zero)))
           (if (not split-amt) (set! split-amt (n* num-shares share-price)))
           
           ;; I don't think this should ever happen, but I want 
@@ -549,46 +550,46 @@
           ;; are amounts currency or shares? 
           (case qif-action
             ((buy buyx reinvint reinvdiv reinvsg reinvsh reinvmd reinvlg)
-             (if (not share-price) (set! share-price (gnc:numeric-zero)))
-             (gnc:split-set-amount gnc-near-split num-shares)
-             (gnc:split-set-value gnc-near-split split-amt)
-             (gnc:split-set-value gnc-far-split (n- xtn-amt))
-             (gnc:split-set-amount gnc-far-split (n- xtn-amt)))
+             (if (not share-price) (set! share-price (gnc-numeric-zero)))
+             (xaccSplitSetAmount gnc-near-split num-shares)
+             (xaccSplitSetValue gnc-near-split split-amt)
+             (xaccSplitSetValue gnc-far-split (n- xtn-amt))
+             (xaccSplitSetAmount gnc-far-split (n- xtn-amt)))
             
             ((sell sellx) 
-             (if (not share-price) (set! share-price (gnc:numeric-zero)))
-             (gnc:split-set-amount gnc-near-split (n- num-shares))
-             (gnc:split-set-value gnc-near-split (n- split-amt))
-             (gnc:split-set-value gnc-far-split xtn-amt)
-             (gnc:split-set-amount gnc-far-split xtn-amt))
+             (if (not share-price) (set! share-price (gnc-numeric-zero)))
+             (xaccSplitSetAmount gnc-near-split (n- num-shares))
+             (xaccSplitSetValue gnc-near-split (n- split-amt))
+             (xaccSplitSetValue gnc-far-split xtn-amt)
+             (xaccSplitSetAmount gnc-far-split xtn-amt))
             
             ((cgshort cgshortx cgmid cgmidx cglong cglongx intinc intincx 
                       div divx miscinc miscincx xin rtrncap rtrncapx)
-             (gnc:split-set-value gnc-near-split xtn-amt)
-             (gnc:split-set-amount gnc-near-split xtn-amt)
-             (gnc:split-set-value gnc-far-split (n- xtn-amt))
-             (gnc:split-set-amount gnc-far-split (n- xtn-amt)))
+             (xaccSplitSetValue gnc-near-split xtn-amt)
+             (xaccSplitSetAmount gnc-near-split xtn-amt)
+             (xaccSplitSetValue gnc-far-split (n- xtn-amt))
+             (xaccSplitSetAmount gnc-far-split (n- xtn-amt)))
             
             ((xout miscexp miscexpx margint margintx)
-             (gnc:split-set-value gnc-near-split (n- xtn-amt))
-             (gnc:split-set-amount gnc-near-split (n- xtn-amt))
-             (gnc:split-set-value gnc-far-split  xtn-amt)
-             (gnc:split-set-amount gnc-far-split  xtn-amt))
+             (xaccSplitSetValue gnc-near-split (n- xtn-amt))
+             (xaccSplitSetAmount gnc-near-split (n- xtn-amt))
+             (xaccSplitSetValue gnc-far-split  xtn-amt)
+             (xaccSplitSetAmount gnc-far-split  xtn-amt))
             
             ((shrsin)
              ;; getting rid of the old equity-acct-per-stock trick.
              ;; you must now have a cash/basis value for the stock.
-             (gnc:split-set-amount gnc-near-split num-shares)
-             (gnc:split-set-value gnc-near-split split-amt)
-             (gnc:split-set-value gnc-far-split (n- xtn-amt))
-             (gnc:split-set-amount gnc-far-split (n- xtn-amt)))
+             (xaccSplitSetAmount gnc-near-split num-shares)
+             (xaccSplitSetValue gnc-near-split split-amt)
+             (xaccSplitSetValue gnc-far-split (n- xtn-amt))
+             (xaccSplitSetAmount gnc-far-split (n- xtn-amt)))
             
             ((shrsout)
              ;; shrsout is like shrsin             
-             (gnc:split-set-amount gnc-near-split (n- num-shares))
-             (gnc:split-set-value gnc-near-split (n- split-amt))
-             (gnc:split-set-value gnc-far-split xtn-amt)
-             (gnc:split-set-amount gnc-far-split xtn-amt))
+             (xaccSplitSetAmount gnc-near-split (n- num-shares))
+             (xaccSplitSetValue gnc-near-split (n- split-amt))
+             (xaccSplitSetValue gnc-far-split xtn-amt)
+             (xaccSplitSetAmount gnc-far-split xtn-amt))
             
             ;; stock splits: QIF just specifies the split ratio, not
             ;; the number of shares in and out, so we have to fetch
@@ -597,51 +598,53 @@
             ;; FIXME : this could be wrong.  Make sure the
             ;; share-amount is at the correct time.
             ((stksplit)
-             (let* ((splitratio (n/ num-shares (gnc:numeric-create 10 1)))
+             (let* ((splitratio (n/ num-shares (gnc-numeric-create 10 1)))
                     (in-shares 
-                     (gnc:account-get-balance near-acct))
+                     (xaccAccountGetBalance near-acct))
                     (out-shares (n* in-shares splitratio)))
-               (gnc:split-set-amount gnc-near-split out-shares)
-               (gnc:split-set-amount gnc-far-split (n- in-shares))
-               (gnc:split-set-value gnc-near-split (n- split-amt))
-               (gnc:split-set-value gnc-far-split split-amt))))
+               (xaccSplitSetAmount gnc-near-split out-shares)
+               (xaccSplitSetAmount gnc-far-split (n- in-shares))
+               (xaccSplitSetValue gnc-near-split (n- split-amt))
+               (xaccSplitSetValue gnc-far-split split-amt))))
           
           (let ((cleared (qif-split:matching-cleared 
                           (car (qif-xtn:splits qif-xtn)))))
             (if (eq? 'cleared cleared)
-                (gnc:split-set-reconcile gnc-far-split #\c))
+                (xaccSplitSetReconcile gnc-far-split #\c))
             (if (eq? 'reconciled cleared)
-                (gnc:split-set-reconcile gnc-far-split #\y)))
+                (xaccSplitSetReconcile gnc-far-split #\y)))
           
           (if qif-commission-acct
-              (let* ((commission-acct-info 
+              (let* ((commission-acct-info
                       (or (hash-ref qif-acct-map qif-commission-acct)
                           (hash-ref qif-cat-map qif-commission-acct)))
-                     (commission-acct-name 
-                      (qif-map-entry:gnc-name commission-acct-info)))
-                (set! commission-acct 
-                      (hash-ref gnc-acct-hash commission-acct-name))))
+                     (commission-acct-name
+                      (and commission-acct-info
+                           (qif-map-entry:gnc-name commission-acct-info))))
+                (if commission-acct-name
+                    (set! commission-acct
+                          (hash-ref gnc-acct-hash commission-acct-name)))))
           
           (if (and commission-amt commission-acct)
               (begin 
-                (set! commission-split (gnc:split-create
-                                        (gnc:get-current-book)))
-                (gnc:split-set-value commission-split commission-amt)
-                (gnc:split-set-amount commission-split commission-amt)))
+                (set! commission-split (xaccMallocSplit
+                                        (gnc-get-current-book)))
+                (xaccSplitSetValue commission-split commission-amt)
+                (xaccSplitSetAmount commission-split commission-amt)))
 
           (if (and qif-near-acct qif-far-acct)
               (begin 
-                (gnc:transaction-append-split gnc-xtn gnc-near-split)
-                (gnc:account-insert-split near-acct gnc-near-split)
+                (xaccSplitSetParent gnc-near-split gnc-xtn)
+                (xaccSplitSetAccount gnc-near-split near-acct)
                 
-                (gnc:transaction-append-split gnc-xtn gnc-far-split)
-                (gnc:account-insert-split far-acct gnc-far-split)
+                (xaccSplitSetParent gnc-far-split gnc-xtn)
+                (xaccSplitSetAccount gnc-far-split far-acct)
                 
                 (if commission-split
                     (begin 
-                      (gnc:transaction-append-split gnc-xtn commission-split)
-                      (gnc:account-insert-split commission-acct 
-                                                commission-split)))))))
+                      (xaccSplitSetParent commission-split gnc-xtn)
+                      (xaccSplitSetAccount commission-split
+                                           commission-acct)))))))
     ;; return the modified transaction (though it's ignored).
     gnc-xtn))
 
@@ -678,11 +681,11 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 (define (qif-import:mark-some-splits splits xtn candidate-xtns)
-  (let* ((n- (lambda (n) (gnc:numeric-neg n)))
-         (nsub (lambda (a b) (gnc:numeric-sub a b 0 GNC-DENOM-LCD)))
-         (n+ (lambda (a b) (gnc:numeric-add a b 0 GNC-DENOM-LCD)))
-         (n* (lambda (a b) (gnc:numeric-mul a b 0 GNC-DENOM-REDUCE)))
-         (n/ (lambda (a b) (gnc:numeric-div a b 0 GNC-DENOM-REDUCE)))    
+  (let* ((n- (lambda (n) (gnc-numeric-neg n)))
+         (nsub (lambda (a b) (gnc-numeric-sub a b 0 GNC-DENOM-LCD)))
+         (n+ (lambda (a b) (gnc-numeric-add a b 0 GNC-DENOM-LCD)))
+         (n* (lambda (a b) (gnc-numeric-mul a b 0 GNC-DENOM-REDUCE)))
+         (n/ (lambda (a b) (gnc-numeric-div a b 0 GNC-DENOM-REDUCE)))
          (split (car splits))
          (near-acct-name #f)
          (far-acct-name #f)
@@ -703,7 +706,7 @@
         (begin 
           (set! near-acct-name (qif-xtn:from-acct xtn))
           (set! far-acct-name (qif-split:category split))
-          (set! group-amount (gnc:numeric-zero))
+          (set! group-amount (gnc-numeric-zero))
           
           ;; group-amount is the sum of all the splits in this xtn
           ;; going to the same account as 'split'.  We might be able
@@ -789,7 +792,7 @@
 (define (qif-import:xtn-has-matches? xtn acct-name date amount group-amt)
   (let ((matching-splits '())
         (same-acct-splits '())
-        (this-group-amt (gnc:numeric-zero))
+        (this-group-amt (gnc-numeric-zero))
         (how #f)
         (date-matches 
          (let ((self-date (qif-xtn:date xtn)))
@@ -800,11 +803,11 @@
                 (= (car self-date) (car date))
                 (= (cadr self-date) (cadr date))
                 (= (caddr self-date) (caddr date)))))
-        (n- (lambda (n) (gnc:numeric-neg n)))
-        (nsub (lambda (a b) (gnc:numeric-sub a b 0 GNC-DENOM-LCD)))
-        (n+ (lambda (a b) (gnc:numeric-add a b 0 GNC-DENOM-LCD)))
-        (n* (lambda (a b) (gnc:numeric-mul a b 0 GNC-DENOM-REDUCE)))
-        (n/ (lambda (a b) (gnc:numeric-div a b 0 GNC-DENOM-REDUCE))))
+        (n- (lambda (n) (gnc-numeric-neg n)))
+        (nsub (lambda (a b) (gnc-numeric-sub a b 0 GNC-DENOM-LCD)))
+        (n+ (lambda (a b) (gnc-numeric-add a b 0 GNC-DENOM-LCD)))
+        (n* (lambda (a b) (gnc-numeric-mul a b 0 GNC-DENOM-REDUCE)))
+        (n/ (lambda (a b) (gnc-numeric-div a b 0 GNC-DENOM-REDUCE))))
     
     (if date-matches 
         (begin 
@@ -831,10 +834,10 @@
                     ;; we might be done if this-amt is either equal 
                     ;; to the split amount or the group amount.
                     (cond 
-                     ((gnc:numeric-equal this-amt amount)
+                     ((gnc-numeric-equal this-amt amount)
                       (set! how 
                             (cons 'one-to-one (list split))))
-                     ((and group-amt (gnc:numeric-equal this-amt group-amt))
+                     ((and group-amt (gnc-numeric-equal this-amt group-amt))
                       (set! how
                             (cons 'one-to-many (list split))))
                      (#t
@@ -850,7 +853,7 @@
           ;; now we're out of the loop.  if 'how' isn't set, 
           ;; we can still have a many-to-one match.
           (if (and (not how)
-                   (gnc:numeric-equal this-group-amt amount))
+                   (gnc-numeric-equal this-group-amt amount))
               (begin 
                 (set! how 
                       (cons 'many-to-one same-acct-splits))))))
