@@ -25,7 +25,6 @@
 #include <glib.h>
 #include <glib/gi18n.h>
 
-#include "Group.h"
 #include "Scrub.h"
 #include "combocell.h"
 #include "gnc-component-manager.h"
@@ -53,6 +52,7 @@ gnc_split_register_balance_trans (SplitRegister *reg, Transaction *trans)
     int default_value;
     Account *default_account;
     Account *other_account;
+    Account *root;
     GList *radio_list = NULL;
     const char *title   = _("Rebalance Transaction");
     const char *message = _("The current transaction is not balanced.");
@@ -133,6 +133,7 @@ gnc_split_register_balance_trans (SplitRegister *reg, Transaction *trans)
 
     g_list_free (radio_list);
 
+    root = gnc_account_get_root(default_account);
     switch (choice)
     {
       default:
@@ -140,17 +141,15 @@ gnc_split_register_balance_trans (SplitRegister *reg, Transaction *trans)
         break;
 
       case 1:
-        xaccTransScrubImbalance (trans, gnc_get_current_group (), NULL);
+        xaccTransScrubImbalance (trans, root, NULL);
         break;
 
       case 2:
-        xaccTransScrubImbalance (trans, gnc_get_current_group (),
-                                 default_account);
+        xaccTransScrubImbalance (trans, root, default_account);
         break;
 
       case 3:
-        xaccTransScrubImbalance (trans, gnc_get_current_group (),
-                                 other_account);
+        xaccTransScrubImbalance (trans, root, other_account);
         break;
     }
 
@@ -1125,7 +1124,7 @@ gnc_split_register_handle_exchange (SplitRegister *reg, gboolean force_dialog)
    * _not_ the blank split, then return FALSE -- this is a "special"
    * gain/loss stock transaction.
    */
-  if (gnc_numeric_zero_p(exch_rate) && !force_dialog &&
+  if (gnc_numeric_zero_p(exch_rate) && !force_dialog && split &&
       split != gnc_split_register_get_blank_split (reg))
     return FALSE;
 
@@ -1473,7 +1472,7 @@ gnc_split_register_recn_cell_confirm (char old_flag, gpointer data)
   /* Does the user want to be warned? */
   window = gnc_split_register_get_parent(reg);
   dialog =
-    gtk_message_dialog_new_with_markup(GTK_WINDOW(window),
+    gtk_message_dialog_new(GTK_WINDOW(window),
 				       GTK_DIALOG_DESTROY_WITH_PARENT,
                                        GTK_MESSAGE_WARNING,
 				       GTK_BUTTONS_CANCEL,
