@@ -1299,6 +1299,7 @@ gnc_split_register_save (SplitRegister *reg, gboolean do_commit)
    Transaction *pending_trans;
    Transaction *blank_trans;
    Transaction *trans;
+   Account *account;
    Split *blank_split;
    const char *memo;
    const char *desc;
@@ -1353,7 +1354,7 @@ gnc_split_register_save (SplitRegister *reg, gboolean do_commit)
      return TRUE;
    }
 
-   ENTER ("save split is %p \n", split);
+   DEBUG ("save split is %p \n", split);
 
    if (!gnc_split_register_auto_calc (reg, split))
      return FALSE;
@@ -1375,7 +1376,7 @@ gnc_split_register_save (SplitRegister *reg, gboolean do_commit)
        // FIXME: For that matter, how could an open pending
        // transaction ever not be the current trans?
        if (xaccTransIsOpen (pending_trans)) {
-           g_message("Impossible? commiting pending %p", pending_trans);
+           g_warning("Impossible? commiting pending %p", pending_trans);
            xaccTransCommitEdit (pending_trans);
        } else if (pending_trans) 
            g_assert_not_reached();
@@ -1401,8 +1402,9 @@ gnc_split_register_save (SplitRegister *reg, gboolean do_commit)
    /* If we are committing the blank split, add it to the account now */
    if (trans == blank_trans)
    {
-     xaccSplitSetAccount(blank_split, 
-                         gnc_split_register_get_default_account (reg));
+     account = gnc_split_register_get_default_account(reg);
+     if (account)
+       xaccSplitSetAccount(blank_split, account);
      xaccTransSetDateEnteredSecs(trans, time(NULL));
    }
 
@@ -1504,7 +1506,7 @@ gnc_split_register_get_account_by_name (SplitRegister *reg, BasicCell * bcell,
     return NULL;
 
   /* Find the account */
-  account = xaccGetAccountFromFullName (gnc_get_current_group (), name);
+  account = gnc_account_lookup_by_full_name (gnc_get_current_root_account (), name);
 
   if (!account) {
     /* Ask if they want to create a new one. */
@@ -1846,37 +1848,37 @@ gnc_split_register_type_to_account_type (SplitRegisterType sr_type)
   switch (sr_type)
   {
     case BANK_REGISTER:
-      return BANK;
+      return ACCT_TYPE_BANK;
     case CASH_REGISTER:
-      return CASH;
+      return ACCT_TYPE_CASH;
     case ASSET_REGISTER:
-      return ASSET;
+      return ACCT_TYPE_ASSET;
     case CREDIT_REGISTER:
-      return CREDIT;
+      return ACCT_TYPE_CREDIT;
     case LIABILITY_REGISTER:
-      return LIABILITY;
+      return ACCT_TYPE_LIABILITY;
     case PAYABLE_REGISTER:
-      return PAYABLE;
+      return ACCT_TYPE_PAYABLE;
     case RECEIVABLE_REGISTER:
-      return RECEIVABLE;
+      return ACCT_TYPE_RECEIVABLE;
     case INCOME_LEDGER:  
     case INCOME_REGISTER:
-      return INCOME;
+      return ACCT_TYPE_INCOME;
     case EXPENSE_REGISTER:
-      return EXPENSE;
+      return ACCT_TYPE_EXPENSE;
     case STOCK_REGISTER:
     case PORTFOLIO_LEDGER:
-      return STOCK;
+      return ACCT_TYPE_STOCK;
     case CURRENCY_REGISTER:
-      return CURRENCY;
+      return ACCT_TYPE_CURRENCY;
     case GENERAL_LEDGER:  
-      return NO_TYPE;
+      return ACCT_TYPE_NONE;
     case EQUITY_REGISTER:
-      return EQUITY;
+      return ACCT_TYPE_EQUITY;
     case SEARCH_LEDGER:
-      return NO_TYPE;
+      return ACCT_TYPE_NONE;
     default:
-      return NO_TYPE;
+      return ACCT_TYPE_NONE;
   }
 }
 
