@@ -31,7 +31,8 @@
 #include "basiccell.h"
 #include "formulacell.h"
 
-static QofLogModule log_module = GNC_MOD_SX;
+#undef G_LOG_DOMAIN
+#define G_LOG_DOMAIN "gnc.register.core.formulacell"
 
 static void gnc_formula_cell_init( FormulaCell *fc );
 
@@ -82,7 +83,7 @@ void
 gnc_formula_cell_set_value( FormulaCell *fc,
                             const char *newVal )
 {
-  DEBUG( "Got value \"%s\"", newVal );
+  g_debug("got value [%s]", newVal);
   gnc_formula_cell_set_value_internal( &fc->cell, newVal );
 }
 
@@ -93,7 +94,7 @@ gnc_formula_cell_enter( BasicCell *_cell,
                         int *start_selection,
                         int *end_selection )
 {
-  DEBUG( "%d, %d, %d", *cursor_position, *start_selection, *end_selection );
+  g_debug("%d, %d, %d", *cursor_position, *start_selection, *end_selection);
   *cursor_position = -1;
   *start_selection = 0;
   *end_selection   = -1;
@@ -140,9 +141,10 @@ gnc_formula_cell_modify_verify( BasicCell *_cell,
   const char *c;
   gunichar uc;
 
-  DEBUG( "%s, %d, %s, %d, %d, %d, %d",
-         (gchar *)change, change_len, (gchar *)newval, newval_len,
-         *cursor_position, *start_selection, *end_selection );
+  g_debug("%s, %d, %s, %d, %d, %d, %d",
+          change ? (gchar *)change : "(null)", change_len,
+          newval ? (gchar *)newval : "(null)", newval_len,
+          *cursor_position, *start_selection, *end_selection);
 
   /* accept the newval string if user action was delete */
   if (change == NULL)
@@ -184,6 +186,6 @@ gnc_formula_cell_set_value_internal( BasicCell *_cell,
                                      const char *str )
 {
   FormulaCell *fc = (FormulaCell*)_cell;
-  DEBUG( "internal string: %s", str );
+  g_debug("internal string: [%s]", str);
   gnc_basic_cell_set_value_internal( &fc->cell, str );
 }
