@@ -21,7 +21,7 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 (use-modules (gnucash main))
-(use-modules (g-wrapped gw-report-system)) 
+(use-modules (sw_report_system))
 
 ;; This hash should contain all the reports available and will be used
 ;; to generate the reports menu whenever a new window opens and to
@@ -99,9 +99,9 @@
 			 (gnc:report-template-name report-rec) report-rec)
 	      (begin
 		;; FIXME: We should pass the top-level window
-		;; instead of the #f to gnc:error-dialog, but I
+		;; instead of the '() to gnc-error-dialog, but I
 		;; have no idea where to get it from.
-		(gnc:error-dialog #f (string-append (_ "A custom report with this name already exists. Either rename the report to store it with a different name, or edit your saved-reports file and delete the section with the following name: ") name ))
+		(gnc-error-dialog '() (string-append (_ "A custom report with this name already exists. Either rename the report to store it with a different name, or edit your saved-reports file and delete the section with the following name: ") name ))
 		)))
         (gnc:warn "gnc:define-report: bad report"))))
 
@@ -266,7 +266,7 @@
                (cb r))))
        options))
 
-    (gnc:report-set-id! r (gnc:report-add r))
+    (gnc:report-set-id! r (gnc-report-add r))
     (gnc:report-id r))
   )
 
@@ -274,7 +274,7 @@
 (define (gnc:restore-report id template-name options)
   (let ((r ((record-constructor <report>)
             template-name id options #t #t #f #f)))
-    (gnc:report-add r))
+    (gnc-report-add r))
   )
 
 
@@ -392,14 +392,31 @@
     (gnc:report-type report))))
 
 (define gnc:current-saved-reports
-  (gnc:build-dotgnucash-path "saved-reports-2.0"))
+  (gnc-build-dotgnucash-path "saved-reports-2.0"))
 
 (define (gnc:report-save-to-savefile report)
-  (let ((conf-file-name gnc:current-saved-reports))
-    ;;(display conf-file-name)
-    (display (gnc:report-generate-saved-forms report)
-	     (open-file conf-file-name "a"))
-    (force-output)))
+  (let* ((conf-file-name gnc:current-saved-reports)
+         (saved-form (gnc:report-generate-saved-forms report))
+         ;; Immediate evaluate the saved form to both load it into the
+         ;; runtime, but also so we can check if it's "allowed" to actually
+         ;; be written to the saved reports file by inspecting the result.
+         ;; #Bug#342206.
+         (save-result (eval-string saved-form)))
+    (if (record? save-result)
+        (begin
+          (display saved-form
+                   (open-file conf-file-name "a"))
+          (force-output)
+	  (let ((report-name (gnc:report-name report)))
+	    (gnc-info-dialog
+	     '()
+	     (sprintf 
+	      #f (_ "Your report \"%s\" has been saved into the configuration file \"%s\".  The report will be available in the menu Reports -> Custom at the next startup of GnuCash.")
+	      (if (and report-name (not (string-null? report-name)))
+		  (gnc:gettext report-name)
+		  (gnc:gettext "Untitled"))
+	      conf-file-name)))
+	  ))))
 
 ;; gets the renderer from the report template;
 ;; gets the stylesheet from the report;
@@ -433,21 +450,15 @@
 ;; looks up the report by id and renders it with gnc:report-render-html
 ;; marks the cursor busy during rendering; returns the html
 (define (gnc:report-run id)
-  (let ((report (gnc:find-report id))
-	(start-time (gettimeofday))
+  (let ((report (gnc-report-find id))
 	(html #f))
-    (gnc:set-busy-cursor #f #t)
+    (gnc-set-busy-cursor '() #t)
     (gnc:backtrace-if-exception 
      (lambda ()
        (if report
 	   (begin 
-	     (set! html (gnc:report-render-html report #t))
-;;	     (display "total time to run report: ")
-;;	     (display (gnc:time-elapsed start-time (gettimeofday)))
-;;	     (newline)
-;;	     (display html) (newline)
-	     ))))
-    (gnc:unset-busy-cursor #f)
+	     (set! html (gnc:report-render-html report #t))))))
+    (gnc-unset-busy-cursor '())
     html))
 
 
